copy_postgres_extraction_service_data_batch

Function copy_postgres_extraction_service_data_batch 

pub async fn copy_postgres_extraction_service_data_batch(
    source_pool: &PgPool,
    destination_pool: &PgPool,
    plan: &ExtractionPlan,
    run: ExtractionBackfillRun,
    batch_id: impl Into<String>,
    limit: i64,
) -> Result<ExtractionBackfillRun, ExtractionBackfillError>
Read one plan-scoped source batch and copy it into the planned candidate Postgres table before atomically advancing the durable checkpoint.