pub struct CanaryPlan {Show 35 fields
pub protocol: String,
pub plan_id: String,
pub plan_digest: String,
pub release_id: String,
pub release_digest: String,
pub production_deployment_plan_id: String,
pub production_deployment_digest: String,
pub production_deployment_receipt_id: String,
pub production_deployment_observation_id: String,
pub production_environment: String,
pub production_expected_environment_revision: u64,
pub reliability_contract: DeliveryReliabilityContract,
pub release_rollback_constraints: ReleaseRollbackConstraints,
pub policy_evidence_id: String,
pub policy_evidence_digest: String,
pub environment_verification_id: String,
pub environment_verification_digest: String,
pub previous_known_good_plan_id: String,
pub previous_known_good_deployment_digest: String,
pub previous_known_good_release_id: String,
pub previous_known_good_release_digest: String,
pub previous_known_good_receipt_id: String,
pub previous_known_good_observation_id: String,
pub previous_known_good_policy_evidence_id: String,
pub previous_known_good_policy_evidence_digest: String,
pub previous_known_good_gateway_plan_id: String,
pub previous_known_good_gateway_plan_digest: String,
pub previous_known_good_gateway_configuration_identity: String,
pub previous_known_good_gateway_observation_id: String,
pub previous_known_good_gateway_observation_revision: u64,
pub previous_known_good_gateway_observed_after: String,
pub initial_percent: u8,
pub maximum_percent: u8,
pub workload_ids: Vec<String>,
pub effects: DeliveryEffects,
}Fields
protocol: Stringplan_id: Stringplan_digest: Stringrelease_id: Stringrelease_digest: Stringproduction_deployment_plan_id: Stringproduction_deployment_digest: Stringproduction_deployment_receipt_id: Stringproduction_deployment_observation_id: Stringproduction_environment: Stringproduction_expected_environment_revision: u64reliability_contract: DeliveryReliabilityContractrelease_rollback_constraints: ReleaseRollbackConstraintspolicy_evidence_id: Stringpolicy_evidence_digest: Stringenvironment_verification_id: Stringenvironment_verification_digest: Stringprevious_known_good_plan_id: Stringprevious_known_good_deployment_digest: Stringprevious_known_good_release_id: Stringprevious_known_good_release_digest: Stringprevious_known_good_receipt_id: Stringprevious_known_good_observation_id: Stringprevious_known_good_policy_evidence_id: Stringprevious_known_good_policy_evidence_digest: Stringprevious_known_good_gateway_plan_id: Stringprevious_known_good_gateway_plan_digest: Stringprevious_known_good_gateway_configuration_identity: Stringprevious_known_good_gateway_observation_id: Stringprevious_known_good_gateway_observation_revision: u64previous_known_good_gateway_observed_after: Stringinitial_percent: u8maximum_percent: u8workload_ids: Vec<String>effects: DeliveryEffectsTrait Implementations
Sourceimpl Clone for CanaryPlan
impl Clone for CanaryPlan
Sourcefn clone(&self) -> CanaryPlan
fn clone(&self) -> CanaryPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CanaryPlan
impl ComposeSchema for CanaryPlan
Sourceimpl Debug for CanaryPlan
impl Debug for CanaryPlan
Sourceimpl<'de> Deserialize<'de> for CanaryPlan
impl<'de> Deserialize<'de> for CanaryPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CanaryPlan
Sourceimpl JsonSchema for CanaryPlan
impl JsonSchema for CanaryPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CanaryPlan
impl PartialEq for CanaryPlan
Sourceimpl Serialize for CanaryPlan
impl Serialize for CanaryPlan
impl StructuralPartialEq for CanaryPlan