pub struct ConfigActivationPlan {
pub protocol: String,
pub plan_id: String,
pub plan_digest: String,
pub environment: String,
pub expected_environment_revision: u64,
pub operation: ConfigOperation,
pub target_revision_id: String,
pub previous_revision_id: Option<String>,
pub contract_digest: String,
pub effects: DeliveryEffects,
}Fields
protocol: Stringplan_id: Stringplan_digest: Stringenvironment: Stringexpected_environment_revision: u64operation: ConfigOperationtarget_revision_id: Stringprevious_revision_id: Option<String>contract_digest: Stringeffects: DeliveryEffectsTrait Implementations
Sourceimpl Clone for ConfigActivationPlan
impl Clone for ConfigActivationPlan
Sourcefn clone(&self) -> ConfigActivationPlan
fn clone(&self) -> ConfigActivationPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ConfigActivationPlan
impl ComposeSchema for ConfigActivationPlan
Sourceimpl Debug for ConfigActivationPlan
impl Debug for ConfigActivationPlan
Sourceimpl<'de> Deserialize<'de> for ConfigActivationPlan
impl<'de> Deserialize<'de> for ConfigActivationPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConfigActivationPlan
Sourceimpl JsonSchema for ConfigActivationPlan
impl JsonSchema for ConfigActivationPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConfigActivationPlan
impl PartialEq for ConfigActivationPlan
Sourceimpl Serialize for ConfigActivationPlan
impl Serialize for ConfigActivationPlan
impl StructuralPartialEq for ConfigActivationPlan