pub struct ConfigActivationReceipt {
pub protocol: String,
pub receipt_id: String,
pub plan_id: String,
pub environment: String,
pub environment_revision_before: u64,
pub environment_revision_after: u64,
pub target_revision_id: String,
pub previous_revision_id: Option<String>,
pub activation: ConfigRevisionActivation,
pub effects: DeliveryEffects,
}Fields
protocol: Stringreceipt_id: Stringplan_id: Stringenvironment: Stringenvironment_revision_before: u64environment_revision_after: u64target_revision_id: Stringprevious_revision_id: Option<String>activation: ConfigRevisionActivationeffects: DeliveryEffectsTrait Implementations
Sourceimpl Clone for ConfigActivationReceipt
impl Clone for ConfigActivationReceipt
Sourcefn clone(&self) -> ConfigActivationReceipt
fn clone(&self) -> ConfigActivationReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ConfigActivationReceipt
impl ComposeSchema for ConfigActivationReceipt
Sourceimpl Debug for ConfigActivationReceipt
impl Debug for ConfigActivationReceipt
Sourceimpl<'de> Deserialize<'de> for ConfigActivationReceipt
impl<'de> Deserialize<'de> for ConfigActivationReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConfigActivationReceipt
Sourceimpl JsonSchema for ConfigActivationReceipt
impl JsonSchema for ConfigActivationReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConfigActivationReceipt
impl PartialEq for ConfigActivationReceipt
Sourceimpl Serialize for ConfigActivationReceipt
impl Serialize for ConfigActivationReceipt
impl StructuralPartialEq for ConfigActivationReceipt