pub struct ConfigApplyRejection {
pub issues: Vec<DeliveryIssue>,
pub effects: DeliveryEffects,
}Fields
issues: Vec<DeliveryIssue>effects: DeliveryEffectsTrait Implementations
Sourceimpl Clone for ConfigApplyRejection
impl Clone for ConfigApplyRejection
Sourcefn clone(&self) -> ConfigApplyRejection
fn clone(&self) -> ConfigApplyRejection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ConfigApplyRejection
impl ComposeSchema for ConfigApplyRejection
Sourceimpl Debug for ConfigApplyRejection
impl Debug for ConfigApplyRejection
Sourceimpl<'de> Deserialize<'de> for ConfigApplyRejection
impl<'de> Deserialize<'de> for ConfigApplyRejection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConfigApplyRejection
Sourceimpl JsonSchema for ConfigApplyRejection
impl JsonSchema for ConfigApplyRejection
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConfigApplyRejection
impl PartialEq for ConfigApplyRejection
Sourceimpl Serialize for ConfigApplyRejection
impl Serialize for ConfigApplyRejection
impl StructuralPartialEq for ConfigApplyRejection