pub struct ConfigContractDefinition {
pub protocol: String,
pub reference: String,
pub digest: String,
pub fields: Vec<ConfigField>,
}Fields
protocol: Stringreference: Stringdigest: Stringfields: Vec<ConfigField>Trait Implementations
Sourceimpl Clone for ConfigContractDefinition
impl Clone for ConfigContractDefinition
Sourcefn clone(&self) -> ConfigContractDefinition
fn clone(&self) -> ConfigContractDefinition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ConfigContractDefinition
impl ComposeSchema for ConfigContractDefinition
Sourceimpl Debug for ConfigContractDefinition
impl Debug for ConfigContractDefinition
Sourceimpl<'de> Deserialize<'de> for ConfigContractDefinition
impl<'de> Deserialize<'de> for ConfigContractDefinition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConfigContractDefinition
Sourceimpl JsonSchema for ConfigContractDefinition
impl JsonSchema for ConfigContractDefinition
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConfigContractDefinition
impl PartialEq for ConfigContractDefinition
Sourceimpl Serialize for ConfigContractDefinition
impl Serialize for ConfigContractDefinition
impl StructuralPartialEq for ConfigContractDefinition