pub struct ConfigField {
pub path: String,
pub value_type: ConfigValueType,
pub required: bool,
pub sensitivity: ConfigFieldSensitivity,
pub scope: ConfigFieldScope,
pub activation: ConfigFieldActivation,
pub mutable: bool,
}Fields
path: Stringvalue_type: ConfigValueTyperequired: boolsensitivity: ConfigFieldSensitivityscope: ConfigFieldScopeactivation: ConfigFieldActivationmutable: boolTrait Implementations
Sourceimpl Clone for ConfigField
impl Clone for ConfigField
Sourcefn clone(&self) -> ConfigField
fn clone(&self) -> ConfigField
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ConfigField
impl ComposeSchema for ConfigField
Sourceimpl Debug for ConfigField
impl Debug for ConfigField
Sourceimpl<'de> Deserialize<'de> for ConfigField
impl<'de> Deserialize<'de> for ConfigField
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConfigField
Sourceimpl JsonSchema for ConfigField
impl JsonSchema for ConfigField
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ConfigField
impl Ord for ConfigField
Sourcefn cmp(&self, other: &ConfigField) -> Ordering
fn cmp(&self, other: &ConfigField) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ConfigField
impl PartialEq for ConfigField
Sourceimpl PartialOrd for ConfigField
impl PartialOrd for ConfigField
Sourceimpl Serialize for ConfigField
impl Serialize for ConfigField
impl StructuralPartialEq for ConfigField