pub struct ConfigImpact {
pub path: String,
pub scope: ConfigFieldScope,
pub activation: ConfigFieldActivation,
pub mutable: bool,
}Fields
path: Stringscope: ConfigFieldScopeactivation: ConfigFieldActivationmutable: boolTrait Implementations
Sourceimpl Clone for ConfigImpact
impl Clone for ConfigImpact
Sourcefn clone(&self) -> ConfigImpact
fn clone(&self) -> ConfigImpact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ConfigImpact
impl ComposeSchema for ConfigImpact
Sourceimpl Debug for ConfigImpact
impl Debug for ConfigImpact
Sourceimpl<'de> Deserialize<'de> for ConfigImpact
impl<'de> Deserialize<'de> for ConfigImpact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConfigImpact
impl JsonSchema for ConfigImpact
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConfigImpact
impl PartialEq for ConfigImpact
Sourceimpl Serialize for ConfigImpact
impl Serialize for ConfigImpact
impl StructuralPartialEq for ConfigImpact