pub struct ConfigRevision {
pub protocol: String,
pub revision_id: String,
pub revision_digest: String,
pub service_id: String,
pub contract_reference: String,
pub contract_digest: String,
pub values: BTreeMap<String, Value>,
pub secret_references: Vec<SecretReference>,
pub impacts: Vec<ConfigImpact>,
}Fields
protocol: Stringrevision_id: Stringrevision_digest: Stringservice_id: Stringcontract_reference: Stringcontract_digest: Stringvalues: BTreeMap<String, Value>secret_references: Vec<SecretReference>impacts: Vec<ConfigImpact>Trait Implementations
Sourceimpl Clone for ConfigRevision
impl Clone for ConfigRevision
Sourcefn clone(&self) -> ConfigRevision
fn clone(&self) -> ConfigRevision
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ConfigRevision
impl ComposeSchema for ConfigRevision
Sourceimpl Debug for ConfigRevision
impl Debug for ConfigRevision
Sourceimpl<'de> Deserialize<'de> for ConfigRevision
impl<'de> Deserialize<'de> for ConfigRevision
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConfigRevision
impl JsonSchema for ConfigRevision
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConfigRevision
impl PartialEq for ConfigRevision
Sourceimpl Serialize for ConfigRevision
impl Serialize for ConfigRevision
impl StructuralPartialEq for ConfigRevision