pub struct ContractCompatibilityInput {
pub contract_id: String,
pub current_major: u32,
pub candidate_major: u32,
pub compatible: Option<bool>,
pub active_consumers: Vec<String>,
pub consumer_migration_evidence: bool,
pub retiring: bool,
pub deprecation_window_complete: bool,
}Fields
contract_id: Stringcurrent_major: u32candidate_major: u32compatible: Option<bool>active_consumers: Vec<String>consumer_migration_evidence: boolretiring: booldeprecation_window_complete: boolTrait Implementations
Sourceimpl Clone for ContractCompatibilityInput
impl Clone for ContractCompatibilityInput
Sourcefn clone(&self) -> ContractCompatibilityInput
fn clone(&self) -> ContractCompatibilityInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ContractCompatibilityInput
impl ComposeSchema for ContractCompatibilityInput
Sourceimpl Debug for ContractCompatibilityInput
impl Debug for ContractCompatibilityInput
Sourceimpl<'de> Deserialize<'de> for ContractCompatibilityInput
impl<'de> Deserialize<'de> for ContractCompatibilityInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ContractCompatibilityInput
Sourceimpl JsonSchema for ContractCompatibilityInput
impl JsonSchema for ContractCompatibilityInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ContractCompatibilityInput