pub struct ContractConsumerEvidence {
pub consumer_id: String,
pub active_version: Option<String>,
pub replacement_verified: bool,
}Fields
consumer_id: Stringactive_version: Option<String>replacement_verified: boolTrait Implementations
Sourceimpl Clone for ContractConsumerEvidence
impl Clone for ContractConsumerEvidence
Sourcefn clone(&self) -> ContractConsumerEvidence
fn clone(&self) -> ContractConsumerEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ContractConsumerEvidence
impl ComposeSchema for ContractConsumerEvidence
Sourceimpl Debug for ContractConsumerEvidence
impl Debug for ContractConsumerEvidence
Sourceimpl<'de> Deserialize<'de> for ContractConsumerEvidence
impl<'de> Deserialize<'de> for ContractConsumerEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ContractConsumerEvidence
Sourceimpl JsonSchema for ContractConsumerEvidence
impl JsonSchema for ContractConsumerEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ContractConsumerEvidence
impl PartialEq for ContractConsumerEvidence
Sourceimpl Serialize for ContractConsumerEvidence
impl Serialize for ContractConsumerEvidence
impl StructuralPartialEq for ContractConsumerEvidence