pub struct ContractRetirementEffects {
pub retires_contract: bool,
pub mutates_consumers: bool,
}Fields
retires_contract: boolmutates_consumers: boolTrait Implementations
Sourceimpl Clone for ContractRetirementEffects
impl Clone for ContractRetirementEffects
Sourcefn clone(&self) -> ContractRetirementEffects
fn clone(&self) -> ContractRetirementEffects
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ContractRetirementEffects
impl ComposeSchema for ContractRetirementEffects
impl Copy for ContractRetirementEffects
Sourceimpl Debug for ContractRetirementEffects
impl Debug for ContractRetirementEffects
Sourceimpl Default for ContractRetirementEffects
impl Default for ContractRetirementEffects
Sourcefn default() -> ContractRetirementEffects
fn default() -> ContractRetirementEffects
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ContractRetirementEffects
impl<'de> Deserialize<'de> for ContractRetirementEffects
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ContractRetirementEffects
Sourceimpl JsonSchema for ContractRetirementEffects
impl JsonSchema for ContractRetirementEffects
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ContractRetirementEffects