pub struct ContractRetirementEvidence {
pub contract_id: String,
pub ready: bool,
pub active_consumers: Vec<String>,
pub deprecation_window_complete: bool,
}Fields
contract_id: Stringready: boolactive_consumers: Vec<String>deprecation_window_complete: boolTrait Implementations
Sourceimpl Clone for ContractRetirementEvidence
impl Clone for ContractRetirementEvidence
Sourcefn clone(&self) -> ContractRetirementEvidence
fn clone(&self) -> ContractRetirementEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ContractRetirementEvidence
impl ComposeSchema for ContractRetirementEvidence
Sourceimpl Debug for ContractRetirementEvidence
impl Debug for ContractRetirementEvidence
Sourceimpl<'de> Deserialize<'de> for ContractRetirementEvidence
impl<'de> Deserialize<'de> for ContractRetirementEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ContractRetirementEvidence
Sourceimpl JsonSchema for ContractRetirementEvidence
impl JsonSchema for ContractRetirementEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ContractRetirementEvidence