pub struct ContractRetirementInput {
pub system_graph_digest: String,
pub environment_evidence_digest: String,
pub evidence_fresh: bool,
pub contract_id: String,
pub retiring_version: String,
pub replacement_version: String,
pub deprecation_window_complete: bool,
pub consumers: Vec<ContractConsumerEvidence>,
}Fields
system_graph_digest: Stringenvironment_evidence_digest: Stringevidence_fresh: boolcontract_id: Stringretiring_version: Stringreplacement_version: Stringdeprecation_window_complete: boolconsumers: Vec<ContractConsumerEvidence>Trait Implementations
Sourceimpl Clone for ContractRetirementInput
impl Clone for ContractRetirementInput
Sourcefn clone(&self) -> ContractRetirementInput
fn clone(&self) -> ContractRetirementInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ContractRetirementInput
impl ComposeSchema for ContractRetirementInput
Sourceimpl Debug for ContractRetirementInput
impl Debug for ContractRetirementInput
Sourceimpl<'de> Deserialize<'de> for ContractRetirementInput
impl<'de> Deserialize<'de> for ContractRetirementInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ContractRetirementInput
Sourceimpl JsonSchema for ContractRetirementInput
impl JsonSchema for ContractRetirementInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ContractRetirementInput
impl PartialEq for ContractRetirementInput
Sourceimpl Serialize for ContractRetirementInput
impl Serialize for ContractRetirementInput
impl StructuralPartialEq for ContractRetirementInput