pub struct ContractRetirementPlan {Show 13 fields
pub protocol: String,
pub plan_id: String,
pub plan_digest: String,
pub input_digest: String,
pub decision: SupportDecision,
pub contract_id: String,
pub retiring_version: String,
pub replacement_version: String,
pub affected_consumers: Vec<String>,
pub irreversible_effects: Vec<String>,
pub issues: Vec<GaIssue>,
pub effects: ContractRetirementEffects,
pub approval_boundary: String,
}Fields
protocol: Stringplan_id: Stringplan_digest: Stringinput_digest: Stringdecision: SupportDecisioncontract_id: Stringretiring_version: Stringreplacement_version: Stringaffected_consumers: Vec<String>irreversible_effects: Vec<String>issues: Vec<GaIssue>effects: ContractRetirementEffectsapproval_boundary: StringTrait Implementations
Sourceimpl Clone for ContractRetirementPlan
impl Clone for ContractRetirementPlan
Sourcefn clone(&self) -> ContractRetirementPlan
fn clone(&self) -> ContractRetirementPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ContractRetirementPlan
impl ComposeSchema for ContractRetirementPlan
Sourceimpl Debug for ContractRetirementPlan
impl Debug for ContractRetirementPlan
Sourceimpl<'de> Deserialize<'de> for ContractRetirementPlan
impl<'de> Deserialize<'de> for ContractRetirementPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ContractRetirementPlan
Sourceimpl JsonSchema for ContractRetirementPlan
impl JsonSchema for ContractRetirementPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ContractRetirementPlan
impl PartialEq for ContractRetirementPlan
Sourceimpl Serialize for ContractRetirementPlan
impl Serialize for ContractRetirementPlan
impl StructuralPartialEq for ContractRetirementPlan