pub struct ContractRetirementReceipt {
pub protocol: String,
pub receipt_id: String,
pub receipt_digest: String,
pub plan_digest: String,
pub contract_id: String,
pub retired_version: String,
pub replacement_version: String,
pub approver: String,
pub approval_reason: String,
pub retired: bool,
}Fields
protocol: Stringreceipt_id: Stringreceipt_digest: Stringplan_digest: Stringcontract_id: Stringretired_version: Stringreplacement_version: Stringapprover: Stringapproval_reason: Stringretired: boolTrait Implementations
Sourceimpl Clone for ContractRetirementReceipt
impl Clone for ContractRetirementReceipt
Sourcefn clone(&self) -> ContractRetirementReceipt
fn clone(&self) -> ContractRetirementReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ContractRetirementReceipt
impl ComposeSchema for ContractRetirementReceipt
Sourceimpl Debug for ContractRetirementReceipt
impl Debug for ContractRetirementReceipt
Sourceimpl<'de> Deserialize<'de> for ContractRetirementReceipt
impl<'de> Deserialize<'de> for ContractRetirementReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ContractRetirementReceipt
Sourceimpl JsonSchema for ContractRetirementReceipt
impl JsonSchema for ContractRetirementReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ContractRetirementReceipt