pub struct CorsIntent {
pub allowed_origins: Vec<String>,
pub allowed_methods: Vec<String>,
}Fields
allowed_origins: Vec<String>allowed_methods: Vec<String>Trait Implementations
Sourceimpl Clone for CorsIntent
impl Clone for CorsIntent
Sourcefn clone(&self) -> CorsIntent
fn clone(&self) -> CorsIntent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CorsIntent
impl ComposeSchema for CorsIntent
Sourceimpl Debug for CorsIntent
impl Debug for CorsIntent
Sourceimpl<'de> Deserialize<'de> for CorsIntent
impl<'de> Deserialize<'de> for CorsIntent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CorsIntent
Sourceimpl JsonSchema for CorsIntent
impl JsonSchema for CorsIntent
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CorsIntent
impl PartialEq for CorsIntent
Sourceimpl Serialize for CorsIntent
impl Serialize for CorsIntent
impl StructuralPartialEq for CorsIntent