pub struct DeliveryConsoleAdapterDrift {
pub environment: String,
pub drifted: bool,
pub fresh: bool,
pub next_actions: Vec<String>,
}Fields
environment: Stringdrifted: boolfresh: boolnext_actions: Vec<String>Trait Implementations
Sourceimpl Clone for DeliveryConsoleAdapterDrift
impl Clone for DeliveryConsoleAdapterDrift
Sourcefn clone(&self) -> DeliveryConsoleAdapterDrift
fn clone(&self) -> DeliveryConsoleAdapterDrift
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeliveryConsoleAdapterDrift
impl ComposeSchema for DeliveryConsoleAdapterDrift
Sourceimpl Debug for DeliveryConsoleAdapterDrift
impl Debug for DeliveryConsoleAdapterDrift
Sourceimpl<'de> Deserialize<'de> for DeliveryConsoleAdapterDrift
impl<'de> Deserialize<'de> for DeliveryConsoleAdapterDrift
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeliveryConsoleAdapterDrift
Sourceimpl JsonSchema for DeliveryConsoleAdapterDrift
impl JsonSchema for DeliveryConsoleAdapterDrift
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DeliveryConsoleAdapterDrift