pub struct DeliveryConsoleConfiguration {
pub desired_revision_id: Option<String>,
pub active_revision_id: Option<String>,
pub previous_revision_id: Option<String>,
pub drifted: bool,
pub secret_references: Vec<DeliveryConsoleSecretReference>,
}Fields
desired_revision_id: Option<String>active_revision_id: Option<String>previous_revision_id: Option<String>drifted: boolsecret_references: Vec<DeliveryConsoleSecretReference>Trait Implementations
Sourceimpl Clone for DeliveryConsoleConfiguration
impl Clone for DeliveryConsoleConfiguration
Sourcefn clone(&self) -> DeliveryConsoleConfiguration
fn clone(&self) -> DeliveryConsoleConfiguration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeliveryConsoleConfiguration
impl ComposeSchema for DeliveryConsoleConfiguration
Sourceimpl Debug for DeliveryConsoleConfiguration
impl Debug for DeliveryConsoleConfiguration
Sourceimpl Default for DeliveryConsoleConfiguration
impl Default for DeliveryConsoleConfiguration
Sourcefn default() -> DeliveryConsoleConfiguration
fn default() -> DeliveryConsoleConfiguration
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for DeliveryConsoleConfiguration
impl<'de> Deserialize<'de> for DeliveryConsoleConfiguration
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeliveryConsoleConfiguration
Sourceimpl JsonSchema for DeliveryConsoleConfiguration
impl JsonSchema for DeliveryConsoleConfiguration
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DeliveryConsoleConfiguration