pub struct DeliveryConsoleDeployment {
pub environment: String,
pub desired_release_id: String,
pub observed_release_id: String,
pub config_revision_id: String,
pub drifted: bool,
pub fresh: bool,
}Fields
environment: Stringdesired_release_id: Stringobserved_release_id: Stringconfig_revision_id: Stringdrifted: boolfresh: boolTrait Implementations
Sourceimpl Clone for DeliveryConsoleDeployment
impl Clone for DeliveryConsoleDeployment
Sourcefn clone(&self) -> DeliveryConsoleDeployment
fn clone(&self) -> DeliveryConsoleDeployment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeliveryConsoleDeployment
impl ComposeSchema for DeliveryConsoleDeployment
Sourceimpl Debug for DeliveryConsoleDeployment
impl Debug for DeliveryConsoleDeployment
Sourceimpl<'de> Deserialize<'de> for DeliveryConsoleDeployment
impl<'de> Deserialize<'de> for DeliveryConsoleDeployment
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeliveryConsoleDeployment
Sourceimpl JsonSchema for DeliveryConsoleDeployment
impl JsonSchema for DeliveryConsoleDeployment
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DeliveryConsoleDeployment