pub struct DeliveryConsoleEdge {
pub contract_id: String,
pub public_routes: Vec<String>,
}Fields
contract_id: Stringpublic_routes: Vec<String>Trait Implementations
Sourceimpl Clone for DeliveryConsoleEdge
impl Clone for DeliveryConsoleEdge
Sourcefn clone(&self) -> DeliveryConsoleEdge
fn clone(&self) -> DeliveryConsoleEdge
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeliveryConsoleEdge
impl ComposeSchema for DeliveryConsoleEdge
Sourceimpl Debug for DeliveryConsoleEdge
impl Debug for DeliveryConsoleEdge
Sourceimpl<'de> Deserialize<'de> for DeliveryConsoleEdge
impl<'de> Deserialize<'de> for DeliveryConsoleEdge
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeliveryConsoleEdge
Sourceimpl JsonSchema for DeliveryConsoleEdge
impl JsonSchema for DeliveryConsoleEdge
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DeliveryConsoleEdge
impl PartialEq for DeliveryConsoleEdge
Sourceimpl Serialize for DeliveryConsoleEdge
impl Serialize for DeliveryConsoleEdge
impl StructuralPartialEq for DeliveryConsoleEdge