pub struct DeliveryConsoleIssue {
pub code: String,
pub message: String,
pub evidence_references: Vec<String>,
pub remediation: String,
pub next_actions: Vec<String>,
}Fields
code: Stringmessage: Stringevidence_references: Vec<String>remediation: Stringnext_actions: Vec<String>Trait Implementations
Sourceimpl Clone for DeliveryConsoleIssue
impl Clone for DeliveryConsoleIssue
Sourcefn clone(&self) -> DeliveryConsoleIssue
fn clone(&self) -> DeliveryConsoleIssue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeliveryConsoleIssue
impl ComposeSchema for DeliveryConsoleIssue
Sourceimpl Debug for DeliveryConsoleIssue
impl Debug for DeliveryConsoleIssue
Sourceimpl<'de> Deserialize<'de> for DeliveryConsoleIssue
impl<'de> Deserialize<'de> for DeliveryConsoleIssue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeliveryConsoleIssue
Sourceimpl JsonSchema for DeliveryConsoleIssue
impl JsonSchema for DeliveryConsoleIssue
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for DeliveryConsoleIssue
impl Ord for DeliveryConsoleIssue
Sourcefn cmp(&self, other: &DeliveryConsoleIssue) -> Ordering
fn cmp(&self, other: &DeliveryConsoleIssue) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeliveryConsoleIssue
impl PartialEq for DeliveryConsoleIssue
Sourceimpl PartialOrd for DeliveryConsoleIssue
impl PartialOrd for DeliveryConsoleIssue
Sourceimpl Serialize for DeliveryConsoleIssue
impl Serialize for DeliveryConsoleIssue
impl StructuralPartialEq for DeliveryConsoleIssue