pub struct DeliveryConsolePolicy {
pub evidence_id: String,
pub pack_id: String,
pub decision: String,
}Fields
evidence_id: Stringpack_id: Stringdecision: StringTrait Implementations
Sourceimpl Clone for DeliveryConsolePolicy
impl Clone for DeliveryConsolePolicy
Sourcefn clone(&self) -> DeliveryConsolePolicy
fn clone(&self) -> DeliveryConsolePolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeliveryConsolePolicy
impl ComposeSchema for DeliveryConsolePolicy
Sourceimpl Debug for DeliveryConsolePolicy
impl Debug for DeliveryConsolePolicy
Sourceimpl<'de> Deserialize<'de> for DeliveryConsolePolicy
impl<'de> Deserialize<'de> for DeliveryConsolePolicy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeliveryConsolePolicy
Sourceimpl JsonSchema for DeliveryConsolePolicy
impl JsonSchema for DeliveryConsolePolicy
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DeliveryConsolePolicy
impl PartialEq for DeliveryConsolePolicy
Sourceimpl Serialize for DeliveryConsolePolicy
impl Serialize for DeliveryConsolePolicy
impl StructuralPartialEq for DeliveryConsolePolicy