pub struct DeliveryConsoleProjection {Show 20 fields
pub protocol: String,
pub projection_digest: String,
pub state: DeliveryConsoleState,
pub release: Option<DeliveryConsoleRelease>,
pub supply_chain: Vec<DeliveryConsoleSupplyChainWorkload>,
pub policy: Option<DeliveryConsolePolicy>,
pub configuration: DeliveryConsoleConfiguration,
pub deployments: Vec<DeliveryConsoleDeployment>,
pub edge: Option<DeliveryConsoleEdge>,
pub adapter_drift: Vec<DeliveryConsoleAdapterDrift>,
pub promotion_history: Vec<DeliveryConsoleTimelineEntry>,
pub canary_timeline: Vec<DeliveryConsoleTimelineEntry>,
pub canary_observations: Vec<DeliveryConsoleCanaryObservation>,
pub rollback_timeline: Vec<DeliveryConsoleTimelineEntry>,
pub issues: Vec<DeliveryConsoleIssue>,
pub next_actions: Vec<String>,
pub runtime_story_references: Vec<String>,
pub ga_operations: DeliveryConsoleGaOperations,
pub read_only: bool,
pub apply_actions: Vec<String>,
}Fields
protocol: Stringprojection_digest: Stringstate: DeliveryConsoleStaterelease: Option<DeliveryConsoleRelease>supply_chain: Vec<DeliveryConsoleSupplyChainWorkload>policy: Option<DeliveryConsolePolicy>configuration: DeliveryConsoleConfigurationdeployments: Vec<DeliveryConsoleDeployment>edge: Option<DeliveryConsoleEdge>adapter_drift: Vec<DeliveryConsoleAdapterDrift>promotion_history: Vec<DeliveryConsoleTimelineEntry>canary_timeline: Vec<DeliveryConsoleTimelineEntry>canary_observations: Vec<DeliveryConsoleCanaryObservation>rollback_timeline: Vec<DeliveryConsoleTimelineEntry>issues: Vec<DeliveryConsoleIssue>next_actions: Vec<String>runtime_story_references: Vec<String>ga_operations: DeliveryConsoleGaOperationsread_only: boolapply_actions: Vec<String>Trait Implementations
Sourceimpl Clone for DeliveryConsoleProjection
impl Clone for DeliveryConsoleProjection
Sourcefn clone(&self) -> DeliveryConsoleProjection
fn clone(&self) -> DeliveryConsoleProjection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeliveryConsoleProjection
impl ComposeSchema for DeliveryConsoleProjection
Sourceimpl Debug for DeliveryConsoleProjection
impl Debug for DeliveryConsoleProjection
Sourceimpl<'de> Deserialize<'de> for DeliveryConsoleProjection
impl<'de> Deserialize<'de> for DeliveryConsoleProjection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeliveryConsoleProjection
Sourceimpl JsonSchema for DeliveryConsoleProjection
impl JsonSchema for DeliveryConsoleProjection
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DeliveryConsoleProjection