pub struct DeliveryConsoleSecretReference {
pub reference_id: String,
pub provider: String,
pub purpose: String,
pub scope: String,
pub status: String,
pub rotation_revision: Option<String>,
}Fields
reference_id: Stringprovider: Stringpurpose: Stringscope: Stringstatus: Stringrotation_revision: Option<String>Trait Implementations
Sourceimpl Clone for DeliveryConsoleSecretReference
impl Clone for DeliveryConsoleSecretReference
Sourcefn clone(&self) -> DeliveryConsoleSecretReference
fn clone(&self) -> DeliveryConsoleSecretReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeliveryConsoleSecretReference
impl ComposeSchema for DeliveryConsoleSecretReference
Sourceimpl<'de> Deserialize<'de> for DeliveryConsoleSecretReference
impl<'de> Deserialize<'de> for DeliveryConsoleSecretReference
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeliveryConsoleSecretReference
Sourceimpl JsonSchema for DeliveryConsoleSecretReference
impl JsonSchema for DeliveryConsoleSecretReference
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DeliveryConsoleSecretReference