pub struct DeliveryConsoleSupplyChainWorkload {
pub workload_id: String,
pub artifact_digest: String,
pub signature_status: String,
pub sbom_reference: String,
pub provenance_reference: String,
pub provenance_subject_matches: bool,
}Fields
workload_id: Stringartifact_digest: Stringsignature_status: Stringsbom_reference: Stringprovenance_reference: Stringprovenance_subject_matches: boolTrait Implementations
Sourceimpl Clone for DeliveryConsoleSupplyChainWorkload
impl Clone for DeliveryConsoleSupplyChainWorkload
Sourcefn clone(&self) -> DeliveryConsoleSupplyChainWorkload
fn clone(&self) -> DeliveryConsoleSupplyChainWorkload
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeliveryConsoleSupplyChainWorkload
impl ComposeSchema for DeliveryConsoleSupplyChainWorkload
Sourceimpl<'de> Deserialize<'de> for DeliveryConsoleSupplyChainWorkload
impl<'de> Deserialize<'de> for DeliveryConsoleSupplyChainWorkload
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeliveryConsoleSupplyChainWorkload
Sourceimpl JsonSchema for DeliveryConsoleSupplyChainWorkload
impl JsonSchema for DeliveryConsoleSupplyChainWorkload
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DeliveryConsoleSupplyChainWorkload