pub struct DeliveryConsoleTimelineEntry {
pub protocol: String,
pub artifact_id: String,
pub state: String,
pub evidence_references: Vec<String>,
}Fields
protocol: Stringartifact_id: Stringstate: Stringevidence_references: Vec<String>Trait Implementations
Sourceimpl Clone for DeliveryConsoleTimelineEntry
impl Clone for DeliveryConsoleTimelineEntry
Sourcefn clone(&self) -> DeliveryConsoleTimelineEntry
fn clone(&self) -> DeliveryConsoleTimelineEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeliveryConsoleTimelineEntry
impl ComposeSchema for DeliveryConsoleTimelineEntry
Sourceimpl Debug for DeliveryConsoleTimelineEntry
impl Debug for DeliveryConsoleTimelineEntry
Sourceimpl<'de> Deserialize<'de> for DeliveryConsoleTimelineEntry
impl<'de> Deserialize<'de> for DeliveryConsoleTimelineEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeliveryConsoleTimelineEntry
Sourceimpl JsonSchema for DeliveryConsoleTimelineEntry
impl JsonSchema for DeliveryConsoleTimelineEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for DeliveryConsoleTimelineEntry
impl Ord for DeliveryConsoleTimelineEntry
Sourcefn cmp(&self, other: &DeliveryConsoleTimelineEntry) -> Ordering
fn cmp(&self, other: &DeliveryConsoleTimelineEntry) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for DeliveryConsoleTimelineEntry
impl PartialOrd for DeliveryConsoleTimelineEntry
impl StructuralPartialEq for DeliveryConsoleTimelineEntry