pub struct DeliveryEffects {
pub mutates_environment: bool,
pub mutates_configuration: bool,
pub mutates_gateway: bool,
pub mutates_deployment: bool,
pub appends_ledger: bool,
}Fields
mutates_environment: boolmutates_configuration: boolmutates_gateway: boolmutates_deployment: boolappends_ledger: boolTrait Implementations
Sourceimpl Clone for DeliveryEffects
impl Clone for DeliveryEffects
Sourcefn clone(&self) -> DeliveryEffects
fn clone(&self) -> DeliveryEffects
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeliveryEffects
impl ComposeSchema for DeliveryEffects
impl Copy for DeliveryEffects
Sourceimpl Debug for DeliveryEffects
impl Debug for DeliveryEffects
Sourceimpl Default for DeliveryEffects
impl Default for DeliveryEffects
Sourcefn default() -> DeliveryEffects
fn default() -> DeliveryEffects
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for DeliveryEffects
impl<'de> Deserialize<'de> for DeliveryEffects
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeliveryEffects
Sourceimpl JsonSchema for DeliveryEffects
impl JsonSchema for DeliveryEffects
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DeliveryEffects
impl PartialEq for DeliveryEffects
Sourceimpl Serialize for DeliveryEffects
impl Serialize for DeliveryEffects
impl StructuralPartialEq for DeliveryEffects