pub struct DeliveryEvidenceReference {
pub reference: String,
pub digest: String,
}Fields
reference: Stringdigest: StringTrait Implementations
Sourceimpl Clone for DeliveryEvidenceReference
impl Clone for DeliveryEvidenceReference
Sourcefn clone(&self) -> DeliveryEvidenceReference
fn clone(&self) -> DeliveryEvidenceReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeliveryEvidenceReference
impl ComposeSchema for DeliveryEvidenceReference
Sourceimpl Debug for DeliveryEvidenceReference
impl Debug for DeliveryEvidenceReference
Sourceimpl<'de> Deserialize<'de> for DeliveryEvidenceReference
impl<'de> Deserialize<'de> for DeliveryEvidenceReference
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeliveryEvidenceReference
Sourceimpl JsonSchema for DeliveryEvidenceReference
impl JsonSchema for DeliveryEvidenceReference
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for DeliveryEvidenceReference
impl Ord for DeliveryEvidenceReference
Sourcefn cmp(&self, other: &DeliveryEvidenceReference) -> Ordering
fn cmp(&self, other: &DeliveryEvidenceReference) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for DeliveryEvidenceReference
impl PartialOrd for DeliveryEvidenceReference
impl StructuralPartialEq for DeliveryEvidenceReference