pub struct DeliveryFailureRecoveryEvidence {Show 16 fields
pub protocol: String,
pub evidence_id: String,
pub evidence_digest: String,
pub scenario_id: String,
pub condition: DeliveryFailureCondition,
pub stage: DeliveryFailureStage,
pub scope: DeliveryRecoveryScope,
pub desired_state: DeliveryStateObservation,
pub observed_state: DeliveryStateObservation,
pub retained_config_revision_id: String,
pub migration: Option<MigrationRecoveryEvidence>,
pub environment_observation: Option<KubernetesRecoveryObservation>,
pub decision: DeliveryRecoveryDecision,
pub issues: Vec<DeliveryRecoveryIssue>,
pub next_actions: Vec<String>,
pub effects: DeliveryEffects,
}Fields
protocol: Stringevidence_id: Stringevidence_digest: Stringscenario_id: Stringcondition: DeliveryFailureConditionstage: DeliveryFailureStagescope: DeliveryRecoveryScopedesired_state: DeliveryStateObservationobserved_state: DeliveryStateObservationretained_config_revision_id: Stringmigration: Option<MigrationRecoveryEvidence>environment_observation: Option<KubernetesRecoveryObservation>decision: DeliveryRecoveryDecisionissues: Vec<DeliveryRecoveryIssue>next_actions: Vec<String>effects: DeliveryEffectsTrait Implementations
Sourceimpl Clone for DeliveryFailureRecoveryEvidence
impl Clone for DeliveryFailureRecoveryEvidence
Sourcefn clone(&self) -> DeliveryFailureRecoveryEvidence
fn clone(&self) -> DeliveryFailureRecoveryEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeliveryFailureRecoveryEvidence
impl ComposeSchema for DeliveryFailureRecoveryEvidence
Sourceimpl<'de> Deserialize<'de> for DeliveryFailureRecoveryEvidence
impl<'de> Deserialize<'de> for DeliveryFailureRecoveryEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeliveryFailureRecoveryEvidence
Sourceimpl JsonSchema for DeliveryFailureRecoveryEvidence
impl JsonSchema for DeliveryFailureRecoveryEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DeliveryFailureRecoveryEvidence