pub struct DeliveryFailureRecoveryInput {Show 13 fields
pub scenario_id: String,
pub condition: DeliveryFailureCondition,
pub stage: DeliveryFailureStage,
pub scope: DeliveryRecoveryScope,
pub desired_state: DeliveryStateObservation,
pub observed_state: DeliveryStateObservation,
pub previous_valid_config_revision_id: String,
pub attempted_config_revision_id: String,
pub active_config_revision_id: String,
pub migration: Option<MigrationRecoveryEvidence>,
pub infrastructure_mutations: Vec<String>,
pub kubernetes: Option<KubernetesRecoveryObservation>,
pub cleanup_complete: bool,
}Fields
scenario_id: Stringcondition: DeliveryFailureConditionstage: DeliveryFailureStagescope: DeliveryRecoveryScopedesired_state: DeliveryStateObservationobserved_state: DeliveryStateObservationprevious_valid_config_revision_id: Stringattempted_config_revision_id: Stringactive_config_revision_id: Stringmigration: Option<MigrationRecoveryEvidence>infrastructure_mutations: Vec<String>kubernetes: Option<KubernetesRecoveryObservation>cleanup_complete: boolTrait Implementations
Sourceimpl Clone for DeliveryFailureRecoveryInput
impl Clone for DeliveryFailureRecoveryInput
Sourcefn clone(&self) -> DeliveryFailureRecoveryInput
fn clone(&self) -> DeliveryFailureRecoveryInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeliveryFailureRecoveryInput
impl ComposeSchema for DeliveryFailureRecoveryInput
Sourceimpl Debug for DeliveryFailureRecoveryInput
impl Debug for DeliveryFailureRecoveryInput
Sourceimpl<'de> Deserialize<'de> for DeliveryFailureRecoveryInput
impl<'de> Deserialize<'de> for DeliveryFailureRecoveryInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeliveryFailureRecoveryInput
Sourceimpl JsonSchema for DeliveryFailureRecoveryInput
impl JsonSchema for DeliveryFailureRecoveryInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DeliveryFailureRecoveryInput