pub struct DeliveryRecoveryIssue {
pub code: DeliveryRecoveryIssueCode,
pub message: String,
pub remediation: String,
pub next_actions: Vec<String>,
}Fields
code: DeliveryRecoveryIssueCodemessage: Stringremediation: Stringnext_actions: Vec<String>Trait Implementations
Sourceimpl Clone for DeliveryRecoveryIssue
impl Clone for DeliveryRecoveryIssue
Sourcefn clone(&self) -> DeliveryRecoveryIssue
fn clone(&self) -> DeliveryRecoveryIssue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeliveryRecoveryIssue
impl ComposeSchema for DeliveryRecoveryIssue
Sourceimpl Debug for DeliveryRecoveryIssue
impl Debug for DeliveryRecoveryIssue
Sourceimpl<'de> Deserialize<'de> for DeliveryRecoveryIssue
impl<'de> Deserialize<'de> for DeliveryRecoveryIssue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeliveryRecoveryIssue
Sourceimpl JsonSchema for DeliveryRecoveryIssue
impl JsonSchema for DeliveryRecoveryIssue
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DeliveryRecoveryIssue
impl PartialEq for DeliveryRecoveryIssue
Sourceimpl Serialize for DeliveryRecoveryIssue
impl Serialize for DeliveryRecoveryIssue
impl StructuralPartialEq for DeliveryRecoveryIssue