pub struct DeliveryReliabilityContract {Show 14 fields
pub protocol: String,
pub contract_id: String,
pub minimum_observation_seconds: u64,
pub minimum_sample_count: u64,
pub minimum_availability_basis_points: u32,
pub maximum_latency_p99_ms: u64,
pub maximum_error_budget_used_basis_points: u32,
pub maximum_queue_backlog: u64,
pub maximum_workflow_backlog: u64,
pub maximum_timer_lag_ms: u64,
pub maximum_retry_exhaustion: u64,
pub maximum_compensation_pressure: u64,
pub minimum_healthy_failure_domains: u32,
pub dependencies: Vec<DependencyReliability>,
}Fields
protocol: Stringcontract_id: Stringminimum_observation_seconds: u64minimum_sample_count: u64minimum_availability_basis_points: u32maximum_latency_p99_ms: u64maximum_error_budget_used_basis_points: u32maximum_queue_backlog: u64maximum_workflow_backlog: u64maximum_timer_lag_ms: u64maximum_retry_exhaustion: u64maximum_compensation_pressure: u64minimum_healthy_failure_domains: u32dependencies: Vec<DependencyReliability>Trait Implementations
Sourceimpl Clone for DeliveryReliabilityContract
impl Clone for DeliveryReliabilityContract
Sourcefn clone(&self) -> DeliveryReliabilityContract
fn clone(&self) -> DeliveryReliabilityContract
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeliveryReliabilityContract
impl ComposeSchema for DeliveryReliabilityContract
Sourceimpl Debug for DeliveryReliabilityContract
impl Debug for DeliveryReliabilityContract
Sourceimpl<'de> Deserialize<'de> for DeliveryReliabilityContract
impl<'de> Deserialize<'de> for DeliveryReliabilityContract
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeliveryReliabilityContract
Sourceimpl JsonSchema for DeliveryReliabilityContract
impl JsonSchema for DeliveryReliabilityContract
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DeliveryReliabilityContract