pub struct DeliveryStateObservation {
pub observation_id: String,
pub source: String,
pub revision: u64,
pub desired_digest: String,
pub observed_digest: String,
pub fresh: bool,
pub drifted: bool,
}Fields
observation_id: Stringsource: Stringrevision: u64desired_digest: Stringobserved_digest: Stringfresh: booldrifted: boolTrait Implementations
Sourceimpl Clone for DeliveryStateObservation
impl Clone for DeliveryStateObservation
Sourcefn clone(&self) -> DeliveryStateObservation
fn clone(&self) -> DeliveryStateObservation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeliveryStateObservation
impl ComposeSchema for DeliveryStateObservation
Sourceimpl Debug for DeliveryStateObservation
impl Debug for DeliveryStateObservation
Sourceimpl<'de> Deserialize<'de> for DeliveryStateObservation
impl<'de> Deserialize<'de> for DeliveryStateObservation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeliveryStateObservation
Sourceimpl JsonSchema for DeliveryStateObservation
impl JsonSchema for DeliveryStateObservation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DeliveryStateObservation
impl PartialEq for DeliveryStateObservation
Sourceimpl Serialize for DeliveryStateObservation
impl Serialize for DeliveryStateObservation
impl StructuralPartialEq for DeliveryStateObservation