pub struct DependencyReliability {
pub dependency_id: String,
pub criticality: DependencyCriticality,
pub allowed_degraded_modes: Vec<String>,
}Fields
dependency_id: Stringcriticality: DependencyCriticalityallowed_degraded_modes: Vec<String>Trait Implementations
Sourceimpl Clone for DependencyReliability
impl Clone for DependencyReliability
Sourcefn clone(&self) -> DependencyReliability
fn clone(&self) -> DependencyReliability
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DependencyReliability
impl ComposeSchema for DependencyReliability
Sourceimpl Debug for DependencyReliability
impl Debug for DependencyReliability
Sourceimpl<'de> Deserialize<'de> for DependencyReliability
impl<'de> Deserialize<'de> for DependencyReliability
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DependencyReliability
Sourceimpl JsonSchema for DependencyReliability
impl JsonSchema for DependencyReliability
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DependencyReliability
impl PartialEq for DependencyReliability
Sourceimpl Serialize for DependencyReliability
impl Serialize for DependencyReliability
impl StructuralPartialEq for DependencyReliability