pub struct DependencyReliabilityObservation {
pub dependency_id: String,
pub available: bool,
pub active_degraded_mode: Option<String>,
}Fields
dependency_id: Stringavailable: boolactive_degraded_mode: Option<String>Trait Implementations
Sourceimpl Clone for DependencyReliabilityObservation
impl Clone for DependencyReliabilityObservation
Sourcefn clone(&self) -> DependencyReliabilityObservation
fn clone(&self) -> DependencyReliabilityObservation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DependencyReliabilityObservation
impl ComposeSchema for DependencyReliabilityObservation
Sourceimpl<'de> Deserialize<'de> for DependencyReliabilityObservation
impl<'de> Deserialize<'de> for DependencyReliabilityObservation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DependencyReliabilityObservation
Sourceimpl JsonSchema for DependencyReliabilityObservation
impl JsonSchema for DependencyReliabilityObservation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DependencyReliabilityObservation