pub struct DeploymentEnvironmentBinding {
pub environment: String,
pub expected_environment_revision: u64,
pub config_revision_id: String,
pub secret_reference_ids: Vec<String>,
pub endpoints: BTreeMap<String, String>,
pub placement: BTreeMap<String, String>,
pub workloads: Vec<DeploymentWorkloadSettings>,
pub adapter_inputs: BTreeMap<String, String>,
pub gateway_plan_digest: String,
pub policy_evidence_references: Vec<String>,
}Fields
environment: Stringexpected_environment_revision: u64config_revision_id: Stringsecret_reference_ids: Vec<String>endpoints: BTreeMap<String, String>placement: BTreeMap<String, String>workloads: Vec<DeploymentWorkloadSettings>adapter_inputs: BTreeMap<String, String>gateway_plan_digest: Stringpolicy_evidence_references: Vec<String>Trait Implementations
Sourceimpl Clone for DeploymentEnvironmentBinding
impl Clone for DeploymentEnvironmentBinding
Sourcefn clone(&self) -> DeploymentEnvironmentBinding
fn clone(&self) -> DeploymentEnvironmentBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeploymentEnvironmentBinding
impl ComposeSchema for DeploymentEnvironmentBinding
Sourceimpl Debug for DeploymentEnvironmentBinding
impl Debug for DeploymentEnvironmentBinding
Sourceimpl<'de> Deserialize<'de> for DeploymentEnvironmentBinding
impl<'de> Deserialize<'de> for DeploymentEnvironmentBinding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeploymentEnvironmentBinding
Sourceimpl JsonSchema for DeploymentEnvironmentBinding
impl JsonSchema for DeploymentEnvironmentBinding
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DeploymentEnvironmentBinding