pub struct DeploymentPlan {Show 20 fields
pub protocol: String,
pub plan_id: String,
pub plan_digest: String,
pub adapter: DeploymentAdapterKind,
pub environment: String,
pub expected_environment_revision: u64,
pub release_id: String,
pub release_digest: String,
pub service_id: String,
pub config_revision_id: String,
pub secret_reference_ids: Vec<String>,
pub endpoints: BTreeMap<String, String>,
pub placement: BTreeMap<String, String>,
pub workloads: Vec<DeploymentWorkloadPlan>,
pub adapter_inputs: BTreeMap<String, String>,
pub gateway_plan_digest: String,
pub policy_evidence_references: Vec<String>,
pub rollback_capable: bool,
pub next_actions: Vec<String>,
pub effects: DeliveryEffects,
}Fields
protocol: Stringplan_id: Stringplan_digest: Stringadapter: DeploymentAdapterKindenvironment: Stringexpected_environment_revision: u64release_id: Stringrelease_digest: Stringservice_id: Stringconfig_revision_id: Stringsecret_reference_ids: Vec<String>endpoints: BTreeMap<String, String>placement: BTreeMap<String, String>workloads: Vec<DeploymentWorkloadPlan>adapter_inputs: BTreeMap<String, String>gateway_plan_digest: Stringpolicy_evidence_references: Vec<String>rollback_capable: boolnext_actions: Vec<String>effects: DeliveryEffectsTrait Implementations
Sourceimpl Clone for DeploymentPlan
impl Clone for DeploymentPlan
Sourcefn clone(&self) -> DeploymentPlan
fn clone(&self) -> DeploymentPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeploymentPlan
impl ComposeSchema for DeploymentPlan
Sourceimpl Debug for DeploymentPlan
impl Debug for DeploymentPlan
Sourceimpl<'de> Deserialize<'de> for DeploymentPlan
impl<'de> Deserialize<'de> for DeploymentPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeploymentPlan
Sourceimpl JsonSchema for DeploymentPlan
impl JsonSchema for DeploymentPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DeploymentPlan
impl PartialEq for DeploymentPlan
Sourceimpl Serialize for DeploymentPlan
impl Serialize for DeploymentPlan
impl StructuralPartialEq for DeploymentPlan