pub struct DeploymentReceipt {Show 13 fields
pub protocol: String,
pub receipt_id: String,
pub plan_id: String,
pub adapter: DeploymentAdapterKind,
pub environment: String,
pub environment_revision_before: u64,
pub environment_revision_after: u64,
pub release_id: String,
pub release_digest: String,
pub config_revision_id: String,
pub workload_digests: BTreeMap<String, String>,
pub gateway_plan_digest: String,
pub effects: DeliveryEffects,
}Fields
protocol: Stringreceipt_id: Stringplan_id: Stringadapter: DeploymentAdapterKindenvironment: Stringenvironment_revision_before: u64environment_revision_after: u64release_id: Stringrelease_digest: Stringconfig_revision_id: Stringworkload_digests: BTreeMap<String, String>gateway_plan_digest: Stringeffects: DeliveryEffectsTrait Implementations
Sourceimpl Clone for DeploymentReceipt
impl Clone for DeploymentReceipt
Sourcefn clone(&self) -> DeploymentReceipt
fn clone(&self) -> DeploymentReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeploymentReceipt
impl ComposeSchema for DeploymentReceipt
Sourceimpl Debug for DeploymentReceipt
impl Debug for DeploymentReceipt
Sourceimpl<'de> Deserialize<'de> for DeploymentReceipt
impl<'de> Deserialize<'de> for DeploymentReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeploymentReceipt
Sourceimpl JsonSchema for DeploymentReceipt
impl JsonSchema for DeploymentReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DeploymentReceipt
impl PartialEq for DeploymentReceipt
Sourceimpl Serialize for DeploymentReceipt
impl Serialize for DeploymentReceipt
impl StructuralPartialEq for DeploymentReceipt