pub struct DeploymentWorkloadPlan {
pub workload_id: String,
pub role: ReleaseWorkloadRole,
pub artifact_reference: String,
pub artifact_digest: String,
pub media_type: String,
pub settings: DeploymentWorkloadSettings,
}Fields
workload_id: Stringrole: ReleaseWorkloadRoleartifact_reference: Stringartifact_digest: Stringmedia_type: Stringsettings: DeploymentWorkloadSettingsTrait Implementations
Sourceimpl Clone for DeploymentWorkloadPlan
impl Clone for DeploymentWorkloadPlan
Sourcefn clone(&self) -> DeploymentWorkloadPlan
fn clone(&self) -> DeploymentWorkloadPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeploymentWorkloadPlan
impl ComposeSchema for DeploymentWorkloadPlan
Sourceimpl Debug for DeploymentWorkloadPlan
impl Debug for DeploymentWorkloadPlan
Sourceimpl<'de> Deserialize<'de> for DeploymentWorkloadPlan
impl<'de> Deserialize<'de> for DeploymentWorkloadPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeploymentWorkloadPlan
Sourceimpl JsonSchema for DeploymentWorkloadPlan
impl JsonSchema for DeploymentWorkloadPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DeploymentWorkloadPlan
impl PartialEq for DeploymentWorkloadPlan
Sourceimpl Serialize for DeploymentWorkloadPlan
impl Serialize for DeploymentWorkloadPlan
impl StructuralPartialEq for DeploymentWorkloadPlan