pub struct DeploymentWorkloadSettings {
pub workload_id: String,
pub replicas: u32,
pub port: Option<u16>,
pub command: Vec<String>,
pub health_path: Option<String>,
pub disruption_min_available: Option<u32>,
}Fields
workload_id: Stringreplicas: u32port: Option<u16>command: Vec<String>health_path: Option<String>disruption_min_available: Option<u32>Trait Implementations
Sourceimpl Clone for DeploymentWorkloadSettings
impl Clone for DeploymentWorkloadSettings
Sourcefn clone(&self) -> DeploymentWorkloadSettings
fn clone(&self) -> DeploymentWorkloadSettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DeploymentWorkloadSettings
impl ComposeSchema for DeploymentWorkloadSettings
Sourceimpl Debug for DeploymentWorkloadSettings
impl Debug for DeploymentWorkloadSettings
Sourceimpl<'de> Deserialize<'de> for DeploymentWorkloadSettings
impl<'de> Deserialize<'de> for DeploymentWorkloadSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeploymentWorkloadSettings
Sourceimpl JsonSchema for DeploymentWorkloadSettings
impl JsonSchema for DeploymentWorkloadSettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DeploymentWorkloadSettings