pub struct DisasterRecoveryApproval {
pub plan_digest: String,
pub phase: DisasterRecoveryPhase,
pub approver: String,
pub reason: String,
pub approved_at_unix_ms: u64,
}Fields
plan_digest: Stringphase: DisasterRecoveryPhaseapprover: Stringreason: Stringapproved_at_unix_ms: u64Trait Implementations
Sourceimpl Clone for DisasterRecoveryApproval
impl Clone for DisasterRecoveryApproval
Sourcefn clone(&self) -> DisasterRecoveryApproval
fn clone(&self) -> DisasterRecoveryApproval
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DisasterRecoveryApproval
impl ComposeSchema for DisasterRecoveryApproval
Sourceimpl Debug for DisasterRecoveryApproval
impl Debug for DisasterRecoveryApproval
Sourceimpl<'de> Deserialize<'de> for DisasterRecoveryApproval
impl<'de> Deserialize<'de> for DisasterRecoveryApproval
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DisasterRecoveryApproval
Sourceimpl JsonSchema for DisasterRecoveryApproval
impl JsonSchema for DisasterRecoveryApproval
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DisasterRecoveryApproval
impl PartialEq for DisasterRecoveryApproval
Sourceimpl Serialize for DisasterRecoveryApproval
impl Serialize for DisasterRecoveryApproval
impl StructuralPartialEq for DisasterRecoveryApproval