pub struct DisasterRecoveryEvidence {Show 19 fields
pub protocol: String,
pub evidence_id: String,
pub evidence_digest: String,
pub plan_id: String,
pub plan_digest: String,
pub phase: DisasterRecoveryPhase,
pub service_id: String,
pub primary_region: String,
pub passive_region: String,
pub observed_rpo_ms: u64,
pub observed_rto_ms: u64,
pub data_loss_bound_ms: u64,
pub replay_bound_count: u64,
pub cleanup_complete: bool,
pub authoritative_environment_count: u32,
pub decision: DisasterRecoveryDecision,
pub issues: Vec<DisasterRecoveryIssue>,
pub approval_boundary: String,
pub failback_steps: Vec<String>,
}Fields
protocol: Stringevidence_id: Stringevidence_digest: Stringplan_id: Stringplan_digest: Stringphase: DisasterRecoveryPhaseservice_id: Stringprimary_region: Stringpassive_region: Stringobserved_rpo_ms: u64observed_rto_ms: u64data_loss_bound_ms: u64replay_bound_count: u64cleanup_complete: booldecision: DisasterRecoveryDecisionissues: Vec<DisasterRecoveryIssue>approval_boundary: Stringfailback_steps: Vec<String>Trait Implementations
Sourceimpl Clone for DisasterRecoveryEvidence
impl Clone for DisasterRecoveryEvidence
Sourcefn clone(&self) -> DisasterRecoveryEvidence
fn clone(&self) -> DisasterRecoveryEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DisasterRecoveryEvidence
impl ComposeSchema for DisasterRecoveryEvidence
Sourceimpl Debug for DisasterRecoveryEvidence
impl Debug for DisasterRecoveryEvidence
Sourceimpl<'de> Deserialize<'de> for DisasterRecoveryEvidence
impl<'de> Deserialize<'de> for DisasterRecoveryEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DisasterRecoveryEvidence
Sourceimpl JsonSchema for DisasterRecoveryEvidence
impl JsonSchema for DisasterRecoveryEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DisasterRecoveryEvidence
impl PartialEq for DisasterRecoveryEvidence
Sourceimpl Serialize for DisasterRecoveryEvidence
impl Serialize for DisasterRecoveryEvidence
impl StructuralPartialEq for DisasterRecoveryEvidence