pub struct DisasterRecoveryIssue {
pub code: DisasterRecoveryIssueCode,
pub message: String,
pub remediation: String,
pub next_actions: Vec<String>,
}Fields
code: DisasterRecoveryIssueCodemessage: Stringremediation: Stringnext_actions: Vec<String>Trait Implementations
Sourceimpl Clone for DisasterRecoveryIssue
impl Clone for DisasterRecoveryIssue
Sourcefn clone(&self) -> DisasterRecoveryIssue
fn clone(&self) -> DisasterRecoveryIssue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DisasterRecoveryIssue
impl ComposeSchema for DisasterRecoveryIssue
Sourceimpl Debug for DisasterRecoveryIssue
impl Debug for DisasterRecoveryIssue
Sourceimpl<'de> Deserialize<'de> for DisasterRecoveryIssue
impl<'de> Deserialize<'de> for DisasterRecoveryIssue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DisasterRecoveryIssue
Sourceimpl JsonSchema for DisasterRecoveryIssue
impl JsonSchema for DisasterRecoveryIssue
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DisasterRecoveryIssue
impl PartialEq for DisasterRecoveryIssue
Sourceimpl Serialize for DisasterRecoveryIssue
impl Serialize for DisasterRecoveryIssue
impl StructuralPartialEq for DisasterRecoveryIssue