pub struct DisasterRecoveryObservation {Show 21 fields
pub plan_digest: String,
pub phase: DisasterRecoveryPhase,
pub observed_at_unix_ms: u64,
pub active_state_digest: String,
pub authoritative_environment_count: u32,
pub primary_fenced: bool,
pub passive_fenced: bool,
pub passive_became_authoritative: bool,
pub primary_became_authoritative: bool,
pub traffic_switched: bool,
pub observed_rpo_ms: u64,
pub observed_rto_ms: u64,
pub release_digest: String,
pub config_revision_digest: String,
pub contract_set_digest: String,
pub workload_identity_preserved: bool,
pub duplicate_business_effects: u64,
pub lost_committed_effects: u64,
pub requests_events_workflows_stories_verified: bool,
pub cleanup_complete: bool,
pub evidence_digest: String,
}Fields
plan_digest: Stringphase: DisasterRecoveryPhaseobserved_at_unix_ms: u64active_state_digest: Stringprimary_fenced: boolpassive_fenced: booltraffic_switched: boolobserved_rpo_ms: u64observed_rto_ms: u64release_digest: Stringconfig_revision_digest: Stringcontract_set_digest: Stringworkload_identity_preserved: boolduplicate_business_effects: u64lost_committed_effects: u64requests_events_workflows_stories_verified: boolcleanup_complete: boolevidence_digest: StringTrait Implementations
Sourceimpl Clone for DisasterRecoveryObservation
impl Clone for DisasterRecoveryObservation
Sourcefn clone(&self) -> DisasterRecoveryObservation
fn clone(&self) -> DisasterRecoveryObservation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DisasterRecoveryObservation
impl ComposeSchema for DisasterRecoveryObservation
Sourceimpl Debug for DisasterRecoveryObservation
impl Debug for DisasterRecoveryObservation
Sourceimpl<'de> Deserialize<'de> for DisasterRecoveryObservation
impl<'de> Deserialize<'de> for DisasterRecoveryObservation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DisasterRecoveryObservation
Sourceimpl JsonSchema for DisasterRecoveryObservation
impl JsonSchema for DisasterRecoveryObservation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DisasterRecoveryObservation