pub struct DisasterRecoveryPlan {
pub protocol: String,
pub plan_id: String,
pub plan_digest: String,
pub input: DisasterRecoveryPlanInput,
pub decision: DisasterRecoveryDecision,
pub issues: Vec<DisasterRecoveryIssue>,
pub approval_boundary: String,
pub effects: Vec<String>,
}Fields
protocol: Stringplan_id: Stringplan_digest: Stringinput: DisasterRecoveryPlanInputdecision: DisasterRecoveryDecisionissues: Vec<DisasterRecoveryIssue>approval_boundary: Stringeffects: Vec<String>Trait Implementations
Sourceimpl Clone for DisasterRecoveryPlan
impl Clone for DisasterRecoveryPlan
Sourcefn clone(&self) -> DisasterRecoveryPlan
fn clone(&self) -> DisasterRecoveryPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DisasterRecoveryPlan
impl ComposeSchema for DisasterRecoveryPlan
Sourceimpl Debug for DisasterRecoveryPlan
impl Debug for DisasterRecoveryPlan
Sourceimpl<'de> Deserialize<'de> for DisasterRecoveryPlan
impl<'de> Deserialize<'de> for DisasterRecoveryPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DisasterRecoveryPlan
Sourceimpl JsonSchema for DisasterRecoveryPlan
impl JsonSchema for DisasterRecoveryPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DisasterRecoveryPlan
impl PartialEq for DisasterRecoveryPlan
Sourceimpl Serialize for DisasterRecoveryPlan
impl Serialize for DisasterRecoveryPlan
impl StructuralPartialEq for DisasterRecoveryPlan