pub struct DisasterRecoveryPlanInput {Show 20 fields
pub phase: DisasterRecoveryPhase,
pub service_id: String,
pub primary_region: String,
pub passive_region: String,
pub restore_evidence: ServiceRestoreEvidence,
pub expected_release_digest: String,
pub expected_config_revision_digest: String,
pub expected_contract_set_digest: String,
pub expected_active_state_digest: String,
pub authoritative_environment_count_before: u32,
pub planned_at_unix_ms: u64,
pub freshness_horizon_unix_ms: u64,
pub rpo_budget_ms: u64,
pub rto_budget_ms: u64,
pub primary_fenced: bool,
pub passive_fenced: bool,
pub passive_health_verified: bool,
pub passive_identity_verified: bool,
pub passive_contracts_verified: bool,
pub failback_steps: Vec<String>,
}Fields
phase: DisasterRecoveryPhaseservice_id: Stringprimary_region: Stringpassive_region: Stringrestore_evidence: ServiceRestoreEvidenceexpected_release_digest: Stringexpected_config_revision_digest: Stringexpected_contract_set_digest: Stringexpected_active_state_digest: Stringplanned_at_unix_ms: u64freshness_horizon_unix_ms: u64rpo_budget_ms: u64rto_budget_ms: u64primary_fenced: boolpassive_fenced: boolpassive_health_verified: boolpassive_identity_verified: boolpassive_contracts_verified: boolfailback_steps: Vec<String>Trait Implementations
Sourceimpl Clone for DisasterRecoveryPlanInput
impl Clone for DisasterRecoveryPlanInput
Sourcefn clone(&self) -> DisasterRecoveryPlanInput
fn clone(&self) -> DisasterRecoveryPlanInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DisasterRecoveryPlanInput
impl ComposeSchema for DisasterRecoveryPlanInput
Sourceimpl Debug for DisasterRecoveryPlanInput
impl Debug for DisasterRecoveryPlanInput
Sourceimpl<'de> Deserialize<'de> for DisasterRecoveryPlanInput
impl<'de> Deserialize<'de> for DisasterRecoveryPlanInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DisasterRecoveryPlanInput
Sourceimpl JsonSchema for DisasterRecoveryPlanInput
impl JsonSchema for DisasterRecoveryPlanInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for DisasterRecoveryPlanInput