pub struct DocumentationIdentity {
pub version: String,
pub digest: String,
}Fields
version: Stringdigest: StringTrait Implementations
Sourceimpl Clone for DocumentationIdentity
impl Clone for DocumentationIdentity
Sourcefn clone(&self) -> DocumentationIdentity
fn clone(&self) -> DocumentationIdentity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DocumentationIdentity
impl ComposeSchema for DocumentationIdentity
Sourceimpl Debug for DocumentationIdentity
impl Debug for DocumentationIdentity
Sourceimpl<'de> Deserialize<'de> for DocumentationIdentity
impl<'de> Deserialize<'de> for DocumentationIdentity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DocumentationIdentity
Sourceimpl JsonSchema for DocumentationIdentity
impl JsonSchema for DocumentationIdentity
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DocumentationIdentity
impl PartialEq for DocumentationIdentity
Sourceimpl Serialize for DocumentationIdentity
impl Serialize for DocumentationIdentity
impl StructuralPartialEq for DocumentationIdentity