pub struct EdgeRoute {
pub contract_id: String,
pub contract_version: String,
pub operation_id: String,
pub public_path: String,
pub authentication: EdgeAuthentication,
pub cors: CorsIntent,
pub rate: RateIntent,
pub deprecated: bool,
}Fields
contract_id: Stringcontract_version: Stringoperation_id: Stringpublic_path: Stringauthentication: EdgeAuthenticationcors: CorsIntentrate: RateIntentdeprecated: boolTrait Implementations
Sourceimpl<'de> Deserialize<'de> for EdgeRoute
impl<'de> Deserialize<'de> for EdgeRoute
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EdgeRoute
Sourceimpl JsonSchema for EdgeRoute
impl JsonSchema for EdgeRoute
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for EdgeRoute