pub struct EnvironmentVerification {Show 40 fields
pub protocol: String,
pub verification_id: String,
pub verification_digest: String,
pub environment: String,
pub environment_revision: u64,
pub release_id: String,
pub release_digest: String,
pub workload_digests: BTreeMap<String, String>,
pub workload_health: BTreeMap<String, bool>,
pub config_revision_id: String,
pub trust_evidence_digest: String,
pub policy_evidence_id: String,
pub policy_evidence_digest: String,
pub deployment_plan_id: String,
pub deployment_plan_digest: String,
pub deployment_receipt_id: String,
pub deployment_observation_id: String,
pub operator_observation_id: String,
pub operator_observation_digest: String,
pub operator_observation_authority_id: String,
pub operator_observation_authority_proof: String,
pub operator_observation_claims: OperatorObservationClaims,
pub gateway_plan_id: String,
pub gateway_plan_digest: String,
pub gateway_observation_id: String,
pub gateway_resource_uid: String,
pub gateway_resource_version: String,
pub gateway_authority_context: String,
pub gateway_configuration_identity: String,
pub gateway_observation_revision: u64,
pub gateway_observation_observed_after: String,
pub gateway_observation_fresh: bool,
pub gateway_observation_provider_id: String,
pub gateway_observation_provider_proof: String,
pub topology_digest: String,
pub evidence_references: Vec<String>,
pub freshness_horizon_revision: u64,
pub decision: DeliveryDecision,
pub issues: Vec<DeliveryIssue>,
pub effects: DeliveryEffects,
}Fields
protocol: Stringverification_id: Stringverification_digest: Stringenvironment: Stringenvironment_revision: u64release_id: Stringrelease_digest: Stringworkload_digests: BTreeMap<String, String>workload_health: BTreeMap<String, bool>config_revision_id: Stringtrust_evidence_digest: Stringpolicy_evidence_id: Stringpolicy_evidence_digest: Stringdeployment_plan_id: Stringdeployment_plan_digest: Stringdeployment_receipt_id: Stringdeployment_observation_id: Stringoperator_observation_id: Stringoperator_observation_digest: Stringoperator_observation_claims: OperatorObservationClaimsgateway_plan_id: Stringgateway_plan_digest: Stringgateway_observation_id: Stringgateway_resource_uid: Stringgateway_resource_version: Stringgateway_configuration_identity: Stringgateway_observation_revision: u64gateway_observation_observed_after: Stringgateway_observation_fresh: boolgateway_observation_provider_id: Stringgateway_observation_provider_proof: Stringtopology_digest: Stringevidence_references: Vec<String>freshness_horizon_revision: u64decision: DeliveryDecisionissues: Vec<DeliveryIssue>effects: DeliveryEffectsTrait Implementations
Sourceimpl Clone for EnvironmentVerification
impl Clone for EnvironmentVerification
Sourcefn clone(&self) -> EnvironmentVerification
fn clone(&self) -> EnvironmentVerification
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for EnvironmentVerification
impl ComposeSchema for EnvironmentVerification
Sourceimpl Debug for EnvironmentVerification
impl Debug for EnvironmentVerification
Sourceimpl<'de> Deserialize<'de> for EnvironmentVerification
impl<'de> Deserialize<'de> for EnvironmentVerification
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EnvironmentVerification
Sourceimpl JsonSchema for EnvironmentVerification
impl JsonSchema for EnvironmentVerification
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EnvironmentVerification
impl PartialEq for EnvironmentVerification
Sourceimpl Serialize for EnvironmentVerification
impl Serialize for EnvironmentVerification
impl StructuralPartialEq for EnvironmentVerification