pub struct EvidenceReceiptTrust {
pub authorities: BTreeMap<String, String>,
pub public_keys: BTreeMap<String, String>,
}Fields
public_keys: BTreeMap<String, String>Trait Implementations
Sourceimpl Clone for EvidenceReceiptTrust
impl Clone for EvidenceReceiptTrust
Sourcefn clone(&self) -> EvidenceReceiptTrust
fn clone(&self) -> EvidenceReceiptTrust
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for EvidenceReceiptTrust
impl ComposeSchema for EvidenceReceiptTrust
Sourceimpl Debug for EvidenceReceiptTrust
impl Debug for EvidenceReceiptTrust
Sourceimpl Default for EvidenceReceiptTrust
impl Default for EvidenceReceiptTrust
Sourcefn default() -> EvidenceReceiptTrust
fn default() -> EvidenceReceiptTrust
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for EvidenceReceiptTrust
impl<'de> Deserialize<'de> for EvidenceReceiptTrust
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EvidenceReceiptTrust
Sourceimpl JsonSchema for EvidenceReceiptTrust
impl JsonSchema for EvidenceReceiptTrust
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EvidenceReceiptTrust
impl PartialEq for EvidenceReceiptTrust
Sourceimpl Serialize for EvidenceReceiptTrust
impl Serialize for EvidenceReceiptTrust
impl StructuralPartialEq for EvidenceReceiptTrust