pub struct ExtractionAuthorityCommitInputs {
pub cutover: ExtractionProvisionalCutoverRun,
pub approval: ExtractionApproval,
pub current_authority_revision: String,
pub current_routing_revision: String,
pub current_system_graph_revision: String,
pub revalidation: ExtractionAuthorityCommitRevalidation,
}Fields
cutover: ExtractionProvisionalCutoverRunapproval: ExtractionApprovalcurrent_routing_revision: Stringcurrent_system_graph_revision: Stringrevalidation: ExtractionAuthorityCommitRevalidationTrait Implementations
Sourceimpl Clone for ExtractionAuthorityCommitInputs
impl Clone for ExtractionAuthorityCommitInputs
Sourcefn clone(&self) -> ExtractionAuthorityCommitInputs
fn clone(&self) -> ExtractionAuthorityCommitInputs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ExtractionAuthorityCommitInputs
impl<'de> Deserialize<'de> for ExtractionAuthorityCommitInputs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionAuthorityCommitInputs
Sourceimpl JsonSchema for ExtractionAuthorityCommitInputs
impl JsonSchema for ExtractionAuthorityCommitInputs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionAuthorityCommitInputs