pub struct ExtractionAuthorityCommitReceipt {
pub receipt_id: String,
pub receipt_digest: String,
pub expected_authority_revision: String,
pub expected_routing_revision: String,
pub expected_system_graph_revision: String,
pub committed_authority_revision: String,
pub committed_routing_revision: String,
pub committed_system_graph_revision: String,
pub candidate_service_id: String,
pub outcome: String,
}Fields
receipt_id: Stringreceipt_digest: Stringexpected_routing_revision: Stringexpected_system_graph_revision: Stringcommitted_routing_revision: Stringcommitted_system_graph_revision: Stringcandidate_service_id: Stringoutcome: StringTrait Implementations
Sourceimpl Clone for ExtractionAuthorityCommitReceipt
impl Clone for ExtractionAuthorityCommitReceipt
Sourcefn clone(&self) -> ExtractionAuthorityCommitReceipt
fn clone(&self) -> ExtractionAuthorityCommitReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ExtractionAuthorityCommitReceipt
impl<'de> Deserialize<'de> for ExtractionAuthorityCommitReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionAuthorityCommitReceipt
Sourceimpl JsonSchema for ExtractionAuthorityCommitReceipt
impl JsonSchema for ExtractionAuthorityCommitReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionAuthorityCommitReceipt