pub struct ExtractionAuthorityCommitResult {Show 20 fields
pub protocol: String,
pub commit_id: String,
pub commit_digest: String,
pub status: ExtractionAuthorityCommitStatus,
pub plan_digest: String,
pub approval: ExtractionApproval,
pub authority_revision: String,
pub routing_revision: String,
pub system_graph_revision: String,
pub candidate_service_id: String,
pub candidate_authoritative: bool,
pub linked_authoritative: bool,
pub candidate_mutations_open: bool,
pub linked_recovery_read_only: bool,
pub source_cleanup_performed: bool,
pub autonomous_mutation_ids: Vec<String>,
pub fast_rollback_blocked: bool,
pub business_execution_requires_runtime_console: bool,
pub business_execution_requires_system_plane: bool,
pub commit_receipts: Vec<ExtractionAuthorityCommitReceipt>,
}Fields
protocol: Stringcommit_id: Stringcommit_digest: Stringstatus: ExtractionAuthorityCommitStatusplan_digest: Stringapproval: ExtractionApprovalrouting_revision: Stringsystem_graph_revision: Stringcandidate_service_id: Stringcandidate_mutations_open: boollinked_recovery_read_only: boolsource_cleanup_performed: boolautonomous_mutation_ids: Vec<String>fast_rollback_blocked: boolbusiness_execution_requires_runtime_console: boolbusiness_execution_requires_system_plane: boolcommit_receipts: Vec<ExtractionAuthorityCommitReceipt>Trait Implementations
Sourceimpl Clone for ExtractionAuthorityCommitResult
impl Clone for ExtractionAuthorityCommitResult
Sourcefn clone(&self) -> ExtractionAuthorityCommitResult
fn clone(&self) -> ExtractionAuthorityCommitResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ExtractionAuthorityCommitResult
impl<'de> Deserialize<'de> for ExtractionAuthorityCommitResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionAuthorityCommitResult
Sourceimpl JsonSchema for ExtractionAuthorityCommitResult
impl JsonSchema for ExtractionAuthorityCommitResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionAuthorityCommitResult