pub struct ExtractionAuthorityCommitRevalidation {
pub reconciliation: ExtractionReconciliationResult,
pub verification: ExtractionVerificationResult,
pub quiescence: ExtractionQuiescenceRun,
pub candidate_health: ExtractionCandidateHealthEvidence,
}Fields
reconciliation: ExtractionReconciliationResultverification: ExtractionVerificationResultquiescence: ExtractionQuiescenceRuncandidate_health: ExtractionCandidateHealthEvidenceTrait Implementations
Sourceimpl Clone for ExtractionAuthorityCommitRevalidation
impl Clone for ExtractionAuthorityCommitRevalidation
Sourcefn clone(&self) -> ExtractionAuthorityCommitRevalidation
fn clone(&self) -> ExtractionAuthorityCommitRevalidation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ExtractionAuthorityCommitRevalidation
impl<'de> Deserialize<'de> for ExtractionAuthorityCommitRevalidation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionAuthorityCommitRevalidation
Sourceimpl JsonSchema for ExtractionAuthorityCommitRevalidation
impl JsonSchema for ExtractionAuthorityCommitRevalidation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionAuthorityCommitRevalidation