pub struct ExtractionBackfillBatchReceipt {
pub batch_id: String,
pub batch_digest: String,
pub previous_destination_checkpoint: Option<String>,
pub destination_checkpoint: String,
pub first_stable_id: Option<String>,
pub last_stable_id: Option<String>,
pub copied_count: u64,
pub duplicate_count: u64,
pub source_high_water_mark: String,
pub source_authority_unchanged: bool,
pub candidate_authoritative: bool,
}Fields
batch_id: Stringbatch_digest: Stringprevious_destination_checkpoint: Option<String>destination_checkpoint: Stringfirst_stable_id: Option<String>last_stable_id: Option<String>copied_count: u64duplicate_count: u64source_high_water_mark: StringTrait Implementations
Sourceimpl Clone for ExtractionBackfillBatchReceipt
impl Clone for ExtractionBackfillBatchReceipt
Sourcefn clone(&self) -> ExtractionBackfillBatchReceipt
fn clone(&self) -> ExtractionBackfillBatchReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ExtractionBackfillBatchReceipt
impl<'de> Deserialize<'de> for ExtractionBackfillBatchReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionBackfillBatchReceipt
Sourceimpl JsonSchema for ExtractionBackfillBatchReceipt
impl JsonSchema for ExtractionBackfillBatchReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionBackfillBatchReceipt