pub struct ExtractionBackfillEffects {
pub reads_plan_scoped_source_data: bool,
pub copies_destination_data: bool,
pub mutates_source_data: bool,
pub changes_authority: bool,
pub emits_business_effects: bool,
}Fields
reads_plan_scoped_source_data: boolcopies_destination_data: boolmutates_source_data: boolemits_business_effects: boolTrait Implementations
Sourceimpl Clone for ExtractionBackfillEffects
impl Clone for ExtractionBackfillEffects
Sourcefn clone(&self) -> ExtractionBackfillEffects
fn clone(&self) -> ExtractionBackfillEffects
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ExtractionBackfillEffects
Sourceimpl Debug for ExtractionBackfillEffects
impl Debug for ExtractionBackfillEffects
Sourceimpl Default for ExtractionBackfillEffects
impl Default for ExtractionBackfillEffects
Sourcefn default() -> ExtractionBackfillEffects
fn default() -> ExtractionBackfillEffects
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ExtractionBackfillEffects
impl<'de> Deserialize<'de> for ExtractionBackfillEffects
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionBackfillEffects
Sourceimpl JsonSchema for ExtractionBackfillEffects
impl JsonSchema for ExtractionBackfillEffects
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionBackfillEffects