pub struct ExtractionBackfillError {
pub code: ExtractionBackfillErrorCode,
pub message: String,
pub next_actions: Vec<String>,
}Fields
code: ExtractionBackfillErrorCodemessage: Stringnext_actions: Vec<String>Trait Implementations
Sourceimpl Clone for ExtractionBackfillError
impl Clone for ExtractionBackfillError
Sourcefn clone(&self) -> ExtractionBackfillError
fn clone(&self) -> ExtractionBackfillError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionBackfillError
impl Debug for ExtractionBackfillError
Sourceimpl<'de> Deserialize<'de> for ExtractionBackfillError
impl<'de> Deserialize<'de> for ExtractionBackfillError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ExtractionBackfillError
impl Display for ExtractionBackfillError
impl Eq for ExtractionBackfillError
Sourceimpl Error for ExtractionBackfillError
impl Error for ExtractionBackfillError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl JsonSchema for ExtractionBackfillError
impl JsonSchema for ExtractionBackfillError
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionBackfillError
impl PartialEq for ExtractionBackfillError
Sourceimpl Serialize for ExtractionBackfillError
impl Serialize for ExtractionBackfillError
impl StructuralPartialEq for ExtractionBackfillError