pub struct ExtractionBackfillEvidence {
pub kind: String,
pub subject: String,
pub digest: String,
pub detail: String,
}Fields
kind: Stringsubject: Stringdigest: Stringdetail: StringTrait Implementations
Sourceimpl Clone for ExtractionBackfillEvidence
impl Clone for ExtractionBackfillEvidence
Sourcefn clone(&self) -> ExtractionBackfillEvidence
fn clone(&self) -> ExtractionBackfillEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionBackfillEvidence
impl Debug for ExtractionBackfillEvidence
Sourceimpl<'de> Deserialize<'de> for ExtractionBackfillEvidence
impl<'de> Deserialize<'de> for ExtractionBackfillEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionBackfillEvidence
Sourceimpl JsonSchema for ExtractionBackfillEvidence
impl JsonSchema for ExtractionBackfillEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionBackfillEvidence