pub struct ExtractionBackfillProgress {
pub copied_count: u64,
pub remaining_lag: u64,
pub source_high_water_mark: String,
pub destination_checkpoint: Option<String>,
pub next_after_stable_id: Option<String>,
}Fields
copied_count: u64remaining_lag: u64source_high_water_mark: Stringdestination_checkpoint: Option<String>next_after_stable_id: Option<String>Trait Implementations
Sourceimpl Clone for ExtractionBackfillProgress
impl Clone for ExtractionBackfillProgress
Sourcefn clone(&self) -> ExtractionBackfillProgress
fn clone(&self) -> ExtractionBackfillProgress
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionBackfillProgress
impl Debug for ExtractionBackfillProgress
Sourceimpl<'de> Deserialize<'de> for ExtractionBackfillProgress
impl<'de> Deserialize<'de> for ExtractionBackfillProgress
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionBackfillProgress
Sourceimpl JsonSchema for ExtractionBackfillProgress
impl JsonSchema for ExtractionBackfillProgress
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionBackfillProgress