pub struct ExtractionBackfillRun {Show 15 fields
pub protocol: String,
pub run_id: String,
pub run_digest: String,
pub revision: u64,
pub status: ExtractionBackfillStatus,
pub scope: ExtractionBackfillScope,
pub boundary: ExtractionBackfillBoundary,
pub progress: ExtractionBackfillProgress,
pub destination_records: Vec<ExtractionBackfillRecord>,
pub receipts: Vec<ExtractionBackfillBatchReceipt>,
pub evidence: Vec<ExtractionBackfillEvidence>,
pub next_actions: Vec<String>,
pub linked_authority_remains_authoritative: bool,
pub candidate_authoritative: bool,
pub effects: ExtractionBackfillEffects,
}Fields
protocol: Stringrun_id: Stringrun_digest: Stringrevision: u64status: ExtractionBackfillStatusscope: ExtractionBackfillScopeboundary: ExtractionBackfillBoundaryprogress: ExtractionBackfillProgressdestination_records: Vec<ExtractionBackfillRecord>receipts: Vec<ExtractionBackfillBatchReceipt>evidence: Vec<ExtractionBackfillEvidence>next_actions: Vec<String>effects: ExtractionBackfillEffectsTrait Implementations
Sourceimpl Clone for ExtractionBackfillRun
impl Clone for ExtractionBackfillRun
Sourcefn clone(&self) -> ExtractionBackfillRun
fn clone(&self) -> ExtractionBackfillRun
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionBackfillRun
impl Debug for ExtractionBackfillRun
Sourceimpl<'de> Deserialize<'de> for ExtractionBackfillRun
impl<'de> Deserialize<'de> for ExtractionBackfillRun
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionBackfillRun
Sourceimpl JsonSchema for ExtractionBackfillRun
impl JsonSchema for ExtractionBackfillRun
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionBackfillRun
impl PartialEq for ExtractionBackfillRun
Sourceimpl Serialize for ExtractionBackfillRun
impl Serialize for ExtractionBackfillRun
impl StructuralPartialEq for ExtractionBackfillRun