pub struct ExtractionBackfillScope {
pub plan_id: String,
pub plan_digest: String,
pub source_owner_id: String,
pub source_store_id: String,
pub destination_store_id: String,
pub table_mappings: Vec<String>,
}Fields
plan_id: Stringplan_digest: Stringsource_owner_id: Stringsource_store_id: Stringdestination_store_id: Stringtable_mappings: Vec<String>Trait Implementations
Sourceimpl Clone for ExtractionBackfillScope
impl Clone for ExtractionBackfillScope
Sourcefn clone(&self) -> ExtractionBackfillScope
fn clone(&self) -> ExtractionBackfillScope
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionBackfillScope
impl Debug for ExtractionBackfillScope
Sourceimpl<'de> Deserialize<'de> for ExtractionBackfillScope
impl<'de> Deserialize<'de> for ExtractionBackfillScope
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionBackfillScope
Sourceimpl JsonSchema for ExtractionBackfillScope
impl JsonSchema for ExtractionBackfillScope
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionBackfillScope
impl PartialEq for ExtractionBackfillScope
Sourceimpl Serialize for ExtractionBackfillScope
impl Serialize for ExtractionBackfillScope
impl StructuralPartialEq for ExtractionBackfillScope