pub struct ExtractionBehaviorObservation {
pub implementation: String,
pub module_id: String,
pub operation_id: String,
pub tenant_id: String,
pub actor_id: String,
pub response: Value,
pub durable_state: Value,
pub event_effects: Vec<String>,
pub workflow_outcomes: Vec<String>,
pub story_evidence: Vec<String>,
}Fields
implementation: Stringmodule_id: Stringoperation_id: Stringtenant_id: Stringactor_id: Stringresponse: Valuedurable_state: Valueevent_effects: Vec<String>workflow_outcomes: Vec<String>story_evidence: Vec<String>Trait Implementations
Sourceimpl Clone for ExtractionBehaviorObservation
impl Clone for ExtractionBehaviorObservation
Sourcefn clone(&self) -> ExtractionBehaviorObservation
fn clone(&self) -> ExtractionBehaviorObservation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ExtractionBehaviorObservation
impl<'de> Deserialize<'de> for ExtractionBehaviorObservation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionBehaviorObservation
Sourceimpl JsonSchema for ExtractionBehaviorObservation
impl JsonSchema for ExtractionBehaviorObservation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionBehaviorObservation