pub struct ExtractionConsoleApprovalBoundary {
pub boundary_id: String,
pub phase_id: String,
pub action: String,
pub reason: String,
pub required_pins: Vec<String>,
}Fields
boundary_id: Stringphase_id: Stringaction: Stringreason: Stringrequired_pins: Vec<String>Trait Implementations
Sourceimpl Clone for ExtractionConsoleApprovalBoundary
impl Clone for ExtractionConsoleApprovalBoundary
Sourcefn clone(&self) -> ExtractionConsoleApprovalBoundary
fn clone(&self) -> ExtractionConsoleApprovalBoundary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ExtractionConsoleApprovalBoundary
impl ComposeSchema for ExtractionConsoleApprovalBoundary
Sourceimpl<'de> Deserialize<'de> for ExtractionConsoleApprovalBoundary
impl<'de> Deserialize<'de> for ExtractionConsoleApprovalBoundary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionConsoleApprovalBoundary
Sourceimpl JsonSchema for ExtractionConsoleApprovalBoundary
impl JsonSchema for ExtractionConsoleApprovalBoundary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionConsoleApprovalBoundary