pub struct ExtractionConsoleArtifacts {
pub readiness: Option<Value>,
pub plan: Option<Value>,
pub phase_artifacts: Vec<Value>,
pub authority: Option<Value>,
}Fields
readiness: Option<Value>plan: Option<Value>phase_artifacts: Vec<Value>Trait Implementations
Sourceimpl Clone for ExtractionConsoleArtifacts
impl Clone for ExtractionConsoleArtifacts
Sourcefn clone(&self) -> ExtractionConsoleArtifacts
fn clone(&self) -> ExtractionConsoleArtifacts
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ExtractionConsoleArtifacts
impl ComposeSchema for ExtractionConsoleArtifacts
Sourceimpl Debug for ExtractionConsoleArtifacts
impl Debug for ExtractionConsoleArtifacts
Sourceimpl<'de> Deserialize<'de> for ExtractionConsoleArtifacts
impl<'de> Deserialize<'de> for ExtractionConsoleArtifacts
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionConsoleArtifacts
Sourceimpl JsonSchema for ExtractionConsoleArtifacts
impl JsonSchema for ExtractionConsoleArtifacts
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionConsoleArtifacts