pub struct ExtractionConsoleAuthority {
pub kind: String,
pub owner_id: String,
pub revision: String,
}Fields
kind: Stringowner_id: Stringrevision: StringTrait Implementations
Sourceimpl Clone for ExtractionConsoleAuthority
impl Clone for ExtractionConsoleAuthority
Sourcefn clone(&self) -> ExtractionConsoleAuthority
fn clone(&self) -> ExtractionConsoleAuthority
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ExtractionConsoleAuthority
impl ComposeSchema for ExtractionConsoleAuthority
Sourceimpl Debug for ExtractionConsoleAuthority
impl Debug for ExtractionConsoleAuthority
Sourceimpl Default for ExtractionConsoleAuthority
impl Default for ExtractionConsoleAuthority
Sourceimpl<'de> Deserialize<'de> for ExtractionConsoleAuthority
impl<'de> Deserialize<'de> for ExtractionConsoleAuthority
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionConsoleAuthority
Sourceimpl JsonSchema for ExtractionConsoleAuthority
impl JsonSchema for ExtractionConsoleAuthority
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionConsoleAuthority