pub struct ExtractionConsoleBlocker {
pub code: String,
pub subject: String,
pub detail: String,
pub next_actions: Vec<String>,
pub artifact_id: String,
}Fields
code: Stringsubject: Stringdetail: Stringnext_actions: Vec<String>artifact_id: StringTrait Implementations
Sourceimpl Clone for ExtractionConsoleBlocker
impl Clone for ExtractionConsoleBlocker
Sourcefn clone(&self) -> ExtractionConsoleBlocker
fn clone(&self) -> ExtractionConsoleBlocker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ExtractionConsoleBlocker
impl ComposeSchema for ExtractionConsoleBlocker
Sourceimpl Debug for ExtractionConsoleBlocker
impl Debug for ExtractionConsoleBlocker
Sourceimpl<'de> Deserialize<'de> for ExtractionConsoleBlocker
impl<'de> Deserialize<'de> for ExtractionConsoleBlocker
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionConsoleBlocker
Sourceimpl JsonSchema for ExtractionConsoleBlocker
impl JsonSchema for ExtractionConsoleBlocker
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionConsoleBlocker
impl Ord for ExtractionConsoleBlocker
Sourcefn cmp(&self, other: &ExtractionConsoleBlocker) -> Ordering
fn cmp(&self, other: &ExtractionConsoleBlocker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ExtractionConsoleBlocker
impl PartialEq for ExtractionConsoleBlocker
Sourceimpl PartialOrd for ExtractionConsoleBlocker
impl PartialOrd for ExtractionConsoleBlocker
Sourceimpl Serialize for ExtractionConsoleBlocker
impl Serialize for ExtractionConsoleBlocker
impl StructuralPartialEq for ExtractionConsoleBlocker