pub struct ExtractionConsoleEvidence {
pub kind: String,
pub subject: String,
pub digest: String,
pub detail: String,
pub artifact_id: String,
}Fields
kind: Stringsubject: Stringdigest: Stringdetail: Stringartifact_id: StringTrait Implementations
Sourceimpl Clone for ExtractionConsoleEvidence
impl Clone for ExtractionConsoleEvidence
Sourcefn clone(&self) -> ExtractionConsoleEvidence
fn clone(&self) -> ExtractionConsoleEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ExtractionConsoleEvidence
impl ComposeSchema for ExtractionConsoleEvidence
Sourceimpl Debug for ExtractionConsoleEvidence
impl Debug for ExtractionConsoleEvidence
Sourceimpl<'de> Deserialize<'de> for ExtractionConsoleEvidence
impl<'de> Deserialize<'de> for ExtractionConsoleEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionConsoleEvidence
Sourceimpl JsonSchema for ExtractionConsoleEvidence
impl JsonSchema for ExtractionConsoleEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionConsoleEvidence
impl Ord for ExtractionConsoleEvidence
Sourcefn cmp(&self, other: &ExtractionConsoleEvidence) -> Ordering
fn cmp(&self, other: &ExtractionConsoleEvidence) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ExtractionConsoleEvidence
impl PartialOrd for ExtractionConsoleEvidence
impl StructuralPartialEq for ExtractionConsoleEvidence