pub struct ExtractionConsoleProjection {Show 14 fields
pub protocol: String,
pub projection_digest: String,
pub state: ExtractionConsoleState,
pub plan_id: Option<String>,
pub plan_digest: Option<String>,
pub readiness_summary: String,
pub current_authority: ExtractionConsoleAuthority,
pub timeline: Vec<ExtractionConsoleTimelineEntry>,
pub blockers: Vec<ExtractionConsoleBlocker>,
pub evidence: Vec<ExtractionConsoleEvidence>,
pub approval_boundaries: Vec<ExtractionConsoleApprovalBoundary>,
pub read_only: bool,
pub apply_actions: Vec<String>,
pub protected_workflow: String,
}Fields
protocol: Stringprojection_digest: Stringstate: ExtractionConsoleStateplan_id: Option<String>plan_digest: Option<String>readiness_summary: Stringtimeline: Vec<ExtractionConsoleTimelineEntry>blockers: Vec<ExtractionConsoleBlocker>evidence: Vec<ExtractionConsoleEvidence>approval_boundaries: Vec<ExtractionConsoleApprovalBoundary>read_only: boolapply_actions: Vec<String>protected_workflow: StringTrait Implementations
Sourceimpl Clone for ExtractionConsoleProjection
impl Clone for ExtractionConsoleProjection
Sourcefn clone(&self) -> ExtractionConsoleProjection
fn clone(&self) -> ExtractionConsoleProjection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ExtractionConsoleProjection
impl ComposeSchema for ExtractionConsoleProjection
Sourceimpl Debug for ExtractionConsoleProjection
impl Debug for ExtractionConsoleProjection
Sourceimpl<'de> Deserialize<'de> for ExtractionConsoleProjection
impl<'de> Deserialize<'de> for ExtractionConsoleProjection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionConsoleProjection
Sourceimpl JsonSchema for ExtractionConsoleProjection
impl JsonSchema for ExtractionConsoleProjection
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionConsoleProjection