pub struct ExtractionConsoleTimelineEntry {
pub phase_id: String,
pub kind: String,
pub state: String,
pub artifact_id: String,
pub blockers: Vec<ExtractionConsoleBlocker>,
pub evidence: Vec<ExtractionConsoleEvidence>,
}Fields
phase_id: Stringkind: Stringstate: Stringartifact_id: Stringblockers: Vec<ExtractionConsoleBlocker>evidence: Vec<ExtractionConsoleEvidence>Trait Implementations
Sourceimpl Clone for ExtractionConsoleTimelineEntry
impl Clone for ExtractionConsoleTimelineEntry
Sourcefn clone(&self) -> ExtractionConsoleTimelineEntry
fn clone(&self) -> ExtractionConsoleTimelineEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ExtractionConsoleTimelineEntry
impl ComposeSchema for ExtractionConsoleTimelineEntry
Sourceimpl<'de> Deserialize<'de> for ExtractionConsoleTimelineEntry
impl<'de> Deserialize<'de> for ExtractionConsoleTimelineEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionConsoleTimelineEntry
Sourceimpl JsonSchema for ExtractionConsoleTimelineEntry
impl JsonSchema for ExtractionConsoleTimelineEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionConsoleTimelineEntry