pub struct ExtractionConsumerCompatibilityEvidence {
pub consumer_id: String,
pub contract_id: String,
pub classification: CompatibilityCategory,
pub evidence_references: Vec<String>,
pub next_action: String,
}Fields
consumer_id: Stringcontract_id: Stringclassification: CompatibilityCategoryevidence_references: Vec<String>next_action: StringTrait Implementations
Sourceimpl Clone for ExtractionConsumerCompatibilityEvidence
impl Clone for ExtractionConsumerCompatibilityEvidence
Sourcefn clone(&self) -> ExtractionConsumerCompatibilityEvidence
fn clone(&self) -> ExtractionConsumerCompatibilityEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ExtractionConsumerCompatibilityEvidence
impl<'de> Deserialize<'de> for ExtractionConsumerCompatibilityEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionConsumerCompatibilityEvidence
Sourceimpl JsonSchema for ExtractionConsumerCompatibilityEvidence
impl JsonSchema for ExtractionConsumerCompatibilityEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionConsumerCompatibilityEvidence
impl Ord for ExtractionConsumerCompatibilityEvidence
Sourcefn cmp(&self, other: &ExtractionConsumerCompatibilityEvidence) -> Ordering
fn cmp(&self, other: &ExtractionConsumerCompatibilityEvidence) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ExtractionConsumerCompatibilityEvidence
impl PartialOrd for ExtractionConsumerCompatibilityEvidence
impl StructuralPartialEq for ExtractionConsumerCompatibilityEvidence