pub struct ExtractionContractEvidence {
pub subject: String,
pub kind: ExtractionContractKind,
pub direction: ExtractionContractDirection,
pub status: ExtractionEvidenceStatus,
pub contract_id: Option<String>,
pub evidence_references: Vec<String>,
}Fields
subject: Stringkind: ExtractionContractKinddirection: ExtractionContractDirectionstatus: ExtractionEvidenceStatuscontract_id: Option<String>evidence_references: Vec<String>Trait Implementations
Sourceimpl Clone for ExtractionContractEvidence
impl Clone for ExtractionContractEvidence
Sourcefn clone(&self) -> ExtractionContractEvidence
fn clone(&self) -> ExtractionContractEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionContractEvidence
impl Debug for ExtractionContractEvidence
Sourceimpl<'de> Deserialize<'de> for ExtractionContractEvidence
impl<'de> Deserialize<'de> for ExtractionContractEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionContractEvidence
Sourceimpl JsonSchema for ExtractionContractEvidence
impl JsonSchema for ExtractionContractEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionContractEvidence
impl Ord for ExtractionContractEvidence
Sourcefn cmp(&self, other: &ExtractionContractEvidence) -> Ordering
fn cmp(&self, other: &ExtractionContractEvidence) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ExtractionContractEvidence
impl PartialOrd for ExtractionContractEvidence
impl StructuralPartialEq for ExtractionContractEvidence