pub struct ExtractionCursorEvidence {
pub column: String,
pub high_water_mark: String,
pub trustworthy: bool,
pub evidence_references: Vec<String>,
}Fields
column: Stringhigh_water_mark: Stringtrustworthy: boolevidence_references: Vec<String>Trait Implementations
Sourceimpl Clone for ExtractionCursorEvidence
impl Clone for ExtractionCursorEvidence
Sourcefn clone(&self) -> ExtractionCursorEvidence
fn clone(&self) -> ExtractionCursorEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionCursorEvidence
impl Debug for ExtractionCursorEvidence
Sourceimpl<'de> Deserialize<'de> for ExtractionCursorEvidence
impl<'de> Deserialize<'de> for ExtractionCursorEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionCursorEvidence
Sourceimpl JsonSchema for ExtractionCursorEvidence
impl JsonSchema for ExtractionCursorEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionCursorEvidence
impl Ord for ExtractionCursorEvidence
Sourcefn cmp(&self, other: &ExtractionCursorEvidence) -> Ordering
fn cmp(&self, other: &ExtractionCursorEvidence) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ExtractionCursorEvidence
impl PartialEq for ExtractionCursorEvidence
Sourceimpl PartialOrd for ExtractionCursorEvidence
impl PartialOrd for ExtractionCursorEvidence
Sourceimpl Serialize for ExtractionCursorEvidence
impl Serialize for ExtractionCursorEvidence
impl StructuralPartialEq for ExtractionCursorEvidence