pub struct ExtractionCutoverEvidence {
pub kind: String,
pub subject: String,
pub digest: String,
pub detail: String,
}Fields
kind: Stringsubject: Stringdigest: Stringdetail: StringTrait Implementations
Sourceimpl Clone for ExtractionCutoverEvidence
impl Clone for ExtractionCutoverEvidence
Sourcefn clone(&self) -> ExtractionCutoverEvidence
fn clone(&self) -> ExtractionCutoverEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionCutoverEvidence
impl Debug for ExtractionCutoverEvidence
Sourceimpl<'de> Deserialize<'de> for ExtractionCutoverEvidence
impl<'de> Deserialize<'de> for ExtractionCutoverEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionCutoverEvidence
Sourceimpl JsonSchema for ExtractionCutoverEvidence
impl JsonSchema for ExtractionCutoverEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionCutoverEvidence
impl Ord for ExtractionCutoverEvidence
Sourcefn cmp(&self, other: &ExtractionCutoverEvidence) -> Ordering
fn cmp(&self, other: &ExtractionCutoverEvidence) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ExtractionCutoverEvidence
impl PartialOrd for ExtractionCutoverEvidence
impl StructuralPartialEq for ExtractionCutoverEvidence