pub struct ExtractionCutoverReceipt {
pub step_id: String,
pub step_digest: String,
pub from_revision: String,
pub to_revision: String,
pub outcome: String,
}Fields
step_id: Stringstep_digest: Stringfrom_revision: Stringto_revision: Stringoutcome: StringTrait Implementations
Sourceimpl Clone for ExtractionCutoverReceipt
impl Clone for ExtractionCutoverReceipt
Sourcefn clone(&self) -> ExtractionCutoverReceipt
fn clone(&self) -> ExtractionCutoverReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionCutoverReceipt
impl Debug for ExtractionCutoverReceipt
Sourceimpl<'de> Deserialize<'de> for ExtractionCutoverReceipt
impl<'de> Deserialize<'de> for ExtractionCutoverReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionCutoverReceipt
Sourceimpl JsonSchema for ExtractionCutoverReceipt
impl JsonSchema for ExtractionCutoverReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionCutoverReceipt
impl Ord for ExtractionCutoverReceipt
Sourcefn cmp(&self, other: &ExtractionCutoverReceipt) -> Ordering
fn cmp(&self, other: &ExtractionCutoverReceipt) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ExtractionCutoverReceipt
impl PartialEq for ExtractionCutoverReceipt
Sourceimpl PartialOrd for ExtractionCutoverReceipt
impl PartialOrd for ExtractionCutoverReceipt
Sourceimpl Serialize for ExtractionCutoverReceipt
impl Serialize for ExtractionCutoverReceipt
impl StructuralPartialEq for ExtractionCutoverReceipt