pub struct ExtractionDataAccessEvidence {
pub accessor_module: String,
pub table: String,
pub access: ExtractionDataAccessKind,
pub source: ExtractionDataEvidenceSource,
pub evidence_references: Vec<String>,
}Fields
accessor_module: Stringtable: Stringaccess: ExtractionDataAccessKindsource: ExtractionDataEvidenceSourceevidence_references: Vec<String>Trait Implementations
Sourceimpl Clone for ExtractionDataAccessEvidence
impl Clone for ExtractionDataAccessEvidence
Sourcefn clone(&self) -> ExtractionDataAccessEvidence
fn clone(&self) -> ExtractionDataAccessEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionDataAccessEvidence
impl Debug for ExtractionDataAccessEvidence
Sourceimpl<'de> Deserialize<'de> for ExtractionDataAccessEvidence
impl<'de> Deserialize<'de> for ExtractionDataAccessEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionDataAccessEvidence
Sourceimpl JsonSchema for ExtractionDataAccessEvidence
impl JsonSchema for ExtractionDataAccessEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionDataAccessEvidence
impl Ord for ExtractionDataAccessEvidence
Sourcefn cmp(&self, other: &ExtractionDataAccessEvidence) -> Ordering
fn cmp(&self, other: &ExtractionDataAccessEvidence) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ExtractionDataAccessEvidence
impl PartialOrd for ExtractionDataAccessEvidence
impl StructuralPartialEq for ExtractionDataAccessEvidence