pub struct ExtractionDataMapping {
pub store_engine: String,
pub destination_store: String,
pub tables: Vec<ExtractionTableMapping>,
pub migrations: Vec<ExtractionMigrationMapping>,
}Fields
store_engine: Stringdestination_store: Stringtables: Vec<ExtractionTableMapping>migrations: Vec<ExtractionMigrationMapping>Trait Implementations
Sourceimpl Clone for ExtractionDataMapping
impl Clone for ExtractionDataMapping
Sourcefn clone(&self) -> ExtractionDataMapping
fn clone(&self) -> ExtractionDataMapping
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionDataMapping
impl Debug for ExtractionDataMapping
Sourceimpl<'de> Deserialize<'de> for ExtractionDataMapping
impl<'de> Deserialize<'de> for ExtractionDataMapping
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionDataMapping
Sourceimpl JsonSchema for ExtractionDataMapping
impl JsonSchema for ExtractionDataMapping
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionDataMapping
impl PartialEq for ExtractionDataMapping
Sourceimpl Serialize for ExtractionDataMapping
impl Serialize for ExtractionDataMapping
impl StructuralPartialEq for ExtractionDataMapping