pub struct ExtractionDataTableEvidence {
pub table: String,
pub owner_module: Option<String>,
pub source: ExtractionDataEvidenceSource,
pub volume: Option<ExtractionDataVolumeEvidence>,
pub cursor: Option<ExtractionCursorEvidence>,
pub evidence_references: Vec<String>,
}Fields
table: Stringowner_module: Option<String>source: ExtractionDataEvidenceSourcevolume: Option<ExtractionDataVolumeEvidence>cursor: Option<ExtractionCursorEvidence>evidence_references: Vec<String>Trait Implementations
Sourceimpl Clone for ExtractionDataTableEvidence
impl Clone for ExtractionDataTableEvidence
Sourcefn clone(&self) -> ExtractionDataTableEvidence
fn clone(&self) -> ExtractionDataTableEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionDataTableEvidence
impl Debug for ExtractionDataTableEvidence
Sourceimpl<'de> Deserialize<'de> for ExtractionDataTableEvidence
impl<'de> Deserialize<'de> for ExtractionDataTableEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionDataTableEvidence
Sourceimpl JsonSchema for ExtractionDataTableEvidence
impl JsonSchema for ExtractionDataTableEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionDataTableEvidence
impl Ord for ExtractionDataTableEvidence
Sourcefn cmp(&self, other: &ExtractionDataTableEvidence) -> Ordering
fn cmp(&self, other: &ExtractionDataTableEvidence) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ExtractionDataTableEvidence
impl PartialOrd for ExtractionDataTableEvidence
impl StructuralPartialEq for ExtractionDataTableEvidence