pub struct ExtractionExpansionOperation {
pub operation_id: String,
pub operation_digest: String,
pub order: u16,
pub kind: ExtractionExpansionOperationKind,
pub workload_id: String,
pub candidate_service_id: String,
pub destination_store_id: String,
pub mutating: bool,
pub migration: Option<ExtractionExpandMigration>,
}Fields
operation_id: Stringoperation_digest: Stringorder: u16kind: ExtractionExpansionOperationKindworkload_id: Stringcandidate_service_id: Stringdestination_store_id: Stringmutating: boolmigration: Option<ExtractionExpandMigration>Trait Implementations
Sourceimpl Clone for ExtractionExpansionOperation
impl Clone for ExtractionExpansionOperation
Sourcefn clone(&self) -> ExtractionExpansionOperation
fn clone(&self) -> ExtractionExpansionOperation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionExpansionOperation
impl Debug for ExtractionExpansionOperation
Sourceimpl<'de> Deserialize<'de> for ExtractionExpansionOperation
impl<'de> Deserialize<'de> for ExtractionExpansionOperation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionExpansionOperation
Sourceimpl JsonSchema for ExtractionExpansionOperation
impl JsonSchema for ExtractionExpansionOperation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionExpansionOperation