pub struct ExtractionFastRollbackError {
pub code: ExtractionFastRollbackIssueCode,
pub message: String,
pub next_actions: Vec<String>,
}Fields
code: ExtractionFastRollbackIssueCodemessage: Stringnext_actions: Vec<String>Trait Implementations
Sourceimpl Clone for ExtractionFastRollbackError
impl Clone for ExtractionFastRollbackError
Sourcefn clone(&self) -> ExtractionFastRollbackError
fn clone(&self) -> ExtractionFastRollbackError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionFastRollbackError
impl Debug for ExtractionFastRollbackError
Sourceimpl<'de> Deserialize<'de> for ExtractionFastRollbackError
impl<'de> Deserialize<'de> for ExtractionFastRollbackError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionFastRollbackError
Sourceimpl Error for ExtractionFastRollbackError
impl Error for ExtractionFastRollbackError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl JsonSchema for ExtractionFastRollbackError
impl JsonSchema for ExtractionFastRollbackError
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionFastRollbackError