pub struct ExtractionGeneratedBinding {Show 13 fields
pub contract_id: String,
pub version: String,
pub kind: ExtractionGeneratedBindingKind,
pub role: ExtractionScaffoldBindingRole,
pub artifact_path: String,
pub artifact_digest: String,
pub binding_path: String,
pub binding_digest: String,
pub tenancy_mode: ServiceTenancyMode,
pub required_context: Vec<CommonContextRequirement>,
pub operation_ids: Vec<String>,
pub event_types: Vec<String>,
pub generated_client_ids: Vec<String>,
}Fields
contract_id: Stringversion: Stringkind: ExtractionGeneratedBindingKindrole: ExtractionScaffoldBindingRoleartifact_path: Stringartifact_digest: Stringbinding_path: Stringbinding_digest: Stringtenancy_mode: ServiceTenancyModerequired_context: Vec<CommonContextRequirement>operation_ids: Vec<String>event_types: Vec<String>generated_client_ids: Vec<String>Trait Implementations
Sourceimpl Clone for ExtractionGeneratedBinding
impl Clone for ExtractionGeneratedBinding
Sourcefn clone(&self) -> ExtractionGeneratedBinding
fn clone(&self) -> ExtractionGeneratedBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionGeneratedBinding
impl Debug for ExtractionGeneratedBinding
Sourceimpl<'de> Deserialize<'de> for ExtractionGeneratedBinding
impl<'de> Deserialize<'de> for ExtractionGeneratedBinding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionGeneratedBinding
Sourceimpl JsonSchema for ExtractionGeneratedBinding
impl JsonSchema for ExtractionGeneratedBinding
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionGeneratedBinding
impl Ord for ExtractionGeneratedBinding
Sourcefn cmp(&self, other: &ExtractionGeneratedBinding) -> Ordering
fn cmp(&self, other: &ExtractionGeneratedBinding) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ExtractionGeneratedBinding
impl PartialOrd for ExtractionGeneratedBinding
impl StructuralPartialEq for ExtractionGeneratedBinding