pub struct ExtractionGeneratedClientPlan {
pub client_id: String,
pub owner_id: String,
pub contract_id: String,
pub version: String,
pub artifact_reference: String,
}Fields
client_id: Stringowner_id: Stringcontract_id: Stringversion: Stringartifact_reference: StringTrait Implementations
Sourceimpl Clone for ExtractionGeneratedClientPlan
impl Clone for ExtractionGeneratedClientPlan
Sourcefn clone(&self) -> ExtractionGeneratedClientPlan
fn clone(&self) -> ExtractionGeneratedClientPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ExtractionGeneratedClientPlan
impl<'de> Deserialize<'de> for ExtractionGeneratedClientPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionGeneratedClientPlan
Sourceimpl JsonSchema for ExtractionGeneratedClientPlan
impl JsonSchema for ExtractionGeneratedClientPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionGeneratedClientPlan
impl Ord for ExtractionGeneratedClientPlan
Sourcefn cmp(&self, other: &ExtractionGeneratedClientPlan) -> Ordering
fn cmp(&self, other: &ExtractionGeneratedClientPlan) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ExtractionGeneratedClientPlan
impl PartialOrd for ExtractionGeneratedClientPlan
impl StructuralPartialEq for ExtractionGeneratedClientPlan