pub struct ExtractionInputPin {
pub kind: ExtractionInputPinKind,
pub subject: String,
pub digest: String,
}Fields
kind: ExtractionInputPinKindsubject: Stringdigest: StringTrait Implementations
Sourceimpl Clone for ExtractionInputPin
impl Clone for ExtractionInputPin
Sourcefn clone(&self) -> ExtractionInputPin
fn clone(&self) -> ExtractionInputPin
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionInputPin
impl Debug for ExtractionInputPin
Sourceimpl<'de> Deserialize<'de> for ExtractionInputPin
impl<'de> Deserialize<'de> for ExtractionInputPin
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionInputPin
Sourceimpl JsonSchema for ExtractionInputPin
impl JsonSchema for ExtractionInputPin
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionInputPin
impl Ord for ExtractionInputPin
Sourcefn cmp(&self, other: &ExtractionInputPin) -> Ordering
fn cmp(&self, other: &ExtractionInputPin) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ExtractionInputPin
impl PartialEq for ExtractionInputPin
Sourceimpl PartialOrd for ExtractionInputPin
impl PartialOrd for ExtractionInputPin
Sourceimpl Serialize for ExtractionInputPin
impl Serialize for ExtractionInputPin
impl StructuralPartialEq for ExtractionInputPin