pub struct ExtractionMigrationEvidence {
pub migration: String,
pub owner_module: Option<String>,
pub source: ExtractionDataEvidenceSource,
pub evidence_references: Vec<String>,
}Fields
migration: Stringowner_module: Option<String>source: ExtractionDataEvidenceSourceevidence_references: Vec<String>Trait Implementations
Sourceimpl Clone for ExtractionMigrationEvidence
impl Clone for ExtractionMigrationEvidence
Sourcefn clone(&self) -> ExtractionMigrationEvidence
fn clone(&self) -> ExtractionMigrationEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionMigrationEvidence
impl Debug for ExtractionMigrationEvidence
Sourceimpl<'de> Deserialize<'de> for ExtractionMigrationEvidence
impl<'de> Deserialize<'de> for ExtractionMigrationEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionMigrationEvidence
Sourceimpl JsonSchema for ExtractionMigrationEvidence
impl JsonSchema for ExtractionMigrationEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionMigrationEvidence
impl Ord for ExtractionMigrationEvidence
Sourcefn cmp(&self, other: &ExtractionMigrationEvidence) -> Ordering
fn cmp(&self, other: &ExtractionMigrationEvidence) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ExtractionMigrationEvidence
impl PartialOrd for ExtractionMigrationEvidence
impl StructuralPartialEq for ExtractionMigrationEvidence