pub struct ExtractionNormalizedField {
pub json_pointer: String,
pub reason: String,
}Fields
json_pointer: Stringreason: StringTrait Implementations
Sourceimpl Clone for ExtractionNormalizedField
impl Clone for ExtractionNormalizedField
Sourcefn clone(&self) -> ExtractionNormalizedField
fn clone(&self) -> ExtractionNormalizedField
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionNormalizedField
impl Debug for ExtractionNormalizedField
Sourceimpl<'de> Deserialize<'de> for ExtractionNormalizedField
impl<'de> Deserialize<'de> for ExtractionNormalizedField
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionNormalizedField
Sourceimpl JsonSchema for ExtractionNormalizedField
impl JsonSchema for ExtractionNormalizedField
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionNormalizedField