pub struct ExtractionOperationReceipt {Show 19 fields
pub protocol: String,
pub receipt_id: String,
pub receipt_digest: String,
pub run_id: String,
pub plan_id: String,
pub plan_digest: String,
pub expected_state_digest: String,
pub operation_id: String,
pub operation_digest: String,
pub operation_kind: ExtractionExpansionOperationKind,
pub workload_id: String,
pub candidate_service_id: String,
pub destination_store_id: String,
pub outcome: ExtractionOperationOutcome,
pub source_authority: ExtractionExpectedAuthority,
pub source_store_unchanged: bool,
pub linked_authority_remains_authoritative: bool,
pub candidate_authoritative: bool,
pub evidence: Vec<ExtractionRunEvidence>,
}Fields
protocol: Stringreceipt_id: Stringreceipt_digest: Stringrun_id: Stringplan_id: Stringplan_digest: Stringexpected_state_digest: Stringoperation_id: Stringoperation_digest: Stringoperation_kind: ExtractionExpansionOperationKindworkload_id: Stringcandidate_service_id: Stringdestination_store_id: Stringoutcome: ExtractionOperationOutcomesource_store_unchanged: boolevidence: Vec<ExtractionRunEvidence>Trait Implementations
Sourceimpl Clone for ExtractionOperationReceipt
impl Clone for ExtractionOperationReceipt
Sourcefn clone(&self) -> ExtractionOperationReceipt
fn clone(&self) -> ExtractionOperationReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionOperationReceipt
impl Debug for ExtractionOperationReceipt
Sourceimpl<'de> Deserialize<'de> for ExtractionOperationReceipt
impl<'de> Deserialize<'de> for ExtractionOperationReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionOperationReceipt
Sourceimpl JsonSchema for ExtractionOperationReceipt
impl JsonSchema for ExtractionOperationReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionOperationReceipt