pub struct ExtractionPlan {Show 16 fields
pub protocol: String,
pub generator_version: String,
pub plan_id: String,
pub plan_digest: String,
pub target_module: String,
pub source_system_id: String,
pub readiness_classification: CompatibilityCategory,
pub readiness_issue_codes: Vec<ExtractionReadinessIssueCode>,
pub expected_authority: ExtractionExpectedAuthority,
pub pinned_inputs: Vec<ExtractionInputPin>,
pub data_mapping: ExtractionDataMapping,
pub proposed_service: ExtractionServicePlan,
pub diff: ExtractionPlanDiff,
pub phases: Vec<ExtractionPlanPhase>,
pub approval_boundaries: Vec<ExtractionApprovalBoundary>,
pub effects: ExtractionPlanEffects,
}Fields
protocol: Stringgenerator_version: Stringplan_id: Stringplan_digest: Stringtarget_module: Stringsource_system_id: Stringreadiness_classification: CompatibilityCategoryreadiness_issue_codes: Vec<ExtractionReadinessIssueCode>pinned_inputs: Vec<ExtractionInputPin>data_mapping: ExtractionDataMappingproposed_service: ExtractionServicePlandiff: ExtractionPlanDiffphases: Vec<ExtractionPlanPhase>approval_boundaries: Vec<ExtractionApprovalBoundary>effects: ExtractionPlanEffectsTrait Implementations
Sourceimpl Clone for ExtractionPlan
impl Clone for ExtractionPlan
Sourcefn clone(&self) -> ExtractionPlan
fn clone(&self) -> ExtractionPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionPlan
impl Debug for ExtractionPlan
Sourceimpl<'de> Deserialize<'de> for ExtractionPlan
impl<'de> Deserialize<'de> for ExtractionPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionPlan
Sourceimpl JsonSchema for ExtractionPlan
impl JsonSchema for ExtractionPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionPlan
impl PartialEq for ExtractionPlan
Sourceimpl Serialize for ExtractionPlan
impl Serialize for ExtractionPlan
impl StructuralPartialEq for ExtractionPlan