pub struct ExtractionPlanContractVersion {
pub contract_id: String,
pub version: String,
pub kind: ExtractionContractKind,
pub direction: ExtractionContractDirection,
pub artifact_reference: String,
pub artifact_digest: String,
pub artifact_format: ExtractionContractArtifactFormat,
pub tenancy_mode: ServiceTenancyMode,
pub required_context: Vec<CommonContextRequirement>,
pub producer_id: Option<String>,
pub consumer_ids: Vec<String>,
}Fields
contract_id: Stringversion: Stringkind: ExtractionContractKinddirection: ExtractionContractDirectionartifact_reference: Stringartifact_digest: Stringartifact_format: ExtractionContractArtifactFormattenancy_mode: ServiceTenancyModerequired_context: Vec<CommonContextRequirement>producer_id: Option<String>consumer_ids: Vec<String>Trait Implementations
Sourceimpl Clone for ExtractionPlanContractVersion
impl Clone for ExtractionPlanContractVersion
Sourcefn clone(&self) -> ExtractionPlanContractVersion
fn clone(&self) -> ExtractionPlanContractVersion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ExtractionPlanContractVersion
impl<'de> Deserialize<'de> for ExtractionPlanContractVersion
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionPlanContractVersion
Sourceimpl JsonSchema for ExtractionPlanContractVersion
impl JsonSchema for ExtractionPlanContractVersion
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionPlanContractVersion
impl Ord for ExtractionPlanContractVersion
Sourcefn cmp(&self, other: &ExtractionPlanContractVersion) -> Ordering
fn cmp(&self, other: &ExtractionPlanContractVersion) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ExtractionPlanContractVersion
impl PartialOrd for ExtractionPlanContractVersion
impl StructuralPartialEq for ExtractionPlanContractVersion