pub struct ExtractionPlanDiff {
pub entries: Vec<ExtractionPlanDiffEntry>,
}Fields
entries: Vec<ExtractionPlanDiffEntry>Trait Implementations
Sourceimpl Clone for ExtractionPlanDiff
impl Clone for ExtractionPlanDiff
Sourcefn clone(&self) -> ExtractionPlanDiff
fn clone(&self) -> ExtractionPlanDiff
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionPlanDiff
impl Debug for ExtractionPlanDiff
Sourceimpl<'de> Deserialize<'de> for ExtractionPlanDiff
impl<'de> Deserialize<'de> for ExtractionPlanDiff
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionPlanDiff
Sourceimpl JsonSchema for ExtractionPlanDiff
impl JsonSchema for ExtractionPlanDiff
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionPlanDiff
impl PartialEq for ExtractionPlanDiff
Sourceimpl Serialize for ExtractionPlanDiff
impl Serialize for ExtractionPlanDiff
impl StructuralPartialEq for ExtractionPlanDiff