pub struct ExtractionPlanDiffEntry {
pub subject: String,
pub before: Option<String>,
pub after: Option<String>,
}Fields
subject: Stringbefore: Option<String>after: Option<String>Trait Implementations
Sourceimpl Clone for ExtractionPlanDiffEntry
impl Clone for ExtractionPlanDiffEntry
Sourcefn clone(&self) -> ExtractionPlanDiffEntry
fn clone(&self) -> ExtractionPlanDiffEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionPlanDiffEntry
impl Debug for ExtractionPlanDiffEntry
Sourceimpl<'de> Deserialize<'de> for ExtractionPlanDiffEntry
impl<'de> Deserialize<'de> for ExtractionPlanDiffEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionPlanDiffEntry
Sourceimpl JsonSchema for ExtractionPlanDiffEntry
impl JsonSchema for ExtractionPlanDiffEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionPlanDiffEntry
impl Ord for ExtractionPlanDiffEntry
Sourcefn cmp(&self, other: &ExtractionPlanDiffEntry) -> Ordering
fn cmp(&self, other: &ExtractionPlanDiffEntry) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ExtractionPlanDiffEntry
impl PartialEq for ExtractionPlanDiffEntry
Sourceimpl PartialOrd for ExtractionPlanDiffEntry
impl PartialOrd for ExtractionPlanDiffEntry
Sourceimpl Serialize for ExtractionPlanDiffEntry
impl Serialize for ExtractionPlanDiffEntry
impl StructuralPartialEq for ExtractionPlanDiffEntry