pub struct ExtractionPlanEffects {
pub writes_repository_files: bool,
pub starts_workloads: bool,
pub copies_data: bool,
pub changes_authority: bool,
}Fields
writes_repository_files: boolstarts_workloads: boolcopies_data: boolTrait Implementations
Sourceimpl Clone for ExtractionPlanEffects
impl Clone for ExtractionPlanEffects
Sourcefn clone(&self) -> ExtractionPlanEffects
fn clone(&self) -> ExtractionPlanEffects
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ExtractionPlanEffects
Sourceimpl Debug for ExtractionPlanEffects
impl Debug for ExtractionPlanEffects
Sourceimpl Default for ExtractionPlanEffects
impl Default for ExtractionPlanEffects
Sourcefn default() -> ExtractionPlanEffects
fn default() -> ExtractionPlanEffects
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ExtractionPlanEffects
impl<'de> Deserialize<'de> for ExtractionPlanEffects
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionPlanEffects
Sourceimpl JsonSchema for ExtractionPlanEffects
impl JsonSchema for ExtractionPlanEffects
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionPlanEffects
impl PartialEq for ExtractionPlanEffects
Sourceimpl Serialize for ExtractionPlanEffects
impl Serialize for ExtractionPlanEffects
impl StructuralPartialEq for ExtractionPlanEffects