pub struct ExtractionPlanPhase {
pub phase_id: String,
pub order: u16,
pub kind: ExtractionPlanPhaseKind,
pub prerequisite_phase_ids: Vec<String>,
pub prerequisites: Vec<String>,
pub intended_mutations: Vec<String>,
pub expected_evidence: Vec<String>,
pub rollback_conditions: Vec<String>,
pub issue_codes: Vec<ExtractionPlanIssueCode>,
pub next_actions: Vec<String>,
pub approval_boundary: Option<ExtractionApprovalBoundary>,
}Fields
phase_id: Stringorder: u16kind: ExtractionPlanPhaseKindprerequisite_phase_ids: Vec<String>prerequisites: Vec<String>intended_mutations: Vec<String>expected_evidence: Vec<String>rollback_conditions: Vec<String>issue_codes: Vec<ExtractionPlanIssueCode>next_actions: Vec<String>approval_boundary: Option<ExtractionApprovalBoundary>Trait Implementations
Sourceimpl Clone for ExtractionPlanPhase
impl Clone for ExtractionPlanPhase
Sourcefn clone(&self) -> ExtractionPlanPhase
fn clone(&self) -> ExtractionPlanPhase
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionPlanPhase
impl Debug for ExtractionPlanPhase
Sourceimpl<'de> Deserialize<'de> for ExtractionPlanPhase
impl<'de> Deserialize<'de> for ExtractionPlanPhase
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionPlanPhase
Sourceimpl JsonSchema for ExtractionPlanPhase
impl JsonSchema for ExtractionPlanPhase
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionPlanPhase
impl PartialEq for ExtractionPlanPhase
Sourceimpl Serialize for ExtractionPlanPhase
impl Serialize for ExtractionPlanPhase
impl StructuralPartialEq for ExtractionPlanPhase