pub struct ExtractionPlanRejection {
pub plan_id: String,
pub message: String,
pub issue_codes: Vec<ExtractionPlanIssueCode>,
pub stale_inputs: Vec<ExtractionStaleInput>,
pub next_actions: Vec<String>,
pub effects: ExtractionPlanEffects,
}Fields
plan_id: Stringmessage: Stringissue_codes: Vec<ExtractionPlanIssueCode>stale_inputs: Vec<ExtractionStaleInput>next_actions: Vec<String>effects: ExtractionPlanEffectsTrait Implementations
Sourceimpl Clone for ExtractionPlanRejection
impl Clone for ExtractionPlanRejection
Sourcefn clone(&self) -> ExtractionPlanRejection
fn clone(&self) -> ExtractionPlanRejection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionPlanRejection
impl Debug for ExtractionPlanRejection
Sourceimpl<'de> Deserialize<'de> for ExtractionPlanRejection
impl<'de> Deserialize<'de> for ExtractionPlanRejection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ExtractionPlanRejection
impl Display for ExtractionPlanRejection
impl Eq for ExtractionPlanRejection
Sourceimpl Error for ExtractionPlanRejection
impl Error for ExtractionPlanRejection
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl JsonSchema for ExtractionPlanRejection
impl JsonSchema for ExtractionPlanRejection
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionPlanRejection
impl PartialEq for ExtractionPlanRejection
Sourceimpl Serialize for ExtractionPlanRejection
impl Serialize for ExtractionPlanRejection
impl StructuralPartialEq for ExtractionPlanRejection