pub struct ExtractionPreservedIdentity {
pub module_name: String,
pub module_manifest_digest: String,
pub module_manifest: Value,
pub capabilities: Vec<String>,
pub operation_ids: Vec<String>,
pub event_types: Vec<String>,
pub runtime_function_names: Vec<String>,
pub schedule_names: Vec<String>,
pub workflow_identities: Vec<String>,
pub story_titles: Vec<String>,
pub admin_identity: Value,
pub console_identity: Value,
}Fields
module_name: Stringmodule_manifest_digest: Stringmodule_manifest: Valuecapabilities: Vec<String>operation_ids: Vec<String>event_types: Vec<String>runtime_function_names: Vec<String>schedule_names: Vec<String>workflow_identities: Vec<String>story_titles: Vec<String>admin_identity: Valueconsole_identity: ValueTrait Implementations
Sourceimpl Clone for ExtractionPreservedIdentity
impl Clone for ExtractionPreservedIdentity
Sourcefn clone(&self) -> ExtractionPreservedIdentity
fn clone(&self) -> ExtractionPreservedIdentity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionPreservedIdentity
impl Debug for ExtractionPreservedIdentity
Sourceimpl<'de> Deserialize<'de> for ExtractionPreservedIdentity
impl<'de> Deserialize<'de> for ExtractionPreservedIdentity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionPreservedIdentity
Sourceimpl JsonSchema for ExtractionPreservedIdentity
impl JsonSchema for ExtractionPreservedIdentity
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionPreservedIdentity