pub struct ExtractionProvisionalCutoverInputs {
pub plan_id: String,
pub plan_digest: String,
pub authority_revision: String,
pub routing_revision: String,
pub candidate_service_id: String,
pub candidate_healthy: bool,
pub verification: ExtractionVerificationResult,
pub quiescence: ExtractionQuiescenceRun,
}Fields
plan_id: Stringplan_digest: Stringrouting_revision: Stringcandidate_service_id: Stringcandidate_healthy: boolverification: ExtractionVerificationResultquiescence: ExtractionQuiescenceRunTrait Implementations
Sourceimpl Clone for ExtractionProvisionalCutoverInputs
impl Clone for ExtractionProvisionalCutoverInputs
Sourcefn clone(&self) -> ExtractionProvisionalCutoverInputs
fn clone(&self) -> ExtractionProvisionalCutoverInputs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ExtractionProvisionalCutoverInputs
impl<'de> Deserialize<'de> for ExtractionProvisionalCutoverInputs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionProvisionalCutoverInputs
Sourceimpl JsonSchema for ExtractionProvisionalCutoverInputs
impl JsonSchema for ExtractionProvisionalCutoverInputs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionProvisionalCutoverInputs