pub struct ExtractionProvisionalCutoverRun {Show 27 fields
pub protocol: String,
pub cutover_id: String,
pub cutover_digest: String,
pub revision: u64,
pub status: ExtractionProvisionalCutoverStatus,
pub plan_id: String,
pub plan_digest: String,
pub authority_revision: String,
pub routing_revision_before: String,
pub routing_revision_current: String,
pub candidate_service_id: String,
pub verification_digest: String,
pub quiescence_digest: String,
pub source_high_water_mark: String,
pub destination_checkpoint: String,
pub route: ExtractionTrafficRoute,
pub external_mutations_paused: bool,
pub linked_mutations_open: bool,
pub linked_authoritative: bool,
pub candidate_authoritative: bool,
pub candidate_healthy: bool,
pub declared_verification_traffic_only: bool,
pub verification_effects_isolated: bool,
pub linked_business_probe_passed: bool,
pub apply_receipts: Vec<ExtractionCutoverReceipt>,
pub rollback_receipts: Vec<ExtractionCutoverReceipt>,
pub evidence: Vec<ExtractionCutoverEvidence>,
}Fields
protocol: Stringcutover_id: Stringcutover_digest: Stringrevision: u64status: ExtractionProvisionalCutoverStatusplan_id: Stringplan_digest: Stringrouting_revision_before: Stringrouting_revision_current: Stringcandidate_service_id: Stringverification_digest: Stringquiescence_digest: Stringsource_high_water_mark: Stringdestination_checkpoint: Stringroute: ExtractionTrafficRouteexternal_mutations_paused: boollinked_mutations_open: boolcandidate_healthy: booldeclared_verification_traffic_only: boolverification_effects_isolated: boollinked_business_probe_passed: boolapply_receipts: Vec<ExtractionCutoverReceipt>rollback_receipts: Vec<ExtractionCutoverReceipt>evidence: Vec<ExtractionCutoverEvidence>Trait Implementations
Sourceimpl Clone for ExtractionProvisionalCutoverRun
impl Clone for ExtractionProvisionalCutoverRun
Sourcefn clone(&self) -> ExtractionProvisionalCutoverRun
fn clone(&self) -> ExtractionProvisionalCutoverRun
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ExtractionProvisionalCutoverRun
impl<'de> Deserialize<'de> for ExtractionProvisionalCutoverRun
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionProvisionalCutoverRun
Sourceimpl JsonSchema for ExtractionProvisionalCutoverRun
impl JsonSchema for ExtractionProvisionalCutoverRun
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionProvisionalCutoverRun