pub struct ExtractionQuiescenceEffects {
pub pauses_linked_mutations: bool,
pub drains_in_flight_work: bool,
pub copies_final_delta: bool,
pub routes_candidate_traffic: bool,
pub changes_authority: bool,
pub requires_runtime_console: bool,
pub requires_system_plane_for_business_execution: bool,
}Fields
pauses_linked_mutations: booldrains_in_flight_work: boolcopies_final_delta: boolroutes_candidate_traffic: boolrequires_runtime_console: boolrequires_system_plane_for_business_execution: boolTrait Implementations
Sourceimpl Clone for ExtractionQuiescenceEffects
impl Clone for ExtractionQuiescenceEffects
Sourcefn clone(&self) -> ExtractionQuiescenceEffects
fn clone(&self) -> ExtractionQuiescenceEffects
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ExtractionQuiescenceEffects
Sourceimpl Debug for ExtractionQuiescenceEffects
impl Debug for ExtractionQuiescenceEffects
Sourceimpl Default for ExtractionQuiescenceEffects
impl Default for ExtractionQuiescenceEffects
Sourcefn default() -> ExtractionQuiescenceEffects
fn default() -> ExtractionQuiescenceEffects
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ExtractionQuiescenceEffects
impl<'de> Deserialize<'de> for ExtractionQuiescenceEffects
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionQuiescenceEffects
Sourceimpl JsonSchema for ExtractionQuiescenceEffects
impl JsonSchema for ExtractionQuiescenceEffects
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionQuiescenceEffects