pub struct ExtractionQuiescenceEvidence {
pub kind: String,
pub subject: String,
pub digest: String,
pub detail: String,
}Fields
kind: Stringsubject: Stringdigest: Stringdetail: StringTrait Implementations
Sourceimpl Clone for ExtractionQuiescenceEvidence
impl Clone for ExtractionQuiescenceEvidence
Sourcefn clone(&self) -> ExtractionQuiescenceEvidence
fn clone(&self) -> ExtractionQuiescenceEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionQuiescenceEvidence
impl Debug for ExtractionQuiescenceEvidence
Sourceimpl<'de> Deserialize<'de> for ExtractionQuiescenceEvidence
impl<'de> Deserialize<'de> for ExtractionQuiescenceEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionQuiescenceEvidence
Sourceimpl JsonSchema for ExtractionQuiescenceEvidence
impl JsonSchema for ExtractionQuiescenceEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionQuiescenceEvidence
impl Ord for ExtractionQuiescenceEvidence
Sourcefn cmp(&self, other: &ExtractionQuiescenceEvidence) -> Ordering
fn cmp(&self, other: &ExtractionQuiescenceEvidence) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ExtractionQuiescenceEvidence
impl PartialOrd for ExtractionQuiescenceEvidence
impl StructuralPartialEq for ExtractionQuiescenceEvidence