pub struct ExtractionQuiescenceIssue {
pub code: ExtractionQuiescenceIssueCode,
pub subject: String,
pub detail: String,
pub next_actions: Vec<String>,
}Fields
code: ExtractionQuiescenceIssueCodesubject: Stringdetail: Stringnext_actions: Vec<String>Trait Implementations
Sourceimpl Clone for ExtractionQuiescenceIssue
impl Clone for ExtractionQuiescenceIssue
Sourcefn clone(&self) -> ExtractionQuiescenceIssue
fn clone(&self) -> ExtractionQuiescenceIssue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionQuiescenceIssue
impl Debug for ExtractionQuiescenceIssue
Sourceimpl<'de> Deserialize<'de> for ExtractionQuiescenceIssue
impl<'de> Deserialize<'de> for ExtractionQuiescenceIssue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionQuiescenceIssue
Sourceimpl JsonSchema for ExtractionQuiescenceIssue
impl JsonSchema for ExtractionQuiescenceIssue
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionQuiescenceIssue
impl Ord for ExtractionQuiescenceIssue
Sourcefn cmp(&self, other: &ExtractionQuiescenceIssue) -> Ordering
fn cmp(&self, other: &ExtractionQuiescenceIssue) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ExtractionQuiescenceIssue
impl PartialOrd for ExtractionQuiescenceIssue
impl StructuralPartialEq for ExtractionQuiescenceIssue