pub struct ExtractionQuiescenceRun {Show 19 fields
pub protocol: String,
pub quiescence_id: String,
pub quiescence_digest: String,
pub revision: u64,
pub status: ExtractionQuiescenceStatus,
pub plan_id: String,
pub plan_digest: String,
pub expected_authority_revision: String,
pub linked_mutations_paused: bool,
pub linked_read_inspection_available: bool,
pub linked_authority_remains_authoritative: bool,
pub candidate_authoritative: bool,
pub drain: Option<ExtractionDrainSnapshot>,
pub stable_source_high_water_mark: Option<String>,
pub destination_checkpoint: Option<String>,
pub issues: Vec<ExtractionQuiescenceIssue>,
pub evidence: Vec<ExtractionQuiescenceEvidence>,
pub next_actions: Vec<String>,
pub effects: ExtractionQuiescenceEffects,
}Fields
protocol: Stringquiescence_id: Stringquiescence_digest: Stringrevision: u64status: ExtractionQuiescenceStatusplan_id: Stringplan_digest: Stringlinked_mutations_paused: boollinked_read_inspection_available: booldrain: Option<ExtractionDrainSnapshot>stable_source_high_water_mark: Option<String>destination_checkpoint: Option<String>issues: Vec<ExtractionQuiescenceIssue>evidence: Vec<ExtractionQuiescenceEvidence>next_actions: Vec<String>effects: ExtractionQuiescenceEffectsTrait Implementations
Sourceimpl Clone for ExtractionQuiescenceRun
impl Clone for ExtractionQuiescenceRun
Sourcefn clone(&self) -> ExtractionQuiescenceRun
fn clone(&self) -> ExtractionQuiescenceRun
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionQuiescenceRun
impl Debug for ExtractionQuiescenceRun
Sourceimpl<'de> Deserialize<'de> for ExtractionQuiescenceRun
impl<'de> Deserialize<'de> for ExtractionQuiescenceRun
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionQuiescenceRun
Sourceimpl JsonSchema for ExtractionQuiescenceRun
impl JsonSchema for ExtractionQuiescenceRun
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionQuiescenceRun
impl PartialEq for ExtractionQuiescenceRun
Sourceimpl Serialize for ExtractionQuiescenceRun
impl Serialize for ExtractionQuiescenceRun
impl StructuralPartialEq for ExtractionQuiescenceRun