pub struct ExtractionReadinessEffects {
pub writes_repository_files: bool,
pub starts_workloads: bool,
pub moves_data: bool,
pub changes_authority: bool,
}Fields
writes_repository_files: boolstarts_workloads: boolmoves_data: boolTrait Implementations
Sourceimpl Clone for ExtractionReadinessEffects
impl Clone for ExtractionReadinessEffects
Sourcefn clone(&self) -> ExtractionReadinessEffects
fn clone(&self) -> ExtractionReadinessEffects
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ExtractionReadinessEffects
Sourceimpl Debug for ExtractionReadinessEffects
impl Debug for ExtractionReadinessEffects
Sourceimpl Default for ExtractionReadinessEffects
impl Default for ExtractionReadinessEffects
Sourcefn default() -> ExtractionReadinessEffects
fn default() -> ExtractionReadinessEffects
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ExtractionReadinessEffects
impl<'de> Deserialize<'de> for ExtractionReadinessEffects
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionReadinessEffects
Sourceimpl JsonSchema for ExtractionReadinessEffects
impl JsonSchema for ExtractionReadinessEffects
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionReadinessEffects