pub struct ExtractionReadinessFinding {
pub classification: CompatibilityCategory,
pub code: ExtractionReadinessIssueCode,
pub subject: String,
pub message: String,
pub evidence_references: Vec<String>,
pub next_actions: Vec<String>,
}Fields
classification: CompatibilityCategorycode: ExtractionReadinessIssueCodesubject: Stringmessage: Stringevidence_references: Vec<String>next_actions: Vec<String>Trait Implementations
Sourceimpl Clone for ExtractionReadinessFinding
impl Clone for ExtractionReadinessFinding
Sourcefn clone(&self) -> ExtractionReadinessFinding
fn clone(&self) -> ExtractionReadinessFinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionReadinessFinding
impl Debug for ExtractionReadinessFinding
Sourceimpl<'de> Deserialize<'de> for ExtractionReadinessFinding
impl<'de> Deserialize<'de> for ExtractionReadinessFinding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionReadinessFinding
Sourceimpl JsonSchema for ExtractionReadinessFinding
impl JsonSchema for ExtractionReadinessFinding
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionReadinessFinding