pub struct ExtractionReadinessSurfaceSummary {
pub http_routes: Vec<String>,
pub event_handlers: Vec<String>,
pub runtime_functions: Vec<String>,
pub schedules: Vec<String>,
pub workflows: Vec<String>,
pub admin: Vec<String>,
pub console: Vec<String>,
pub stories: Vec<String>,
}Fields
http_routes: Vec<String>event_handlers: Vec<String>runtime_functions: Vec<String>schedules: Vec<String>workflows: Vec<String>admin: Vec<String>console: Vec<String>stories: Vec<String>Trait Implementations
Sourceimpl Clone for ExtractionReadinessSurfaceSummary
impl Clone for ExtractionReadinessSurfaceSummary
Sourcefn clone(&self) -> ExtractionReadinessSurfaceSummary
fn clone(&self) -> ExtractionReadinessSurfaceSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ExtractionReadinessSurfaceSummary
impl Default for ExtractionReadinessSurfaceSummary
Sourcefn default() -> ExtractionReadinessSurfaceSummary
fn default() -> ExtractionReadinessSurfaceSummary
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ExtractionReadinessSurfaceSummary
impl<'de> Deserialize<'de> for ExtractionReadinessSurfaceSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionReadinessSurfaceSummary
Sourceimpl JsonSchema for ExtractionReadinessSurfaceSummary
impl JsonSchema for ExtractionReadinessSurfaceSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionReadinessSurfaceSummary