pub struct ExtractionReconciliationEffects {
pub reads_source_snapshot: bool,
pub reads_candidate_snapshot: bool,
pub mutates_source: bool,
pub mutates_candidate: bool,
pub changes_authority: bool,
}Fields
reads_source_snapshot: boolreads_candidate_snapshot: boolmutates_source: boolmutates_candidate: boolTrait Implementations
Sourceimpl Clone for ExtractionReconciliationEffects
impl Clone for ExtractionReconciliationEffects
Sourcefn clone(&self) -> ExtractionReconciliationEffects
fn clone(&self) -> ExtractionReconciliationEffects
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ExtractionReconciliationEffects
Sourceimpl Default for ExtractionReconciliationEffects
impl Default for ExtractionReconciliationEffects
Sourcefn default() -> ExtractionReconciliationEffects
fn default() -> ExtractionReconciliationEffects
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ExtractionReconciliationEffects
impl<'de> Deserialize<'de> for ExtractionReconciliationEffects
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionReconciliationEffects
Sourceimpl JsonSchema for ExtractionReconciliationEffects
impl JsonSchema for ExtractionReconciliationEffects
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionReconciliationEffects