pub struct ExtractionReconciliationInputs {
pub backfill: ExtractionBackfillRun,
pub source: ExtractionSourceSnapshot,
pub destination_records: Option<Vec<ExtractionBackfillRecord>>,
pub destination_relationship_counts: Vec<ExtractionRelationshipCount>,
pub normalized_fields: Vec<ExtractionNormalizedField>,
pub business_invariants: Vec<ExtractionBusinessInvariant>,
}Fields
backfill: ExtractionBackfillRunsource: ExtractionSourceSnapshotdestination_records: Option<Vec<ExtractionBackfillRecord>>destination_relationship_counts: Vec<ExtractionRelationshipCount>normalized_fields: Vec<ExtractionNormalizedField>business_invariants: Vec<ExtractionBusinessInvariant>Trait Implementations
Sourceimpl Clone for ExtractionReconciliationInputs
impl Clone for ExtractionReconciliationInputs
Sourcefn clone(&self) -> ExtractionReconciliationInputs
fn clone(&self) -> ExtractionReconciliationInputs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ExtractionReconciliationInputs
impl<'de> Deserialize<'de> for ExtractionReconciliationInputs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionReconciliationInputs
Sourceimpl JsonSchema for ExtractionReconciliationInputs
impl JsonSchema for ExtractionReconciliationInputs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionReconciliationInputs