pub struct ExtractionRun {Show 15 fields
pub protocol: String,
pub run_id: String,
pub run_digest: String,
pub revision: u64,
pub mode: ExtractionRunMode,
pub plan: ExtractionPlan,
pub current_phase: ExtractionRunPhase,
pub expected_state: ExtractionRunExpectedState,
pub expected_state_digest: String,
pub ordered_operations: Vec<ExtractionExpansionOperation>,
pub receipts: Vec<ExtractionOperationReceipt>,
pub evidence: Vec<ExtractionRunEvidence>,
pub errors: Vec<ExtractionRunError>,
pub next_actions: Vec<String>,
pub effects: ExtractionRunEffects,
}Fields
protocol: Stringrun_id: Stringrun_digest: Stringrevision: u64mode: ExtractionRunModeplan: ExtractionPlancurrent_phase: ExtractionRunPhaseexpected_state: ExtractionRunExpectedStateexpected_state_digest: Stringordered_operations: Vec<ExtractionExpansionOperation>receipts: Vec<ExtractionOperationReceipt>evidence: Vec<ExtractionRunEvidence>errors: Vec<ExtractionRunError>next_actions: Vec<String>effects: ExtractionRunEffectsTrait Implementations
Sourceimpl Clone for ExtractionRun
impl Clone for ExtractionRun
Sourcefn clone(&self) -> ExtractionRun
fn clone(&self) -> ExtractionRun
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionRun
impl Debug for ExtractionRun
Sourceimpl<'de> Deserialize<'de> for ExtractionRun
impl<'de> Deserialize<'de> for ExtractionRun
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionRun
Sourceimpl JsonSchema for ExtractionRun
impl JsonSchema for ExtractionRun
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionRun
impl PartialEq for ExtractionRun
Sourceimpl Serialize for ExtractionRun
impl Serialize for ExtractionRun
impl StructuralPartialEq for ExtractionRun