pub struct ExtractionRunEffects {
pub creates_destination_store: bool,
pub applies_destination_schema: bool,
pub invokes_candidate_workload_behavior: bool,
pub copies_service_data: bool,
pub mutates_source_store: bool,
pub mutates_linked_implementation: bool,
pub changes_authority: bool,
pub performs_destructive_cleanup: bool,
}Fields
creates_destination_store: boolapplies_destination_schema: boolinvokes_candidate_workload_behavior: boolcopies_service_data: boolmutates_source_store: boolmutates_linked_implementation: boolperforms_destructive_cleanup: boolTrait Implementations
Sourceimpl Clone for ExtractionRunEffects
impl Clone for ExtractionRunEffects
Sourcefn clone(&self) -> ExtractionRunEffects
fn clone(&self) -> ExtractionRunEffects
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ExtractionRunEffects
Sourceimpl Debug for ExtractionRunEffects
impl Debug for ExtractionRunEffects
Sourceimpl Default for ExtractionRunEffects
impl Default for ExtractionRunEffects
Sourcefn default() -> ExtractionRunEffects
fn default() -> ExtractionRunEffects
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ExtractionRunEffects
impl<'de> Deserialize<'de> for ExtractionRunEffects
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionRunEffects
Sourceimpl JsonSchema for ExtractionRunEffects
impl JsonSchema for ExtractionRunEffects
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionRunEffects
impl PartialEq for ExtractionRunEffects
Sourceimpl Serialize for ExtractionRunEffects
impl Serialize for ExtractionRunEffects
impl StructuralPartialEq for ExtractionRunEffects