pub struct ExtractionRunError {
pub sequence: u32,
pub operation_id: Option<String>,
pub code: ExtractionRunErrorCode,
pub message: String,
pub evidence: Vec<ExtractionRunEvidence>,
pub next_actions: Vec<String>,
pub resolved: bool,
}Fields
sequence: u32operation_id: Option<String>code: ExtractionRunErrorCodemessage: Stringevidence: Vec<ExtractionRunEvidence>next_actions: Vec<String>resolved: boolTrait Implementations
Sourceimpl Clone for ExtractionRunError
impl Clone for ExtractionRunError
Sourcefn clone(&self) -> ExtractionRunError
fn clone(&self) -> ExtractionRunError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionRunError
impl Debug for ExtractionRunError
Sourceimpl<'de> Deserialize<'de> for ExtractionRunError
impl<'de> Deserialize<'de> for ExtractionRunError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionRunError
Sourceimpl JsonSchema for ExtractionRunError
impl JsonSchema for ExtractionRunError
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionRunError
impl PartialEq for ExtractionRunError
Sourceimpl Serialize for ExtractionRunError
impl Serialize for ExtractionRunError
impl StructuralPartialEq for ExtractionRunError