pub struct ExtractionRunEvidence {
pub kind: ExtractionRunEvidenceKind,
pub subject: String,
pub digest: String,
pub detail: String,
}Fields
kind: ExtractionRunEvidenceKindsubject: Stringdigest: Stringdetail: StringTrait Implementations
Sourceimpl Clone for ExtractionRunEvidence
impl Clone for ExtractionRunEvidence
Sourcefn clone(&self) -> ExtractionRunEvidence
fn clone(&self) -> ExtractionRunEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionRunEvidence
impl Debug for ExtractionRunEvidence
Sourceimpl<'de> Deserialize<'de> for ExtractionRunEvidence
impl<'de> Deserialize<'de> for ExtractionRunEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionRunEvidence
Sourceimpl JsonSchema for ExtractionRunEvidence
impl JsonSchema for ExtractionRunEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionRunEvidence
impl Ord for ExtractionRunEvidence
Sourcefn cmp(&self, other: &ExtractionRunEvidence) -> Ordering
fn cmp(&self, other: &ExtractionRunEvidence) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ExtractionRunEvidence
impl PartialEq for ExtractionRunEvidence
Sourceimpl PartialOrd for ExtractionRunEvidence
impl PartialOrd for ExtractionRunEvidence
Sourceimpl Serialize for ExtractionRunEvidence
impl Serialize for ExtractionRunEvidence
impl StructuralPartialEq for ExtractionRunEvidence