pub struct ExtractionRunExpectedState {Show 15 fields
pub plan_id: String,
pub plan_digest: String,
pub scaffold_id: String,
pub scaffold_digest: String,
pub phase_id: String,
pub source_authority: ExtractionExpectedAuthority,
pub linked_authority_remains_authoritative: bool,
pub source_store_remains_unchanged: bool,
pub candidate_service_id: String,
pub destination_store_id: String,
pub destination_store_engine: String,
pub destination_store_isolated: bool,
pub migration_workload_id: String,
pub api_workload_id: String,
pub ordered_operations_digest: String,
}Fields
plan_id: Stringplan_digest: Stringscaffold_id: Stringscaffold_digest: Stringphase_id: Stringsource_store_remains_unchanged: boolcandidate_service_id: Stringdestination_store_id: Stringdestination_store_engine: Stringdestination_store_isolated: boolmigration_workload_id: Stringapi_workload_id: Stringordered_operations_digest: StringTrait Implementations
Sourceimpl Clone for ExtractionRunExpectedState
impl Clone for ExtractionRunExpectedState
Sourcefn clone(&self) -> ExtractionRunExpectedState
fn clone(&self) -> ExtractionRunExpectedState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionRunExpectedState
impl Debug for ExtractionRunExpectedState
Sourceimpl<'de> Deserialize<'de> for ExtractionRunExpectedState
impl<'de> Deserialize<'de> for ExtractionRunExpectedState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionRunExpectedState
Sourceimpl JsonSchema for ExtractionRunExpectedState
impl JsonSchema for ExtractionRunExpectedState
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionRunExpectedState