pub struct ExtractionRunPhase {
pub phase_id: String,
pub kind: ExtractionPlanPhaseKind,
pub status: ExtractionRunStatus,
pub completed_operation_ids: Vec<String>,
pub next_operation_id: Option<String>,
}Fields
phase_id: Stringkind: ExtractionPlanPhaseKindstatus: ExtractionRunStatuscompleted_operation_ids: Vec<String>next_operation_id: Option<String>Trait Implementations
Sourceimpl Clone for ExtractionRunPhase
impl Clone for ExtractionRunPhase
Sourcefn clone(&self) -> ExtractionRunPhase
fn clone(&self) -> ExtractionRunPhase
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionRunPhase
impl Debug for ExtractionRunPhase
Sourceimpl<'de> Deserialize<'de> for ExtractionRunPhase
impl<'de> Deserialize<'de> for ExtractionRunPhase
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionRunPhase
Sourceimpl JsonSchema for ExtractionRunPhase
impl JsonSchema for ExtractionRunPhase
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionRunPhase
impl PartialEq for ExtractionRunPhase
Sourceimpl Serialize for ExtractionRunPhase
impl Serialize for ExtractionRunPhase
impl StructuralPartialEq for ExtractionRunPhase