pub struct ExtractionScaffoldApplyResult {
pub protocol: String,
pub scaffold_id: String,
pub plan_id: String,
pub created_files: Vec<String>,
pub unchanged_files: Vec<String>,
pub linked_authority_remains_authoritative: bool,
pub effects: ExtractionScaffoldEffects,
}Fields
protocol: Stringscaffold_id: Stringplan_id: Stringcreated_files: Vec<String>unchanged_files: Vec<String>effects: ExtractionScaffoldEffectsTrait Implementations
Sourceimpl Clone for ExtractionScaffoldApplyResult
impl Clone for ExtractionScaffoldApplyResult
Sourcefn clone(&self) -> ExtractionScaffoldApplyResult
fn clone(&self) -> ExtractionScaffoldApplyResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ExtractionScaffoldApplyResult
impl<'de> Deserialize<'de> for ExtractionScaffoldApplyResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionScaffoldApplyResult
Sourceimpl JsonSchema for ExtractionScaffoldApplyResult
impl JsonSchema for ExtractionScaffoldApplyResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionScaffoldApplyResult