pub struct ExtractionScaffoldEffects {
pub writes_repository_files: bool,
pub starts_workloads: bool,
pub copies_data: bool,
pub changes_authority: bool,
pub changes_provider_path: bool,
}Fields
writes_repository_files: boolstarts_workloads: boolcopies_data: boolchanges_provider_path: boolTrait Implementations
Sourceimpl Clone for ExtractionScaffoldEffects
impl Clone for ExtractionScaffoldEffects
Sourcefn clone(&self) -> ExtractionScaffoldEffects
fn clone(&self) -> ExtractionScaffoldEffects
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ExtractionScaffoldEffects
Sourceimpl Debug for ExtractionScaffoldEffects
impl Debug for ExtractionScaffoldEffects
Sourceimpl Default for ExtractionScaffoldEffects
impl Default for ExtractionScaffoldEffects
Sourcefn default() -> ExtractionScaffoldEffects
fn default() -> ExtractionScaffoldEffects
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ExtractionScaffoldEffects
impl<'de> Deserialize<'de> for ExtractionScaffoldEffects
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionScaffoldEffects
Sourceimpl JsonSchema for ExtractionScaffoldEffects
impl JsonSchema for ExtractionScaffoldEffects
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionScaffoldEffects