pub struct ExtractionScaffoldFile {
pub path: String,
pub kind: ExtractionScaffoldFileKind,
pub digest: String,
pub contents: String,
}Fields
path: Stringkind: ExtractionScaffoldFileKinddigest: Stringcontents: StringTrait Implementations
Sourceimpl Clone for ExtractionScaffoldFile
impl Clone for ExtractionScaffoldFile
Sourcefn clone(&self) -> ExtractionScaffoldFile
fn clone(&self) -> ExtractionScaffoldFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionScaffoldFile
impl Debug for ExtractionScaffoldFile
Sourceimpl<'de> Deserialize<'de> for ExtractionScaffoldFile
impl<'de> Deserialize<'de> for ExtractionScaffoldFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionScaffoldFile
Sourceimpl JsonSchema for ExtractionScaffoldFile
impl JsonSchema for ExtractionScaffoldFile
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionScaffoldFile
impl PartialEq for ExtractionScaffoldFile
Sourceimpl Serialize for ExtractionScaffoldFile
impl Serialize for ExtractionScaffoldFile
impl StructuralPartialEq for ExtractionScaffoldFile