pub struct ExtractionScaffoldIssue {
pub code: ExtractionScaffoldIssueCode,
pub path: String,
pub message: String,
pub next_action: String,
}Fields
code: ExtractionScaffoldIssueCodepath: Stringmessage: Stringnext_action: StringTrait Implementations
Sourceimpl Clone for ExtractionScaffoldIssue
impl Clone for ExtractionScaffoldIssue
Sourcefn clone(&self) -> ExtractionScaffoldIssue
fn clone(&self) -> ExtractionScaffoldIssue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionScaffoldIssue
impl Debug for ExtractionScaffoldIssue
Sourceimpl<'de> Deserialize<'de> for ExtractionScaffoldIssue
impl<'de> Deserialize<'de> for ExtractionScaffoldIssue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionScaffoldIssue
Sourceimpl JsonSchema for ExtractionScaffoldIssue
impl JsonSchema for ExtractionScaffoldIssue
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionScaffoldIssue
impl PartialEq for ExtractionScaffoldIssue
Sourceimpl Serialize for ExtractionScaffoldIssue
impl Serialize for ExtractionScaffoldIssue
impl StructuralPartialEq for ExtractionScaffoldIssue