pub struct ExtractionServicePlan {
pub service_id: String,
pub module_id: String,
pub workloads: Vec<ExtractionWorkloadPlan>,
pub store: ExtractionStorePlan,
pub contract_versions: Vec<ExtractionPlanContractVersion>,
pub service_references: Vec<ExtractionServiceReferencePlan>,
pub generated_clients: Vec<ExtractionGeneratedClientPlan>,
pub preserved_capabilities: Vec<String>,
pub preserved_surfaces: ExtractionReadinessSurfaceSummary,
}Fields
service_id: Stringmodule_id: Stringworkloads: Vec<ExtractionWorkloadPlan>store: ExtractionStorePlancontract_versions: Vec<ExtractionPlanContractVersion>service_references: Vec<ExtractionServiceReferencePlan>generated_clients: Vec<ExtractionGeneratedClientPlan>preserved_capabilities: Vec<String>preserved_surfaces: ExtractionReadinessSurfaceSummaryTrait Implementations
Sourceimpl Clone for ExtractionServicePlan
impl Clone for ExtractionServicePlan
Sourcefn clone(&self) -> ExtractionServicePlan
fn clone(&self) -> ExtractionServicePlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionServicePlan
impl Debug for ExtractionServicePlan
Sourceimpl<'de> Deserialize<'de> for ExtractionServicePlan
impl<'de> Deserialize<'de> for ExtractionServicePlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionServicePlan
Sourceimpl JsonSchema for ExtractionServicePlan
impl JsonSchema for ExtractionServicePlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionServicePlan
impl PartialEq for ExtractionServicePlan
Sourceimpl Serialize for ExtractionServicePlan
impl Serialize for ExtractionServicePlan
impl StructuralPartialEq for ExtractionServicePlan