pub struct ExtractionSourceSnapshot {
pub source_high_water_mark: String,
pub records: Vec<ExtractionBackfillRecord>,
pub relationship_counts: Vec<ExtractionRelationshipCount>,
}Fields
source_high_water_mark: Stringrecords: Vec<ExtractionBackfillRecord>relationship_counts: Vec<ExtractionRelationshipCount>Trait Implementations
Sourceimpl Clone for ExtractionSourceSnapshot
impl Clone for ExtractionSourceSnapshot
Sourcefn clone(&self) -> ExtractionSourceSnapshot
fn clone(&self) -> ExtractionSourceSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionSourceSnapshot
impl Debug for ExtractionSourceSnapshot
Sourceimpl<'de> Deserialize<'de> for ExtractionSourceSnapshot
impl<'de> Deserialize<'de> for ExtractionSourceSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionSourceSnapshot
Sourceimpl JsonSchema for ExtractionSourceSnapshot
impl JsonSchema for ExtractionSourceSnapshot
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionSourceSnapshot
impl PartialEq for ExtractionSourceSnapshot
Sourceimpl Serialize for ExtractionSourceSnapshot
impl Serialize for ExtractionSourceSnapshot
impl StructuralPartialEq for ExtractionSourceSnapshot