pub struct ExtractionStaleInput {
pub kind: ExtractionInputPinKind,
pub subject: String,
pub planned_digest: Option<String>,
pub current_digest: Option<String>,
}Fields
kind: ExtractionInputPinKindsubject: Stringplanned_digest: Option<String>current_digest: Option<String>Trait Implementations
Sourceimpl Clone for ExtractionStaleInput
impl Clone for ExtractionStaleInput
Sourcefn clone(&self) -> ExtractionStaleInput
fn clone(&self) -> ExtractionStaleInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionStaleInput
impl Debug for ExtractionStaleInput
Sourceimpl<'de> Deserialize<'de> for ExtractionStaleInput
impl<'de> Deserialize<'de> for ExtractionStaleInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionStaleInput
Sourceimpl JsonSchema for ExtractionStaleInput
impl JsonSchema for ExtractionStaleInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionStaleInput
impl PartialEq for ExtractionStaleInput
Sourceimpl Serialize for ExtractionStaleInput
impl Serialize for ExtractionStaleInput
impl StructuralPartialEq for ExtractionStaleInput