pub struct ExtractionStorePlan {
pub store_id: String,
pub engine: String,
pub isolated: bool,
}Fields
store_id: Stringengine: Stringisolated: boolTrait Implementations
Sourceimpl Clone for ExtractionStorePlan
impl Clone for ExtractionStorePlan
Sourcefn clone(&self) -> ExtractionStorePlan
fn clone(&self) -> ExtractionStorePlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionStorePlan
impl Debug for ExtractionStorePlan
Sourceimpl<'de> Deserialize<'de> for ExtractionStorePlan
impl<'de> Deserialize<'de> for ExtractionStorePlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionStorePlan
Sourceimpl JsonSchema for ExtractionStorePlan
impl JsonSchema for ExtractionStorePlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionStorePlan
impl Ord for ExtractionStorePlan
Sourcefn cmp(&self, other: &ExtractionStorePlan) -> Ordering
fn cmp(&self, other: &ExtractionStorePlan) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ExtractionStorePlan
impl PartialEq for ExtractionStorePlan
Sourceimpl PartialOrd for ExtractionStorePlan
impl PartialOrd for ExtractionStorePlan
Sourceimpl Serialize for ExtractionStorePlan
impl Serialize for ExtractionStorePlan
impl StructuralPartialEq for ExtractionStorePlan