pub struct ExtractionTableMapping {
pub source_table: String,
pub destination_table: String,
pub destination_store: String,
pub owner_module: String,
pub copy_mode: ExtractionCopyMode,
pub evidence_sources: Vec<ExtractionDataEvidenceSource>,
pub cursors: Vec<ExtractionCursorEvidence>,
}Fields
source_table: Stringdestination_table: Stringdestination_store: Stringowner_module: Stringcopy_mode: ExtractionCopyModeevidence_sources: Vec<ExtractionDataEvidenceSource>cursors: Vec<ExtractionCursorEvidence>Trait Implementations
Sourceimpl Clone for ExtractionTableMapping
impl Clone for ExtractionTableMapping
Sourcefn clone(&self) -> ExtractionTableMapping
fn clone(&self) -> ExtractionTableMapping
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionTableMapping
impl Debug for ExtractionTableMapping
Sourceimpl<'de> Deserialize<'de> for ExtractionTableMapping
impl<'de> Deserialize<'de> for ExtractionTableMapping
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionTableMapping
Sourceimpl JsonSchema for ExtractionTableMapping
impl JsonSchema for ExtractionTableMapping
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionTableMapping
impl Ord for ExtractionTableMapping
Sourcefn cmp(&self, other: &ExtractionTableMapping) -> Ordering
fn cmp(&self, other: &ExtractionTableMapping) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ExtractionTableMapping
impl PartialEq for ExtractionTableMapping
Sourceimpl PartialOrd for ExtractionTableMapping
impl PartialOrd for ExtractionTableMapping
Sourceimpl Serialize for ExtractionTableMapping
impl Serialize for ExtractionTableMapping
impl StructuralPartialEq for ExtractionTableMapping