pub struct ExtractionTopologyState {
pub authority_revision: String,
pub routing_revision: String,
pub system_graph_revision: String,
pub authority_kind: String,
pub owner_id: String,
}Fields
routing_revision: Stringsystem_graph_revision: Stringowner_id: StringTrait Implementations
Sourceimpl Clone for ExtractionTopologyState
impl Clone for ExtractionTopologyState
Sourcefn clone(&self) -> ExtractionTopologyState
fn clone(&self) -> ExtractionTopologyState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionTopologyState
impl Debug for ExtractionTopologyState
Sourceimpl<'de> Deserialize<'de> for ExtractionTopologyState
impl<'de> Deserialize<'de> for ExtractionTopologyState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionTopologyState
Sourceimpl JsonSchema for ExtractionTopologyState
impl JsonSchema for ExtractionTopologyState
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionTopologyState
impl PartialEq for ExtractionTopologyState
Sourceimpl Serialize for ExtractionTopologyState
impl Serialize for ExtractionTopologyState
impl StructuralPartialEq for ExtractionTopologyState