pub struct ExtractionTransactionEvidence {
pub transaction: String,
pub participating_modules: Vec<String>,
pub source: ExtractionDataEvidenceSource,
pub evidence_references: Vec<String>,
}Fields
transaction: Stringparticipating_modules: Vec<String>source: ExtractionDataEvidenceSourceevidence_references: Vec<String>Trait Implementations
Sourceimpl Clone for ExtractionTransactionEvidence
impl Clone for ExtractionTransactionEvidence
Sourcefn clone(&self) -> ExtractionTransactionEvidence
fn clone(&self) -> ExtractionTransactionEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ExtractionTransactionEvidence
impl<'de> Deserialize<'de> for ExtractionTransactionEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionTransactionEvidence
Sourceimpl JsonSchema for ExtractionTransactionEvidence
impl JsonSchema for ExtractionTransactionEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionTransactionEvidence
impl Ord for ExtractionTransactionEvidence
Sourcefn cmp(&self, other: &ExtractionTransactionEvidence) -> Ordering
fn cmp(&self, other: &ExtractionTransactionEvidence) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ExtractionTransactionEvidence
impl PartialOrd for ExtractionTransactionEvidence
impl StructuralPartialEq for ExtractionTransactionEvidence