pub struct ExtractionVerificationEffects {
pub invokes_linked_public_contract: bool,
pub invokes_candidate_public_contract: bool,
pub routes_external_mutations: bool,
pub changes_authority: bool,
pub requires_runtime_console: bool,
pub requires_system_plane_for_business_execution: bool,
}Fields
invokes_linked_public_contract: boolinvokes_candidate_public_contract: boolroutes_external_mutations: boolrequires_runtime_console: boolrequires_system_plane_for_business_execution: boolTrait Implementations
Sourceimpl Clone for ExtractionVerificationEffects
impl Clone for ExtractionVerificationEffects
Sourcefn clone(&self) -> ExtractionVerificationEffects
fn clone(&self) -> ExtractionVerificationEffects
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ExtractionVerificationEffects
Sourceimpl Default for ExtractionVerificationEffects
impl Default for ExtractionVerificationEffects
Sourcefn default() -> ExtractionVerificationEffects
fn default() -> ExtractionVerificationEffects
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ExtractionVerificationEffects
impl<'de> Deserialize<'de> for ExtractionVerificationEffects
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionVerificationEffects
Sourceimpl JsonSchema for ExtractionVerificationEffects
impl JsonSchema for ExtractionVerificationEffects
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionVerificationEffects