pub struct ExtractionVerificationEvidence {
pub kind: String,
pub subject: String,
pub digest: String,
pub detail: String,
}Fields
kind: Stringsubject: Stringdigest: Stringdetail: StringTrait Implementations
Sourceimpl Clone for ExtractionVerificationEvidence
impl Clone for ExtractionVerificationEvidence
Sourcefn clone(&self) -> ExtractionVerificationEvidence
fn clone(&self) -> ExtractionVerificationEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ExtractionVerificationEvidence
impl<'de> Deserialize<'de> for ExtractionVerificationEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionVerificationEvidence
Sourceimpl JsonSchema for ExtractionVerificationEvidence
impl JsonSchema for ExtractionVerificationEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionVerificationEvidence
impl Ord for ExtractionVerificationEvidence
Sourcefn cmp(&self, other: &ExtractionVerificationEvidence) -> Ordering
fn cmp(&self, other: &ExtractionVerificationEvidence) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ExtractionVerificationEvidence
impl PartialOrd for ExtractionVerificationEvidence
impl StructuralPartialEq for ExtractionVerificationEvidence