pub struct ExtractionVerificationIssue {
pub code: ExtractionVerificationIssueCode,
pub subject: String,
pub detail: String,
pub next_actions: Vec<String>,
}Fields
code: ExtractionVerificationIssueCodesubject: Stringdetail: Stringnext_actions: Vec<String>Trait Implementations
Sourceimpl Clone for ExtractionVerificationIssue
impl Clone for ExtractionVerificationIssue
Sourcefn clone(&self) -> ExtractionVerificationIssue
fn clone(&self) -> ExtractionVerificationIssue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionVerificationIssue
impl Debug for ExtractionVerificationIssue
Sourceimpl<'de> Deserialize<'de> for ExtractionVerificationIssue
impl<'de> Deserialize<'de> for ExtractionVerificationIssue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionVerificationIssue
Sourceimpl JsonSchema for ExtractionVerificationIssue
impl JsonSchema for ExtractionVerificationIssue
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionVerificationIssue
impl Ord for ExtractionVerificationIssue
Sourcefn cmp(&self, other: &ExtractionVerificationIssue) -> Ordering
fn cmp(&self, other: &ExtractionVerificationIssue) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for ExtractionVerificationIssue
impl PartialOrd for ExtractionVerificationIssue
impl StructuralPartialEq for ExtractionVerificationIssue