pub struct ExtractionVerificationResult {Show 15 fields
pub protocol: String,
pub verification_id: String,
pub verification_digest: String,
pub status: ExtractionVerificationStatus,
pub plan_id: String,
pub reconciliation_id: String,
pub reconciliation_digest: String,
pub issues: Vec<ExtractionVerificationIssue>,
pub evidence: Vec<ExtractionVerificationEvidence>,
pub compatibility: Vec<ExtractionCompatibilityEvidence>,
pub policy: Vec<ExtractionPolicyEvidence>,
pub volatile_json_pointers: Vec<String>,
pub provisional_cutover_eligible: bool,
pub linked_authority_remains_authoritative: bool,
pub effects: ExtractionVerificationEffects,
}Fields
protocol: Stringverification_id: Stringverification_digest: Stringstatus: ExtractionVerificationStatusplan_id: Stringreconciliation_id: Stringreconciliation_digest: Stringissues: Vec<ExtractionVerificationIssue>evidence: Vec<ExtractionVerificationEvidence>compatibility: Vec<ExtractionCompatibilityEvidence>policy: Vec<ExtractionPolicyEvidence>volatile_json_pointers: Vec<String>provisional_cutover_eligible: booleffects: ExtractionVerificationEffectsTrait Implementations
Sourceimpl Clone for ExtractionVerificationResult
impl Clone for ExtractionVerificationResult
Sourcefn clone(&self) -> ExtractionVerificationResult
fn clone(&self) -> ExtractionVerificationResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionVerificationResult
impl Debug for ExtractionVerificationResult
Sourceimpl<'de> Deserialize<'de> for ExtractionVerificationResult
impl<'de> Deserialize<'de> for ExtractionVerificationResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionVerificationResult
Sourceimpl JsonSchema for ExtractionVerificationResult
impl JsonSchema for ExtractionVerificationResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ExtractionVerificationResult