pub struct ExtractionWorkloadPlan {
pub workload_id: String,
pub role: ExtractionWorkloadRole,
}Fields
workload_id: Stringrole: ExtractionWorkloadRoleTrait Implementations
Sourceimpl Clone for ExtractionWorkloadPlan
impl Clone for ExtractionWorkloadPlan
Sourcefn clone(&self) -> ExtractionWorkloadPlan
fn clone(&self) -> ExtractionWorkloadPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionWorkloadPlan
impl Debug for ExtractionWorkloadPlan
Sourceimpl<'de> Deserialize<'de> for ExtractionWorkloadPlan
impl<'de> Deserialize<'de> for ExtractionWorkloadPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExtractionWorkloadPlan
Sourceimpl JsonSchema for ExtractionWorkloadPlan
impl JsonSchema for ExtractionWorkloadPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ExtractionWorkloadPlan
impl Ord for ExtractionWorkloadPlan
Sourcefn cmp(&self, other: &ExtractionWorkloadPlan) -> Ordering
fn cmp(&self, other: &ExtractionWorkloadPlan) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ExtractionWorkloadPlan
impl PartialEq for ExtractionWorkloadPlan
Sourceimpl PartialOrd for ExtractionWorkloadPlan
impl PartialOrd for ExtractionWorkloadPlan
Sourceimpl Serialize for ExtractionWorkloadPlan
impl Serialize for ExtractionWorkloadPlan
impl StructuralPartialEq for ExtractionWorkloadPlan