pub struct FailureScenarioEvidence {Show 14 fields
pub protocol: String,
pub evidence_id: String,
pub evidence_digest: String,
pub scenario_id: String,
pub condition: FailureCondition,
pub expected: FailureOutcome,
pub observations: Vec<FailureObservation>,
pub effects: Vec<String>,
pub cleanup_complete: bool,
pub adapter_version: Option<String>,
pub controlled_time_unix_ms: Option<u64>,
pub decision: SupportDecision,
pub issues: Vec<GaIssue>,
pub remediation: Vec<String>,
}Fields
protocol: Stringevidence_id: Stringevidence_digest: Stringscenario_id: Stringcondition: FailureConditionexpected: FailureOutcomeobservations: Vec<FailureObservation>effects: Vec<String>cleanup_complete: booladapter_version: Option<String>controlled_time_unix_ms: Option<u64>decision: SupportDecisionissues: Vec<GaIssue>remediation: Vec<String>Trait Implementations
Sourceimpl Clone for FailureScenarioEvidence
impl Clone for FailureScenarioEvidence
Sourcefn clone(&self) -> FailureScenarioEvidence
fn clone(&self) -> FailureScenarioEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for FailureScenarioEvidence
impl ComposeSchema for FailureScenarioEvidence
Sourceimpl Debug for FailureScenarioEvidence
impl Debug for FailureScenarioEvidence
Sourceimpl<'de> Deserialize<'de> for FailureScenarioEvidence
impl<'de> Deserialize<'de> for FailureScenarioEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for FailureScenarioEvidence
Sourceimpl JsonSchema for FailureScenarioEvidence
impl JsonSchema for FailureScenarioEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FailureScenarioEvidence
impl PartialEq for FailureScenarioEvidence
Sourceimpl Serialize for FailureScenarioEvidence
impl Serialize for FailureScenarioEvidence
impl StructuralPartialEq for FailureScenarioEvidence