pub struct FailureScenarioInput {
pub scenario_id: String,
pub condition: FailureCondition,
pub expected: FailureOutcome,
pub observations: Vec<FailureObservation>,
pub effects: Vec<String>,
pub cleanup_complete: bool,
pub adapter_version: Option<String>,
pub controlled_time_unix_ms: Option<u64>,
}Fields
scenario_id: Stringcondition: FailureConditionexpected: FailureOutcomeobservations: Vec<FailureObservation>effects: Vec<String>cleanup_complete: booladapter_version: Option<String>controlled_time_unix_ms: Option<u64>Trait Implementations
Sourceimpl Clone for FailureScenarioInput
impl Clone for FailureScenarioInput
Sourcefn clone(&self) -> FailureScenarioInput
fn clone(&self) -> FailureScenarioInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for FailureScenarioInput
impl ComposeSchema for FailureScenarioInput
Sourceimpl Debug for FailureScenarioInput
impl Debug for FailureScenarioInput
Sourceimpl<'de> Deserialize<'de> for FailureScenarioInput
impl<'de> Deserialize<'de> for FailureScenarioInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for FailureScenarioInput
Sourceimpl JsonSchema for FailureScenarioInput
impl JsonSchema for FailureScenarioInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FailureScenarioInput
impl PartialEq for FailureScenarioInput
Sourceimpl Serialize for FailureScenarioInput
impl Serialize for FailureScenarioInput
impl StructuralPartialEq for FailureScenarioInput