pub struct GaIssue {
pub code: GaIssueCode,
pub message: String,
pub remediation: String,
pub next_actions: Vec<String>,
}Fields
code: GaIssueCodemessage: Stringremediation: Stringnext_actions: Vec<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for GaIssue
impl<'de> Deserialize<'de> for GaIssue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GaIssue
Sourceimpl JsonSchema for GaIssue
impl JsonSchema for GaIssue
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for GaIssue