pub struct GaSupportEvaluation {
pub protocol: String,
pub manifest_id: String,
pub manifest_digest: String,
pub decision: SupportDecision,
pub combination_id: Option<String>,
pub issues: Vec<GaIssue>,
pub next_actions: Vec<String>,
}Fields
protocol: Stringmanifest_id: Stringmanifest_digest: Stringdecision: SupportDecisioncombination_id: Option<String>issues: Vec<GaIssue>next_actions: Vec<String>Trait Implementations
Sourceimpl Clone for GaSupportEvaluation
impl Clone for GaSupportEvaluation
Sourcefn clone(&self) -> GaSupportEvaluation
fn clone(&self) -> GaSupportEvaluation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for GaSupportEvaluation
impl ComposeSchema for GaSupportEvaluation
Sourceimpl Debug for GaSupportEvaluation
impl Debug for GaSupportEvaluation
Sourceimpl<'de> Deserialize<'de> for GaSupportEvaluation
impl<'de> Deserialize<'de> for GaSupportEvaluation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GaSupportEvaluation
Sourceimpl JsonSchema for GaSupportEvaluation
impl JsonSchema for GaSupportEvaluation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GaSupportEvaluation
impl PartialEq for GaSupportEvaluation
Sourceimpl Serialize for GaSupportEvaluation
impl Serialize for GaSupportEvaluation
impl StructuralPartialEq for GaSupportEvaluation