pub struct GatewayConfigurationPlan {Show 21 fields
pub protocol: String,
pub plan_id: String,
pub plan_digest: String,
pub edge_contract_id: String,
pub edge_contract_digest: String,
pub edge_release_id: String,
pub edge_release_digest: String,
pub operation_catalog_digest: String,
pub edge_provider_id: String,
pub edge_provider_proof: String,
pub environment: String,
pub gateway_adapter: String,
pub public_origin: String,
pub expected_gateway_revision: u64,
pub configuration_identity: String,
pub routes: Vec<ResolvedEdgeRoute>,
pub diff: Vec<GatewayPlanDiffEntry>,
pub drifted: bool,
pub issues: Vec<DeliveryIssue>,
pub next_actions: Vec<String>,
pub effects: DeliveryEffects,
}Fields
protocol: Stringplan_id: Stringplan_digest: Stringedge_contract_id: Stringedge_contract_digest: Stringedge_release_id: Stringedge_release_digest: Stringoperation_catalog_digest: Stringedge_provider_id: Stringedge_provider_proof: Stringenvironment: Stringgateway_adapter: Stringpublic_origin: Stringexpected_gateway_revision: u64configuration_identity: Stringroutes: Vec<ResolvedEdgeRoute>diff: Vec<GatewayPlanDiffEntry>drifted: boolissues: Vec<DeliveryIssue>next_actions: Vec<String>effects: DeliveryEffectsTrait Implementations
Sourceimpl Clone for GatewayConfigurationPlan
impl Clone for GatewayConfigurationPlan
Sourcefn clone(&self) -> GatewayConfigurationPlan
fn clone(&self) -> GatewayConfigurationPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for GatewayConfigurationPlan
impl ComposeSchema for GatewayConfigurationPlan
Sourceimpl Debug for GatewayConfigurationPlan
impl Debug for GatewayConfigurationPlan
Sourceimpl<'de> Deserialize<'de> for GatewayConfigurationPlan
impl<'de> Deserialize<'de> for GatewayConfigurationPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GatewayConfigurationPlan
Sourceimpl JsonSchema for GatewayConfigurationPlan
impl JsonSchema for GatewayConfigurationPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GatewayConfigurationPlan
impl PartialEq for GatewayConfigurationPlan
Sourceimpl Serialize for GatewayConfigurationPlan
impl Serialize for GatewayConfigurationPlan
impl StructuralPartialEq for GatewayConfigurationPlan