pub struct GatewayEnvironmentBinding {
pub environment: String,
pub gateway_adapter: String,
pub public_origin: String,
pub expected_gateway_revision: u64,
}Fields
environment: Stringgateway_adapter: Stringpublic_origin: Stringexpected_gateway_revision: u64Trait Implementations
Sourceimpl Clone for GatewayEnvironmentBinding
impl Clone for GatewayEnvironmentBinding
Sourcefn clone(&self) -> GatewayEnvironmentBinding
fn clone(&self) -> GatewayEnvironmentBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for GatewayEnvironmentBinding
impl ComposeSchema for GatewayEnvironmentBinding
Sourceimpl Debug for GatewayEnvironmentBinding
impl Debug for GatewayEnvironmentBinding
Sourceimpl<'de> Deserialize<'de> for GatewayEnvironmentBinding
impl<'de> Deserialize<'de> for GatewayEnvironmentBinding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GatewayEnvironmentBinding
Sourceimpl JsonSchema for GatewayEnvironmentBinding
impl JsonSchema for GatewayEnvironmentBinding
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for GatewayEnvironmentBinding