pub struct GatewayObservation {Show 16 fields
pub protocol: String,
pub observation_id: String,
pub plan_id: String,
pub plan_digest: String,
pub environment: String,
pub release_id: String,
pub release_digest: String,
pub resource_uid: String,
pub resource_version: String,
pub authority_context: String,
pub configuration_identity: String,
pub revision: u64,
pub observed_after: String,
pub fresh: bool,
pub provider_id: String,
pub provider_proof: String,
}Fields
protocol: Stringobservation_id: Stringplan_id: Stringplan_digest: Stringenvironment: Stringrelease_id: Stringrelease_digest: Stringresource_uid: Stringresource_version: Stringconfiguration_identity: Stringrevision: u64observed_after: Stringfresh: boolprovider_id: Stringprovider_proof: StringTrait Implementations
Sourceimpl Clone for GatewayObservation
impl Clone for GatewayObservation
Sourcefn clone(&self) -> GatewayObservation
fn clone(&self) -> GatewayObservation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for GatewayObservation
impl ComposeSchema for GatewayObservation
Sourceimpl Debug for GatewayObservation
impl Debug for GatewayObservation
Sourceimpl<'de> Deserialize<'de> for GatewayObservation
impl<'de> Deserialize<'de> for GatewayObservation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GatewayObservation
Sourceimpl JsonSchema for GatewayObservation
impl JsonSchema for GatewayObservation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GatewayObservation
impl PartialEq for GatewayObservation
Sourceimpl Serialize for GatewayObservation
impl Serialize for GatewayObservation
impl StructuralPartialEq for GatewayObservation