pub struct GatewayPlanDiffEntry {
pub subject: String,
pub before: Option<String>,
pub after: Option<String>,
}Fields
subject: Stringbefore: Option<String>after: Option<String>Trait Implementations
Sourceimpl Clone for GatewayPlanDiffEntry
impl Clone for GatewayPlanDiffEntry
Sourcefn clone(&self) -> GatewayPlanDiffEntry
fn clone(&self) -> GatewayPlanDiffEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for GatewayPlanDiffEntry
impl ComposeSchema for GatewayPlanDiffEntry
Sourceimpl Debug for GatewayPlanDiffEntry
impl Debug for GatewayPlanDiffEntry
Sourceimpl<'de> Deserialize<'de> for GatewayPlanDiffEntry
impl<'de> Deserialize<'de> for GatewayPlanDiffEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GatewayPlanDiffEntry
Sourceimpl JsonSchema for GatewayPlanDiffEntry
impl JsonSchema for GatewayPlanDiffEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GatewayPlanDiffEntry
impl PartialEq for GatewayPlanDiffEntry
Sourceimpl Serialize for GatewayPlanDiffEntry
impl Serialize for GatewayPlanDiffEntry
impl StructuralPartialEq for GatewayPlanDiffEntry