pub struct KubernetesRecoveryObservation {
pub cluster_identity: String,
pub api_server_version: String,
pub operator_version: String,
pub gateway_adapter_version: String,
pub used_real_api: bool,
pub observed_resource_version: String,
pub evidence_digest: String,
}Fields
cluster_identity: Stringapi_server_version: Stringoperator_version: Stringgateway_adapter_version: Stringused_real_api: boolobserved_resource_version: Stringevidence_digest: StringTrait Implementations
Sourceimpl Clone for KubernetesRecoveryObservation
impl Clone for KubernetesRecoveryObservation
Sourcefn clone(&self) -> KubernetesRecoveryObservation
fn clone(&self) -> KubernetesRecoveryObservation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for KubernetesRecoveryObservation
impl ComposeSchema for KubernetesRecoveryObservation
Sourceimpl<'de> Deserialize<'de> for KubernetesRecoveryObservation
impl<'de> Deserialize<'de> for KubernetesRecoveryObservation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for KubernetesRecoveryObservation
Sourceimpl JsonSchema for KubernetesRecoveryObservation
impl JsonSchema for KubernetesRecoveryObservation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for KubernetesRecoveryObservation