pub struct LastValidEndpointResolver<R> { /* private fields */ }Expand description
Client-side resolver that keeps the last valid state from any resolver adapter, so source or System Plane availability is never request-path state.
Implementations
Sourceimpl<R> LastValidEndpointResolver<R>
impl<R> LastValidEndpointResolver<R>