pub struct LinkedModuleDelivery {
pub package: String,
pub crate_version: String,
pub archive_checksum: String,
pub default_features: bool,
pub features: Vec<String>,
pub binding: String,
pub attestations: Vec<AttestationReference>,
pub migrations: Vec<ArtifactReference>,
}Fields
package: Stringcrate_version: Stringarchive_checksum: Stringdefault_features: boolfeatures: Vec<String>binding: Stringattestations: Vec<AttestationReference>migrations: Vec<ArtifactReference>Trait Implementations
Sourceimpl Clone for LinkedModuleDelivery
impl Clone for LinkedModuleDelivery
Sourcefn clone(&self) -> LinkedModuleDelivery
fn clone(&self) -> LinkedModuleDelivery
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LinkedModuleDelivery
impl Debug for LinkedModuleDelivery
Sourceimpl<'de> Deserialize<'de> for LinkedModuleDelivery
impl<'de> Deserialize<'de> for LinkedModuleDelivery
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<LinkedModuleDelivery, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<LinkedModuleDelivery, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LinkedModuleDelivery
Sourceimpl JsonSchema for LinkedModuleDelivery
impl JsonSchema for LinkedModuleDelivery
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for LinkedModuleDelivery
impl PartialEq for LinkedModuleDelivery
Sourceimpl Serialize for LinkedModuleDelivery
impl Serialize for LinkedModuleDelivery
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for LinkedModuleDelivery