pub struct LocalProcessEndpointResolver { /* private fields */ }Expand description
In-process registry for a local development supervisor that starts and observes Autonomous Service Workloads on the same machine.
Implementations
Sourceimpl LocalProcessEndpointResolver
impl LocalProcessEndpointResolver
pub fn new() -> Self
pub fn publish( &self, state: EndpointState, ) -> Result<(), EndpointResolutionError>
pub fn remove(&self, service: &ServiceReference) -> Option<EndpointState>