pub struct ManifestFormat {
pub kind: ManifestKind,
pub version: String,
}Fields
kind: ManifestKindversion: StringTrait Implementations
Sourceimpl Clone for ManifestFormat
impl Clone for ManifestFormat
Sourcefn clone(&self) -> ManifestFormat
fn clone(&self) -> ManifestFormat
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ManifestFormat
impl ComposeSchema for ManifestFormat
Sourceimpl Debug for ManifestFormat
impl Debug for ManifestFormat
Sourceimpl<'de> Deserialize<'de> for ManifestFormat
impl<'de> Deserialize<'de> for ManifestFormat
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ManifestFormat
Sourceimpl JsonSchema for ManifestFormat
impl JsonSchema for ManifestFormat
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ManifestFormat
impl Ord for ManifestFormat
Sourcefn cmp(&self, other: &ManifestFormat) -> Ordering
fn cmp(&self, other: &ManifestFormat) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ManifestFormat
impl PartialEq for ManifestFormat
Sourceimpl PartialOrd for ManifestFormat
impl PartialOrd for ManifestFormat
Sourceimpl Serialize for ManifestFormat
impl Serialize for ManifestFormat
impl StructuralPartialEq for ManifestFormat