pub struct ManifestMigrationEffects {
pub mutates_source: bool,
pub creates_target: bool,
}Fields
mutates_source: boolcreates_target: boolTrait Implementations
Sourceimpl Clone for ManifestMigrationEffects
impl Clone for ManifestMigrationEffects
Sourcefn clone(&self) -> ManifestMigrationEffects
fn clone(&self) -> ManifestMigrationEffects
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ManifestMigrationEffects
impl ComposeSchema for ManifestMigrationEffects
impl Copy for ManifestMigrationEffects
Sourceimpl Debug for ManifestMigrationEffects
impl Debug for ManifestMigrationEffects
Sourceimpl Default for ManifestMigrationEffects
impl Default for ManifestMigrationEffects
Sourcefn default() -> ManifestMigrationEffects
fn default() -> ManifestMigrationEffects
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ManifestMigrationEffects
impl<'de> Deserialize<'de> for ManifestMigrationEffects
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ManifestMigrationEffects
Sourceimpl JsonSchema for ManifestMigrationEffects
impl JsonSchema for ManifestMigrationEffects
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ManifestMigrationEffects
impl PartialEq for ManifestMigrationEffects
Sourceimpl Serialize for ManifestMigrationEffects
impl Serialize for ManifestMigrationEffects
impl StructuralPartialEq for ManifestMigrationEffects