pub struct ManifestMigrationPlan {
pub protocol: String,
pub plan_id: String,
pub plan_digest: String,
pub kind: ManifestKind,
pub source_format: String,
pub target_format: String,
pub source_digest: String,
pub migrated_digest: String,
pub migrated: Value,
pub identity_pointers: Vec<String>,
pub effects: ManifestMigrationEffects,
}Fields
protocol: Stringplan_id: Stringplan_digest: Stringkind: ManifestKindsource_format: Stringtarget_format: Stringsource_digest: Stringmigrated_digest: Stringmigrated: Valueidentity_pointers: Vec<String>effects: ManifestMigrationEffectsTrait Implementations
Sourceimpl Clone for ManifestMigrationPlan
impl Clone for ManifestMigrationPlan
Sourcefn clone(&self) -> ManifestMigrationPlan
fn clone(&self) -> ManifestMigrationPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ManifestMigrationPlan
impl ComposeSchema for ManifestMigrationPlan
Sourceimpl Debug for ManifestMigrationPlan
impl Debug for ManifestMigrationPlan
Sourceimpl<'de> Deserialize<'de> for ManifestMigrationPlan
impl<'de> Deserialize<'de> for ManifestMigrationPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ManifestMigrationPlan
impl JsonSchema for ManifestMigrationPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ManifestMigrationPlan
impl PartialEq for ManifestMigrationPlan
Sourceimpl Serialize for ManifestMigrationPlan
impl Serialize for ManifestMigrationPlan
impl StructuralPartialEq for ManifestMigrationPlan