pub struct MigrationCompatibilityInput {
pub migration_id: String,
pub lineage_id: String,
pub sequence: u32,
pub phase: MigrationPhase,
pub verified: bool,
}Fields
migration_id: Stringlineage_id: Stringsequence: u32phase: MigrationPhaseverified: boolTrait Implementations
Sourceimpl Clone for MigrationCompatibilityInput
impl Clone for MigrationCompatibilityInput
Sourcefn clone(&self) -> MigrationCompatibilityInput
fn clone(&self) -> MigrationCompatibilityInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for MigrationCompatibilityInput
impl ComposeSchema for MigrationCompatibilityInput
Sourceimpl Debug for MigrationCompatibilityInput
impl Debug for MigrationCompatibilityInput
Sourceimpl<'de> Deserialize<'de> for MigrationCompatibilityInput
impl<'de> Deserialize<'de> for MigrationCompatibilityInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MigrationCompatibilityInput
Sourceimpl JsonSchema for MigrationCompatibilityInput
impl JsonSchema for MigrationCompatibilityInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for MigrationCompatibilityInput