pub struct MigrationRecoveryEvidence {
pub migration_id: String,
pub completed_effects: Vec<String>,
pub remaining_steps: Vec<String>,
pub retry_steps: Vec<String>,
pub state_compatible: bool,
pub rollback_allowed: bool,
pub intervention_required: bool,
}Fields
migration_id: Stringcompleted_effects: Vec<String>remaining_steps: Vec<String>retry_steps: Vec<String>state_compatible: boolrollback_allowed: boolintervention_required: boolTrait Implementations
Sourceimpl Clone for MigrationRecoveryEvidence
impl Clone for MigrationRecoveryEvidence
Sourcefn clone(&self) -> MigrationRecoveryEvidence
fn clone(&self) -> MigrationRecoveryEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for MigrationRecoveryEvidence
impl ComposeSchema for MigrationRecoveryEvidence
Sourceimpl Debug for MigrationRecoveryEvidence
impl Debug for MigrationRecoveryEvidence
Sourceimpl<'de> Deserialize<'de> for MigrationRecoveryEvidence
impl<'de> Deserialize<'de> for MigrationRecoveryEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MigrationRecoveryEvidence
Sourceimpl JsonSchema for MigrationRecoveryEvidence
impl JsonSchema for MigrationRecoveryEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for MigrationRecoveryEvidence