pub struct OperatorObservationAttestation {
pub observation_id: String,
pub observation_digest: String,
pub authority_id: String,
pub authority_proof: String,
pub claims: OperatorObservationClaims,
}Fields
observation_id: Stringobservation_digest: Stringclaims: OperatorObservationClaimsTrait Implementations
Sourceimpl Clone for OperatorObservationAttestation
impl Clone for OperatorObservationAttestation
Sourcefn clone(&self) -> OperatorObservationAttestation
fn clone(&self) -> OperatorObservationAttestation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for OperatorObservationAttestation
impl ComposeSchema for OperatorObservationAttestation
Sourceimpl<'de> Deserialize<'de> for OperatorObservationAttestation
impl<'de> Deserialize<'de> for OperatorObservationAttestation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for OperatorObservationAttestation
Sourceimpl JsonSchema for OperatorObservationAttestation
impl JsonSchema for OperatorObservationAttestation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for OperatorObservationAttestation