pub struct OperatorObservationClaims {Show 24 fields
pub protocol: String,
pub service_id: String,
pub environment: String,
pub deployment_plan_id: String,
pub deployment_plan_digest: String,
pub expected_environment_revision: u64,
pub environment_revision: u64,
pub authority_context: String,
pub resource_uid: String,
pub resource_version: String,
pub desired_release_id: String,
pub desired_release_digest: String,
pub observed_release_id: String,
pub observed_release_digest: String,
pub desired_workload_digests: BTreeMap<String, String>,
pub observed_workload_digests: BTreeMap<String, String>,
pub workload_health: BTreeMap<String, bool>,
pub config_revision_id: String,
pub state: String,
pub rollout_phase: String,
pub rollback_state: String,
pub drifted: bool,
pub fresh: bool,
pub decision: DeliveryDecision,
}Fields
protocol: Stringservice_id: Stringenvironment: Stringdeployment_plan_id: Stringdeployment_plan_digest: Stringexpected_environment_revision: u64environment_revision: u64resource_uid: Stringresource_version: Stringdesired_release_id: Stringdesired_release_digest: Stringobserved_release_id: Stringobserved_release_digest: Stringdesired_workload_digests: BTreeMap<String, String>observed_workload_digests: BTreeMap<String, String>workload_health: BTreeMap<String, bool>config_revision_id: Stringstate: Stringrollout_phase: Stringrollback_state: Stringdrifted: boolfresh: booldecision: DeliveryDecisionTrait Implementations
Sourceimpl Clone for OperatorObservationClaims
impl Clone for OperatorObservationClaims
Sourcefn clone(&self) -> OperatorObservationClaims
fn clone(&self) -> OperatorObservationClaims
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for OperatorObservationClaims
impl ComposeSchema for OperatorObservationClaims
Sourceimpl Debug for OperatorObservationClaims
impl Debug for OperatorObservationClaims
Sourceimpl<'de> Deserialize<'de> for OperatorObservationClaims
impl<'de> Deserialize<'de> for OperatorObservationClaims
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for OperatorObservationClaims
Sourceimpl JsonSchema for OperatorObservationClaims
impl JsonSchema for OperatorObservationClaims
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for OperatorObservationClaims