pub struct PerformanceBudget {
pub metric: PerformanceMetric,
pub unit: String,
pub direction: PerformanceBudgetDirection,
pub threshold: u64,
}Fields
metric: PerformanceMetricunit: Stringdirection: PerformanceBudgetDirectionthreshold: u64Trait Implementations
Sourceimpl Clone for PerformanceBudget
impl Clone for PerformanceBudget
Sourcefn clone(&self) -> PerformanceBudget
fn clone(&self) -> PerformanceBudget
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for PerformanceBudget
impl ComposeSchema for PerformanceBudget
Sourceimpl Debug for PerformanceBudget
impl Debug for PerformanceBudget
Sourceimpl<'de> Deserialize<'de> for PerformanceBudget
impl<'de> Deserialize<'de> for PerformanceBudget
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PerformanceBudget
Sourceimpl JsonSchema for PerformanceBudget
impl JsonSchema for PerformanceBudget
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PerformanceBudget
impl PartialEq for PerformanceBudget
Sourceimpl Serialize for PerformanceBudget
impl Serialize for PerformanceBudget
impl StructuralPartialEq for PerformanceBudget