pub struct PerformanceIssue {
pub code: PerformanceIssueCode,
pub message: String,
pub remediation: String,
pub next_actions: Vec<String>,
}Fields
code: PerformanceIssueCodemessage: Stringremediation: Stringnext_actions: Vec<String>Trait Implementations
Sourceimpl Clone for PerformanceIssue
impl Clone for PerformanceIssue
Sourcefn clone(&self) -> PerformanceIssue
fn clone(&self) -> PerformanceIssue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for PerformanceIssue
impl ComposeSchema for PerformanceIssue
Sourceimpl Debug for PerformanceIssue
impl Debug for PerformanceIssue
Sourceimpl<'de> Deserialize<'de> for PerformanceIssue
impl<'de> Deserialize<'de> for PerformanceIssue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PerformanceIssue
Sourceimpl JsonSchema for PerformanceIssue
impl JsonSchema for PerformanceIssue
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PerformanceIssue
impl PartialEq for PerformanceIssue
Sourceimpl Serialize for PerformanceIssue
impl Serialize for PerformanceIssue
impl StructuralPartialEq for PerformanceIssue