pub struct PerformanceProfile {
pub protocol: String,
pub profile_id: String,
pub profile_digest: String,
pub scope: PerformanceProfileScope,
pub support_manifest_digest: String,
pub topology: ReferenceSystemTopology,
pub budgets: Vec<PerformanceBudget>,
pub runs: Vec<PerformanceRun>,
pub variance_basis_points: BTreeMap<PerformanceMetric, u32>,
pub decision: PerformanceDecision,
pub issues: Vec<PerformanceIssue>,
pub next_actions: Vec<String>,
}Fields
protocol: Stringprofile_id: Stringprofile_digest: Stringscope: PerformanceProfileScopesupport_manifest_digest: Stringtopology: ReferenceSystemTopologybudgets: Vec<PerformanceBudget>runs: Vec<PerformanceRun>variance_basis_points: BTreeMap<PerformanceMetric, u32>decision: PerformanceDecisionissues: Vec<PerformanceIssue>next_actions: Vec<String>Trait Implementations
Sourceimpl Clone for PerformanceProfile
impl Clone for PerformanceProfile
Sourcefn clone(&self) -> PerformanceProfile
fn clone(&self) -> PerformanceProfile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for PerformanceProfile
impl ComposeSchema for PerformanceProfile
Sourceimpl Debug for PerformanceProfile
impl Debug for PerformanceProfile
Sourceimpl<'de> Deserialize<'de> for PerformanceProfile
impl<'de> Deserialize<'de> for PerformanceProfile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PerformanceProfile
Sourceimpl JsonSchema for PerformanceProfile
impl JsonSchema for PerformanceProfile
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PerformanceProfile
impl PartialEq for PerformanceProfile
Sourceimpl Serialize for PerformanceProfile
impl Serialize for PerformanceProfile
impl StructuralPartialEq for PerformanceProfile