pub struct PerformanceProfileInput {
pub scope: PerformanceProfileScope,
pub support_manifest_digest: String,
pub topology: ReferenceSystemTopology,
pub budgets: Vec<PerformanceBudget>,
pub runs: Vec<PerformanceRun>,
pub variance_tolerance_basis_points: u32,
}Fields
scope: PerformanceProfileScopesupport_manifest_digest: Stringtopology: ReferenceSystemTopologybudgets: Vec<PerformanceBudget>runs: Vec<PerformanceRun>variance_tolerance_basis_points: u32Trait Implementations
Sourceimpl Clone for PerformanceProfileInput
impl Clone for PerformanceProfileInput
Sourcefn clone(&self) -> PerformanceProfileInput
fn clone(&self) -> PerformanceProfileInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for PerformanceProfileInput
impl ComposeSchema for PerformanceProfileInput
Sourceimpl Debug for PerformanceProfileInput
impl Debug for PerformanceProfileInput
Sourceimpl<'de> Deserialize<'de> for PerformanceProfileInput
impl<'de> Deserialize<'de> for PerformanceProfileInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PerformanceProfileInput
Sourceimpl JsonSchema for PerformanceProfileInput
impl JsonSchema for PerformanceProfileInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PerformanceProfileInput
impl PartialEq for PerformanceProfileInput
Sourceimpl Serialize for PerformanceProfileInput
impl Serialize for PerformanceProfileInput
impl StructuralPartialEq for PerformanceProfileInput