pub struct PerformanceRun {Show 14 fields
pub run_id: String,
pub release_set_digest: String,
pub dataset_digest: String,
pub concurrency: u32,
pub duration_ms: u64,
pub warmup_ms: u64,
pub machine: BTreeMap<String, String>,
pub infrastructure: BTreeMap<String, String>,
pub measurements: Vec<PerformanceMeasurement>,
pub system_plane_data_plane_requests: u64,
pub runtime_console_data_plane_requests: u64,
pub telemetry_data_plane_requests: u64,
pub policy_data_plane_requests: u64,
pub registry_data_plane_requests: u64,
}Fields
run_id: Stringrelease_set_digest: Stringdataset_digest: Stringconcurrency: u32duration_ms: u64warmup_ms: u64machine: BTreeMap<String, String>infrastructure: BTreeMap<String, String>measurements: Vec<PerformanceMeasurement>system_plane_data_plane_requests: u64runtime_console_data_plane_requests: u64telemetry_data_plane_requests: u64policy_data_plane_requests: u64registry_data_plane_requests: u64Trait Implementations
Sourceimpl Clone for PerformanceRun
impl Clone for PerformanceRun
Sourcefn clone(&self) -> PerformanceRun
fn clone(&self) -> PerformanceRun
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for PerformanceRun
impl ComposeSchema for PerformanceRun
Sourceimpl Debug for PerformanceRun
impl Debug for PerformanceRun
Sourceimpl<'de> Deserialize<'de> for PerformanceRun
impl<'de> Deserialize<'de> for PerformanceRun
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PerformanceRun
Sourceimpl JsonSchema for PerformanceRun
impl JsonSchema for PerformanceRun
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PerformanceRun
impl PartialEq for PerformanceRun
Sourceimpl Serialize for PerformanceRun
impl Serialize for PerformanceRun
impl StructuralPartialEq for PerformanceRun