pub struct PolicyEvidence {
pub protocol: String,
pub evidence_id: String,
pub evidence_digest: String,
pub pack_id: String,
pub pack_digest: String,
pub evaluated_subject: String,
pub input_digests: BTreeMap<String, String>,
pub decision: DeliveryDecision,
pub rule_results: Vec<PolicyRuleResult>,
pub issues: Vec<DeliveryIssue>,
pub effects: DeliveryEffects,
}Fields
protocol: Stringevidence_id: Stringevidence_digest: Stringpack_id: Stringpack_digest: Stringevaluated_subject: Stringinput_digests: BTreeMap<String, String>decision: DeliveryDecisionrule_results: Vec<PolicyRuleResult>issues: Vec<DeliveryIssue>effects: DeliveryEffectsTrait Implementations
Sourceimpl Clone for PolicyEvidence
impl Clone for PolicyEvidence
Sourcefn clone(&self) -> PolicyEvidence
fn clone(&self) -> PolicyEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for PolicyEvidence
impl ComposeSchema for PolicyEvidence
Sourceimpl Debug for PolicyEvidence
impl Debug for PolicyEvidence
Sourceimpl<'de> Deserialize<'de> for PolicyEvidence
impl<'de> Deserialize<'de> for PolicyEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PolicyEvidence
Sourceimpl JsonSchema for PolicyEvidence
impl JsonSchema for PolicyEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PolicyEvidence
impl PartialEq for PolicyEvidence
Sourceimpl Serialize for PolicyEvidence
impl Serialize for PolicyEvidence
impl StructuralPartialEq for PolicyEvidence