pub struct PolicyPack {
pub protocol: String,
pub pack_id: String,
pub pack_digest: String,
pub version: String,
pub environment_profile: PolicyEnvironmentProfile,
pub rules: Vec<PolicyRule>,
}Fields
protocol: Stringpack_id: Stringpack_digest: Stringversion: Stringenvironment_profile: PolicyEnvironmentProfilerules: Vec<PolicyRule>Trait Implementations
Sourceimpl Clone for PolicyPack
impl Clone for PolicyPack
Sourcefn clone(&self) -> PolicyPack
fn clone(&self) -> PolicyPack
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for PolicyPack
impl ComposeSchema for PolicyPack
Sourceimpl Debug for PolicyPack
impl Debug for PolicyPack
Sourceimpl<'de> Deserialize<'de> for PolicyPack
impl<'de> Deserialize<'de> for PolicyPack
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PolicyPack
Sourceimpl JsonSchema for PolicyPack
impl JsonSchema for PolicyPack
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PolicyPack
impl PartialEq for PolicyPack
Sourceimpl Serialize for PolicyPack
impl Serialize for PolicyPack
impl StructuralPartialEq for PolicyPack