pub struct PolicyRule {
pub rule_id: String,
pub evidence_key: String,
pub severity: PolicyRuleSeverity,
pub advisory_in_development: bool,
pub remediation: String,
pub next_action: String,
}Fields
rule_id: Stringevidence_key: Stringseverity: PolicyRuleSeverityadvisory_in_development: boolremediation: Stringnext_action: StringTrait Implementations
Sourceimpl Clone for PolicyRule
impl Clone for PolicyRule
Sourcefn clone(&self) -> PolicyRule
fn clone(&self) -> PolicyRule
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for PolicyRule
impl ComposeSchema for PolicyRule
Sourceimpl Debug for PolicyRule
impl Debug for PolicyRule
Sourceimpl<'de> Deserialize<'de> for PolicyRule
impl<'de> Deserialize<'de> for PolicyRule
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PolicyRule
Sourceimpl JsonSchema for PolicyRule
impl JsonSchema for PolicyRule
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for PolicyRule
impl Ord for PolicyRule
Sourcefn cmp(&self, other: &PolicyRule) -> Ordering
fn cmp(&self, other: &PolicyRule) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PolicyRule
impl PartialEq for PolicyRule
Sourceimpl PartialOrd for PolicyRule
impl PartialOrd for PolicyRule
Sourceimpl Serialize for PolicyRule
impl Serialize for PolicyRule
impl StructuralPartialEq for PolicyRule