pub struct PolicyRuleResult {
pub rule_id: String,
pub severity: PolicyRuleSeverity,
pub decision: DeliveryDecision,
pub evidence_references: Vec<String>,
pub remediation: String,
pub next_actions: Vec<String>,
}Fields
rule_id: Stringseverity: PolicyRuleSeveritydecision: DeliveryDecisionevidence_references: Vec<String>remediation: Stringnext_actions: Vec<String>Trait Implementations
Sourceimpl Clone for PolicyRuleResult
impl Clone for PolicyRuleResult
Sourcefn clone(&self) -> PolicyRuleResult
fn clone(&self) -> PolicyRuleResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for PolicyRuleResult
impl ComposeSchema for PolicyRuleResult
Sourceimpl Debug for PolicyRuleResult
impl Debug for PolicyRuleResult
Sourceimpl<'de> Deserialize<'de> for PolicyRuleResult
impl<'de> Deserialize<'de> for PolicyRuleResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PolicyRuleResult
Sourceimpl JsonSchema for PolicyRuleResult
impl JsonSchema for PolicyRuleResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PolicyRuleResult
impl PartialEq for PolicyRuleResult
Sourceimpl Serialize for PolicyRuleResult
impl Serialize for PolicyRuleResult
impl StructuralPartialEq for PolicyRuleResult