pub struct PostgresRestoreObservation {
pub provider: String,
pub version: String,
pub instance_identity: String,
pub used_real_instance: bool,
pub observation_digest: String,
}Fields
provider: Stringversion: Stringinstance_identity: Stringused_real_instance: boolobservation_digest: StringTrait Implementations
Sourceimpl Clone for PostgresRestoreObservation
impl Clone for PostgresRestoreObservation
Sourcefn clone(&self) -> PostgresRestoreObservation
fn clone(&self) -> PostgresRestoreObservation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for PostgresRestoreObservation
impl ComposeSchema for PostgresRestoreObservation
Sourceimpl Debug for PostgresRestoreObservation
impl Debug for PostgresRestoreObservation
Sourceimpl<'de> Deserialize<'de> for PostgresRestoreObservation
impl<'de> Deserialize<'de> for PostgresRestoreObservation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PostgresRestoreObservation
Sourceimpl JsonSchema for PostgresRestoreObservation
impl JsonSchema for PostgresRestoreObservation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for PostgresRestoreObservation