pub struct ProductionEligibilityEvidence {Show 13 fields
pub protocol: String,
pub evidence_id: String,
pub evidence_digest: String,
pub release_id: String,
pub release_digest: String,
pub provider_id: String,
pub input_digest: String,
pub system_graph_digest: String,
pub decision: DeliveryDecision,
pub facts: BTreeMap<String, Option<bool>>,
pub contract_retirement: Vec<ContractRetirementEvidence>,
pub issues: Vec<DeliveryIssue>,
pub effects: DeliveryEffects,
}Fields
protocol: Stringevidence_id: Stringevidence_digest: Stringrelease_id: Stringrelease_digest: Stringprovider_id: Stringinput_digest: Stringsystem_graph_digest: Stringdecision: DeliveryDecisionfacts: BTreeMap<String, Option<bool>>contract_retirement: Vec<ContractRetirementEvidence>issues: Vec<DeliveryIssue>effects: DeliveryEffectsTrait Implementations
Sourceimpl Clone for ProductionEligibilityEvidence
impl Clone for ProductionEligibilityEvidence
Sourcefn clone(&self) -> ProductionEligibilityEvidence
fn clone(&self) -> ProductionEligibilityEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ProductionEligibilityEvidence
impl ComposeSchema for ProductionEligibilityEvidence
Sourceimpl<'de> Deserialize<'de> for ProductionEligibilityEvidence
impl<'de> Deserialize<'de> for ProductionEligibilityEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProductionEligibilityEvidence
Sourceimpl JsonSchema for ProductionEligibilityEvidence
impl JsonSchema for ProductionEligibilityEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ProductionEligibilityEvidence