pub struct ProductionEligibilityInput {Show 19 fields
pub release_id: String,
pub release_digest: String,
pub provider_id: String,
pub provider_proof: String,
pub system_graph_digest: String,
pub contracts: Vec<ContractCompatibilityInput>,
pub migrations: Vec<MigrationCompatibilityInput>,
pub workflows: WorkflowCompatibilityInput,
pub rollback: RollbackCompatibilityInput,
pub provider_compatibility_verified: Option<bool>,
pub workload_identity_production: Option<bool>,
pub tenancy_mode_production: Option<bool>,
pub tenant_context_enforced: Option<bool>,
pub call_policies_declared: Option<bool>,
pub dependencies_ready: Option<bool>,
pub resilience_declared: Option<bool>,
pub reliability_contract_complete: Option<bool>,
pub edge_contract_valid: Option<bool>,
pub environment_verification_fresh: Option<bool>,
}Fields
release_id: Stringrelease_digest: Stringprovider_id: Stringprovider_proof: Stringsystem_graph_digest: Stringcontracts: Vec<ContractCompatibilityInput>migrations: Vec<MigrationCompatibilityInput>workflows: WorkflowCompatibilityInputrollback: RollbackCompatibilityInputprovider_compatibility_verified: Option<bool>workload_identity_production: Option<bool>tenancy_mode_production: Option<bool>tenant_context_enforced: Option<bool>call_policies_declared: Option<bool>dependencies_ready: Option<bool>resilience_declared: Option<bool>reliability_contract_complete: Option<bool>edge_contract_valid: Option<bool>environment_verification_fresh: Option<bool>Trait Implementations
Sourceimpl Clone for ProductionEligibilityInput
impl Clone for ProductionEligibilityInput
Sourcefn clone(&self) -> ProductionEligibilityInput
fn clone(&self) -> ProductionEligibilityInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ProductionEligibilityInput
impl ComposeSchema for ProductionEligibilityInput
Sourceimpl Debug for ProductionEligibilityInput
impl Debug for ProductionEligibilityInput
Sourceimpl<'de> Deserialize<'de> for ProductionEligibilityInput
impl<'de> Deserialize<'de> for ProductionEligibilityInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProductionEligibilityInput
Sourceimpl JsonSchema for ProductionEligibilityInput
impl JsonSchema for ProductionEligibilityInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ProductionEligibilityInput