pub struct PromotionApplyRejection {
pub issues: Vec<DeliveryIssue>,
pub effects: DeliveryEffects,
}Fields
issues: Vec<DeliveryIssue>effects: DeliveryEffectsTrait Implementations
Sourceimpl Clone for PromotionApplyRejection
impl Clone for PromotionApplyRejection
Sourcefn clone(&self) -> PromotionApplyRejection
fn clone(&self) -> PromotionApplyRejection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for PromotionApplyRejection
impl ComposeSchema for PromotionApplyRejection
Sourceimpl Debug for PromotionApplyRejection
impl Debug for PromotionApplyRejection
Sourceimpl<'de> Deserialize<'de> for PromotionApplyRejection
impl<'de> Deserialize<'de> for PromotionApplyRejection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PromotionApplyRejection
Sourceimpl JsonSchema for PromotionApplyRejection
impl JsonSchema for PromotionApplyRejection
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PromotionApplyRejection
impl PartialEq for PromotionApplyRejection
Sourceimpl Serialize for PromotionApplyRejection
impl Serialize for PromotionApplyRejection
impl StructuralPartialEq for PromotionApplyRejection