pub struct PromotionApproval {
pub protocol: String,
pub approval_id: String,
pub plan_digest: String,
pub actor: String,
pub authority: String,
pub authority_proof: String,
pub issued_for_target_revision: u64,
pub approved: bool,
}Fields
protocol: Stringapproval_id: Stringplan_digest: Stringactor: Stringissued_for_target_revision: u64approved: boolTrait Implementations
Sourceimpl Clone for PromotionApproval
impl Clone for PromotionApproval
Sourcefn clone(&self) -> PromotionApproval
fn clone(&self) -> PromotionApproval
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for PromotionApproval
impl ComposeSchema for PromotionApproval
Sourceimpl Debug for PromotionApproval
impl Debug for PromotionApproval
Sourceimpl<'de> Deserialize<'de> for PromotionApproval
impl<'de> Deserialize<'de> for PromotionApproval
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PromotionApproval
Sourceimpl JsonSchema for PromotionApproval
impl JsonSchema for PromotionApproval
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PromotionApproval
impl PartialEq for PromotionApproval
Sourceimpl Serialize for PromotionApproval
impl Serialize for PromotionApproval
impl StructuralPartialEq for PromotionApproval