pub struct PromotionPlan {Show 23 fields
pub protocol: String,
pub plan_id: String,
pub plan_digest: String,
pub release_id: String,
pub release_digest: String,
pub workload_digests: BTreeMap<String, String>,
pub source_environment: String,
pub target_environment: String,
pub source_environment_revision: u64,
pub target_environment_revision: u64,
pub source_verification_id: String,
pub source_verification_digest: String,
pub policy_evidence_id: String,
pub policy_evidence_digest: String,
pub config_revision_id: String,
pub secret_reference_ids: Vec<String>,
pub target_deployment: DeploymentPlan,
pub target_gateway: GatewayConfigurationPlan,
pub source_topology_digest: String,
pub target_topology_digest: String,
pub evidence_references: Vec<String>,
pub freshness_horizon_revision: u64,
pub effects: DeliveryEffects,
}Fields
protocol: Stringplan_id: Stringplan_digest: Stringrelease_id: Stringrelease_digest: Stringworkload_digests: BTreeMap<String, String>source_environment: Stringtarget_environment: Stringsource_environment_revision: u64target_environment_revision: u64source_verification_id: Stringsource_verification_digest: Stringpolicy_evidence_id: Stringpolicy_evidence_digest: Stringconfig_revision_id: Stringsecret_reference_ids: Vec<String>target_deployment: DeploymentPlantarget_gateway: GatewayConfigurationPlansource_topology_digest: Stringtarget_topology_digest: Stringevidence_references: Vec<String>freshness_horizon_revision: u64effects: DeliveryEffectsTrait Implementations
Sourceimpl Clone for PromotionPlan
impl Clone for PromotionPlan
Sourcefn clone(&self) -> PromotionPlan
fn clone(&self) -> PromotionPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for PromotionPlan
impl ComposeSchema for PromotionPlan
Sourceimpl Debug for PromotionPlan
impl Debug for PromotionPlan
Sourceimpl<'de> Deserialize<'de> for PromotionPlan
impl<'de> Deserialize<'de> for PromotionPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PromotionPlan
Sourceimpl JsonSchema for PromotionPlan
impl JsonSchema for PromotionPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PromotionPlan
impl PartialEq for PromotionPlan
Sourceimpl Serialize for PromotionPlan
impl Serialize for PromotionPlan
impl StructuralPartialEq for PromotionPlan