pub struct PromotionReceipt {Show 14 fields
pub protocol: String,
pub receipt_id: String,
pub plan_id: String,
pub approval_id: String,
pub actor: String,
pub source_environment: String,
pub target_environment: String,
pub release_id: String,
pub release_digest: String,
pub workload_digests: BTreeMap<String, String>,
pub deployment_receipt: DeploymentReceipt,
pub environment_revision_before: u64,
pub environment_revision_after: u64,
pub effects: DeliveryEffects,
}Fields
protocol: Stringreceipt_id: Stringplan_id: Stringapproval_id: Stringactor: Stringsource_environment: Stringtarget_environment: Stringrelease_id: Stringrelease_digest: Stringworkload_digests: BTreeMap<String, String>deployment_receipt: DeploymentReceiptenvironment_revision_before: u64environment_revision_after: u64effects: DeliveryEffectsTrait Implementations
Sourceimpl Clone for PromotionReceipt
impl Clone for PromotionReceipt
Sourcefn clone(&self) -> PromotionReceipt
fn clone(&self) -> PromotionReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for PromotionReceipt
impl ComposeSchema for PromotionReceipt
Sourceimpl Debug for PromotionReceipt
impl Debug for PromotionReceipt
Sourceimpl<'de> Deserialize<'de> for PromotionReceipt
impl<'de> Deserialize<'de> for PromotionReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PromotionReceipt
Sourceimpl JsonSchema for PromotionReceipt
impl JsonSchema for PromotionReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PromotionReceipt
impl PartialEq for PromotionReceipt
Sourceimpl Serialize for PromotionReceipt
impl Serialize for PromotionReceipt
impl StructuralPartialEq for PromotionReceipt