pub struct RateIntent {
pub requests: u32,
pub window_seconds: u32,
}Fields
requests: u32window_seconds: u32Trait Implementations
Sourceimpl Clone for RateIntent
impl Clone for RateIntent
Sourcefn clone(&self) -> RateIntent
fn clone(&self) -> RateIntent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RateIntent
impl ComposeSchema for RateIntent
Sourceimpl Debug for RateIntent
impl Debug for RateIntent
Sourceimpl<'de> Deserialize<'de> for RateIntent
impl<'de> Deserialize<'de> for RateIntent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RateIntent
Sourceimpl JsonSchema for RateIntent
impl JsonSchema for RateIntent
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RateIntent
impl PartialEq for RateIntent
Sourceimpl Serialize for RateIntent
impl Serialize for RateIntent
impl StructuralPartialEq for RateIntent