pub struct ReferenceService {
pub service_id: String,
pub contract_id: String,
pub store_id: String,
pub release_digest: String,
}Fields
service_id: Stringcontract_id: Stringstore_id: Stringrelease_digest: StringTrait Implementations
Sourceimpl Clone for ReferenceService
impl Clone for ReferenceService
Sourcefn clone(&self) -> ReferenceService
fn clone(&self) -> ReferenceService
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ReferenceService
impl ComposeSchema for ReferenceService
Sourceimpl Debug for ReferenceService
impl Debug for ReferenceService
Sourceimpl<'de> Deserialize<'de> for ReferenceService
impl<'de> Deserialize<'de> for ReferenceService
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ReferenceService
Sourceimpl JsonSchema for ReferenceService
impl JsonSchema for ReferenceService
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ReferenceService
impl PartialEq for ReferenceService
Sourceimpl Serialize for ReferenceService
impl Serialize for ReferenceService
impl StructuralPartialEq for ReferenceService