pub struct ReleaseProvenance {
pub reference: String,
pub digest: String,
pub source: String,
pub builder: String,
pub input_digests: Vec<String>,
pub subject_digests: Vec<String>,
}Fields
reference: Stringdigest: Stringsource: Stringbuilder: Stringinput_digests: Vec<String>subject_digests: Vec<String>Trait Implementations
Sourceimpl Clone for ReleaseProvenance
impl Clone for ReleaseProvenance
Sourcefn clone(&self) -> ReleaseProvenance
fn clone(&self) -> ReleaseProvenance
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ReleaseProvenance
impl ComposeSchema for ReleaseProvenance
Sourceimpl Debug for ReleaseProvenance
impl Debug for ReleaseProvenance
Sourceimpl<'de> Deserialize<'de> for ReleaseProvenance
impl<'de> Deserialize<'de> for ReleaseProvenance
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ReleaseProvenance
Sourceimpl JsonSchema for ReleaseProvenance
impl JsonSchema for ReleaseProvenance
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ReleaseProvenance
impl PartialEq for ReleaseProvenance
Sourceimpl Serialize for ReleaseProvenance
impl Serialize for ReleaseProvenance
impl StructuralPartialEq for ReleaseProvenance