pub struct ReleaseRollbackConstraints {
pub previous_release_required: bool,
pub automatic_allowed: bool,
pub blocked_by_irreversible_migration: bool,
}Fields
previous_release_required: boolautomatic_allowed: boolblocked_by_irreversible_migration: boolTrait Implementations
Sourceimpl Clone for ReleaseRollbackConstraints
impl Clone for ReleaseRollbackConstraints
Sourcefn clone(&self) -> ReleaseRollbackConstraints
fn clone(&self) -> ReleaseRollbackConstraints
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ReleaseRollbackConstraints
impl ComposeSchema for ReleaseRollbackConstraints
impl Copy for ReleaseRollbackConstraints
Sourceimpl Debug for ReleaseRollbackConstraints
impl Debug for ReleaseRollbackConstraints
Sourceimpl<'de> Deserialize<'de> for ReleaseRollbackConstraints
impl<'de> Deserialize<'de> for ReleaseRollbackConstraints
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ReleaseRollbackConstraints
Sourceimpl JsonSchema for ReleaseRollbackConstraints
impl JsonSchema for ReleaseRollbackConstraints
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ReleaseRollbackConstraints