pub struct ReleaseRolloutGate {
pub gate_id: String,
pub evidence_kind: String,
pub required: bool,
}Fields
gate_id: Stringevidence_kind: Stringrequired: boolTrait Implementations
Sourceimpl Clone for ReleaseRolloutGate
impl Clone for ReleaseRolloutGate
Sourcefn clone(&self) -> ReleaseRolloutGate
fn clone(&self) -> ReleaseRolloutGate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ReleaseRolloutGate
impl ComposeSchema for ReleaseRolloutGate
Sourceimpl Debug for ReleaseRolloutGate
impl Debug for ReleaseRolloutGate
Sourceimpl<'de> Deserialize<'de> for ReleaseRolloutGate
impl<'de> Deserialize<'de> for ReleaseRolloutGate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ReleaseRolloutGate
Sourceimpl JsonSchema for ReleaseRolloutGate
impl JsonSchema for ReleaseRolloutGate
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for ReleaseRolloutGate
impl Ord for ReleaseRolloutGate
Sourcefn cmp(&self, other: &ReleaseRolloutGate) -> Ordering
fn cmp(&self, other: &ReleaseRolloutGate) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ReleaseRolloutGate
impl PartialEq for ReleaseRolloutGate
Sourceimpl PartialOrd for ReleaseRolloutGate
impl PartialOrd for ReleaseRolloutGate
Sourceimpl Serialize for ReleaseRolloutGate
impl Serialize for ReleaseRolloutGate
impl StructuralPartialEq for ReleaseRolloutGate