pub struct ReleaseSignature {
pub signer: String,
pub subject_digest: String,
pub signature: String,
}Fields
signer: Stringsubject_digest: Stringsignature: StringTrait Implementations
Sourceimpl Clone for ReleaseSignature
impl Clone for ReleaseSignature
Sourcefn clone(&self) -> ReleaseSignature
fn clone(&self) -> ReleaseSignature
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ReleaseSignature
impl ComposeSchema for ReleaseSignature
Sourceimpl Debug for ReleaseSignature
impl Debug for ReleaseSignature
Sourceimpl<'de> Deserialize<'de> for ReleaseSignature
impl<'de> Deserialize<'de> for ReleaseSignature
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ReleaseSignature
Sourceimpl JsonSchema for ReleaseSignature
impl JsonSchema for ReleaseSignature
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ReleaseSignature
impl PartialEq for ReleaseSignature
Sourceimpl Serialize for ReleaseSignature
impl Serialize for ReleaseSignature
impl StructuralPartialEq for ReleaseSignature