pub struct ReleaseTrustEvidence {
pub protocol: String,
pub release_id: String,
pub release_digest: String,
pub decision: DeliveryDecision,
pub evidence_digest: String,
pub workloads: Vec<WorkloadTrustEvidence>,
pub signatures: Vec<SignatureTrustEvidence>,
pub issues: Vec<DeliveryIssue>,
pub effects: DeliveryEffects,
}Fields
protocol: Stringrelease_id: Stringrelease_digest: Stringdecision: DeliveryDecisionevidence_digest: Stringworkloads: Vec<WorkloadTrustEvidence>signatures: Vec<SignatureTrustEvidence>issues: Vec<DeliveryIssue>effects: DeliveryEffectsTrait Implementations
Sourceimpl Clone for ReleaseTrustEvidence
impl Clone for ReleaseTrustEvidence
Sourcefn clone(&self) -> ReleaseTrustEvidence
fn clone(&self) -> ReleaseTrustEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ReleaseTrustEvidence
impl ComposeSchema for ReleaseTrustEvidence
Sourceimpl Debug for ReleaseTrustEvidence
impl Debug for ReleaseTrustEvidence
Sourceimpl<'de> Deserialize<'de> for ReleaseTrustEvidence
impl<'de> Deserialize<'de> for ReleaseTrustEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ReleaseTrustEvidence
Sourceimpl JsonSchema for ReleaseTrustEvidence
impl JsonSchema for ReleaseTrustEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ReleaseTrustEvidence
impl PartialEq for ReleaseTrustEvidence
Sourceimpl Serialize for ReleaseTrustEvidence
impl Serialize for ReleaseTrustEvidence
impl StructuralPartialEq for ReleaseTrustEvidence