pub struct ReliabilityObservation {Show 34 fields
pub protocol: String,
pub observation_id: String,
pub canary_plan_id: String,
pub canary_plan_digest: String,
pub release_id: String,
pub release_digest: String,
pub environment: String,
pub deployment_plan_id: String,
pub deployment_plan_digest: String,
pub deployment_observation_id: String,
pub collector_id: String,
pub collector_proof: String,
pub observed_revision: u64,
pub freshness_horizon_revision: u64,
pub fresh: bool,
pub observation_window_seconds: u64,
pub sample_count: u64,
pub generic_process_healthy: bool,
pub workload_readiness: BTreeMap<String, bool>,
pub workload_liveness: BTreeMap<String, bool>,
pub availability_basis_points: Option<u32>,
pub latency_p99_ms: Option<u64>,
pub error_budget_used_basis_points: Option<u32>,
pub queue_backlog: Option<u64>,
pub workflow_backlog: Option<u64>,
pub timer_lag_ms: Option<u64>,
pub retry_exhaustion: Option<u64>,
pub compensation_pressure: Option<u64>,
pub dependencies: Vec<DependencyReliabilityObservation>,
pub failure_domains: BTreeMap<String, bool>,
pub scaling_check_passed: Option<bool>,
pub disruption_check_passed: Option<bool>,
pub availability_check_passed: Option<bool>,
pub evidence_references: Vec<String>,
}Fields
protocol: Stringobservation_id: Stringcanary_plan_id: Stringcanary_plan_digest: Stringrelease_id: Stringrelease_digest: Stringenvironment: Stringdeployment_plan_id: Stringdeployment_plan_digest: Stringdeployment_observation_id: Stringcollector_id: Stringcollector_proof: Stringobserved_revision: u64freshness_horizon_revision: u64fresh: boolobservation_window_seconds: u64sample_count: u64generic_process_healthy: boolworkload_readiness: BTreeMap<String, bool>workload_liveness: BTreeMap<String, bool>availability_basis_points: Option<u32>latency_p99_ms: Option<u64>error_budget_used_basis_points: Option<u32>queue_backlog: Option<u64>workflow_backlog: Option<u64>timer_lag_ms: Option<u64>retry_exhaustion: Option<u64>compensation_pressure: Option<u64>dependencies: Vec<DependencyReliabilityObservation>failure_domains: BTreeMap<String, bool>scaling_check_passed: Option<bool>disruption_check_passed: Option<bool>availability_check_passed: Option<bool>evidence_references: Vec<String>Trait Implementations
Sourceimpl Clone for ReliabilityObservation
impl Clone for ReliabilityObservation
Sourcefn clone(&self) -> ReliabilityObservation
fn clone(&self) -> ReliabilityObservation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ReliabilityObservation
impl ComposeSchema for ReliabilityObservation
Sourceimpl Debug for ReliabilityObservation
impl Debug for ReliabilityObservation
Sourceimpl<'de> Deserialize<'de> for ReliabilityObservation
impl<'de> Deserialize<'de> for ReliabilityObservation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ReliabilityObservation
Sourceimpl JsonSchema for ReliabilityObservation
impl JsonSchema for ReliabilityObservation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ReliabilityObservation
impl PartialEq for ReliabilityObservation
Sourceimpl Serialize for ReliabilityObservation
impl Serialize for ReliabilityObservation
impl StructuralPartialEq for ReliabilityObservation