pub struct ResolvedEdgeRoute {
pub contract_id: String,
pub contract_version: String,
pub operation_id: String,
pub public_path: String,
pub authentication: EdgeAuthentication,
pub cors: CorsIntent,
pub rate: RateIntent,
pub deprecated: bool,
pub request_schema_reference: String,
pub response_schema_reference: String,
}Fields
contract_id: Stringcontract_version: Stringoperation_id: Stringpublic_path: Stringauthentication: EdgeAuthenticationcors: CorsIntentrate: RateIntentdeprecated: boolrequest_schema_reference: Stringresponse_schema_reference: StringTrait Implementations
Sourceimpl Clone for ResolvedEdgeRoute
impl Clone for ResolvedEdgeRoute
Sourcefn clone(&self) -> ResolvedEdgeRoute
fn clone(&self) -> ResolvedEdgeRoute
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ResolvedEdgeRoute
impl ComposeSchema for ResolvedEdgeRoute
Sourceimpl Debug for ResolvedEdgeRoute
impl Debug for ResolvedEdgeRoute
Sourceimpl<'de> Deserialize<'de> for ResolvedEdgeRoute
impl<'de> Deserialize<'de> for ResolvedEdgeRoute
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ResolvedEdgeRoute
Sourceimpl JsonSchema for ResolvedEdgeRoute
impl JsonSchema for ResolvedEdgeRoute
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ResolvedEdgeRoute
impl PartialEq for ResolvedEdgeRoute
Sourceimpl Serialize for ResolvedEdgeRoute
impl Serialize for ResolvedEdgeRoute
impl StructuralPartialEq for ResolvedEdgeRoute