pub struct RestoreIssue {
pub code: RestoreIssueCode,
pub message: String,
pub remediation: String,
pub next_actions: Vec<String>,
}Fields
code: RestoreIssueCodemessage: Stringremediation: Stringnext_actions: Vec<String>Trait Implementations
Sourceimpl Clone for RestoreIssue
impl Clone for RestoreIssue
Sourcefn clone(&self) -> RestoreIssue
fn clone(&self) -> RestoreIssue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RestoreIssue
impl ComposeSchema for RestoreIssue
Sourceimpl Debug for RestoreIssue
impl Debug for RestoreIssue
Sourceimpl<'de> Deserialize<'de> for RestoreIssue
impl<'de> Deserialize<'de> for RestoreIssue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RestoreIssue
Sourceimpl JsonSchema for RestoreIssue
impl JsonSchema for RestoreIssue
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RestoreIssue
impl PartialEq for RestoreIssue
Sourceimpl Serialize for RestoreIssue
impl Serialize for RestoreIssue
impl StructuralPartialEq for RestoreIssue