pub struct RetirementApproval {
pub plan_digest: String,
pub approver: String,
pub reason: String,
}Fields
plan_digest: Stringapprover: Stringreason: StringTrait Implementations
Sourceimpl Clone for RetirementApproval
impl Clone for RetirementApproval
Sourcefn clone(&self) -> RetirementApproval
fn clone(&self) -> RetirementApproval
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RetirementApproval
impl ComposeSchema for RetirementApproval
Sourceimpl Debug for RetirementApproval
impl Debug for RetirementApproval
Sourceimpl<'de> Deserialize<'de> for RetirementApproval
impl<'de> Deserialize<'de> for RetirementApproval
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RetirementApproval
Sourceimpl JsonSchema for RetirementApproval
impl JsonSchema for RetirementApproval
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RetirementApproval
impl PartialEq for RetirementApproval
Sourceimpl Serialize for RetirementApproval
impl Serialize for RetirementApproval
impl StructuralPartialEq for RetirementApproval