pub struct RollbackCompatibilityInput {Show 18 fields
pub prior_release_compatible: Option<bool>,
pub schema_compatible: Option<bool>,
pub workflow_compatible: Option<bool>,
pub config_compatible: Option<bool>,
pub secret_references_compatible: Option<bool>,
pub edge_compatible: Option<bool>,
pub adapter_capable: Option<bool>,
pub previous_release_id: String,
pub previous_release_digest: String,
pub previous_deployment_plan_id: String,
pub previous_deployment_plan_digest: String,
pub previous_config_revision_id: String,
pub previous_config_revision_digest: String,
pub previous_secret_reference_ids: Vec<String>,
pub previous_gateway_plan_id: String,
pub previous_gateway_plan_digest: String,
pub previous_gateway_configuration_identity: String,
pub previous_adapter: String,
}Fields
prior_release_compatible: Option<bool>schema_compatible: Option<bool>workflow_compatible: Option<bool>config_compatible: Option<bool>secret_references_compatible: Option<bool>edge_compatible: Option<bool>adapter_capable: Option<bool>previous_release_id: Stringprevious_release_digest: Stringprevious_deployment_plan_id: Stringprevious_deployment_plan_digest: Stringprevious_config_revision_id: Stringprevious_config_revision_digest: Stringprevious_secret_reference_ids: Vec<String>previous_gateway_plan_id: Stringprevious_gateway_plan_digest: Stringprevious_gateway_configuration_identity: Stringprevious_adapter: StringTrait Implementations
Sourceimpl Clone for RollbackCompatibilityInput
impl Clone for RollbackCompatibilityInput
Sourcefn clone(&self) -> RollbackCompatibilityInput
fn clone(&self) -> RollbackCompatibilityInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RollbackCompatibilityInput
impl ComposeSchema for RollbackCompatibilityInput
Sourceimpl Debug for RollbackCompatibilityInput
impl Debug for RollbackCompatibilityInput
Sourceimpl<'de> Deserialize<'de> for RollbackCompatibilityInput
impl<'de> Deserialize<'de> for RollbackCompatibilityInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RollbackCompatibilityInput
Sourceimpl JsonSchema for RollbackCompatibilityInput
impl JsonSchema for RollbackCompatibilityInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for RollbackCompatibilityInput