pub struct RollbackConvergenceEvidence {Show 21 fields
pub protocol: String,
pub evidence_id: String,
pub evidence_digest: String,
pub rollback_plan_id: String,
pub previous_deployment_plan_id: String,
pub previous_deployment_plan_digest: String,
pub previous_deployment_receipt_id: String,
pub deployment_observation_id: String,
pub previous_gateway_plan_id: String,
pub previous_gateway_plan_digest: String,
pub gateway_observation_id: String,
pub provider_id: String,
pub provider_proof: String,
pub observed_release_id: String,
pub observed_release_digest: String,
pub observed_config_revision_id: String,
pub observed_workload_digests: BTreeMap<String, String>,
pub observed_gateway_configuration_identity: String,
pub observed_gateway_revision: u64,
pub fresh: bool,
pub evidence_references: Vec<String>,
}Fields
protocol: Stringevidence_id: Stringevidence_digest: Stringrollback_plan_id: Stringprevious_deployment_plan_id: Stringprevious_deployment_plan_digest: Stringprevious_deployment_receipt_id: Stringdeployment_observation_id: Stringprevious_gateway_plan_id: Stringprevious_gateway_plan_digest: Stringgateway_observation_id: Stringprovider_id: Stringprovider_proof: Stringobserved_release_id: Stringobserved_release_digest: Stringobserved_config_revision_id: Stringobserved_workload_digests: BTreeMap<String, String>observed_gateway_configuration_identity: Stringobserved_gateway_revision: u64fresh: boolevidence_references: Vec<String>Trait Implementations
Sourceimpl Clone for RollbackConvergenceEvidence
impl Clone for RollbackConvergenceEvidence
Sourcefn clone(&self) -> RollbackConvergenceEvidence
fn clone(&self) -> RollbackConvergenceEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RollbackConvergenceEvidence
impl ComposeSchema for RollbackConvergenceEvidence
Sourceimpl Debug for RollbackConvergenceEvidence
impl Debug for RollbackConvergenceEvidence
Sourceimpl<'de> Deserialize<'de> for RollbackConvergenceEvidence
impl<'de> Deserialize<'de> for RollbackConvergenceEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RollbackConvergenceEvidence
Sourceimpl JsonSchema for RollbackConvergenceEvidence
impl JsonSchema for RollbackConvergenceEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for RollbackConvergenceEvidence