pub struct RollbackPlan {Show 32 fields
pub protocol: String,
pub plan_id: String,
pub plan_digest: String,
pub canary_plan_id: String,
pub canary_plan_digest: String,
pub canary_decision_id: String,
pub environment: String,
pub expected_environment_revision: u64,
pub failed_release_id: String,
pub failed_release_digest: String,
pub failed_deployment_plan_id: String,
pub failed_deployment_plan_digest: String,
pub failed_config_revision_id: String,
pub failed_workload_digests: BTreeMap<String, String>,
pub failed_gateway_plan_id: String,
pub failed_gateway_plan_digest: String,
pub previous_release_id: String,
pub previous_release_digest: String,
pub previous_deployment_plan_id: String,
pub previous_deployment_plan_digest: String,
pub previous_config_revision_id: String,
pub previous_workload_digests: BTreeMap<String, String>,
pub previous_gateway_plan_id: String,
pub previous_gateway_plan_digest: String,
pub previous_gateway_configuration_identity: String,
pub previous_gateway_revision: u64,
pub release_rollback_constraints: ReleaseRollbackConstraints,
pub safety: RollbackSafetyEvidence,
pub automatic_allowed: bool,
pub issues: Vec<DeliveryIssue>,
pub prohibited_actions: Vec<String>,
pub effects: DeliveryEffects,
}Fields
protocol: Stringplan_id: Stringplan_digest: Stringcanary_plan_id: Stringcanary_plan_digest: Stringcanary_decision_id: Stringenvironment: Stringexpected_environment_revision: u64failed_release_id: Stringfailed_release_digest: Stringfailed_deployment_plan_id: Stringfailed_deployment_plan_digest: Stringfailed_config_revision_id: Stringfailed_workload_digests: BTreeMap<String, String>failed_gateway_plan_id: Stringfailed_gateway_plan_digest: Stringprevious_release_id: Stringprevious_release_digest: Stringprevious_deployment_plan_id: Stringprevious_deployment_plan_digest: Stringprevious_config_revision_id: Stringprevious_workload_digests: BTreeMap<String, String>previous_gateway_plan_id: Stringprevious_gateway_plan_digest: Stringprevious_gateway_configuration_identity: Stringprevious_gateway_revision: u64release_rollback_constraints: ReleaseRollbackConstraintssafety: RollbackSafetyEvidenceautomatic_allowed: boolissues: Vec<DeliveryIssue>prohibited_actions: Vec<String>effects: DeliveryEffectsTrait Implementations
Sourceimpl Clone for RollbackPlan
impl Clone for RollbackPlan
Sourcefn clone(&self) -> RollbackPlan
fn clone(&self) -> RollbackPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RollbackPlan
impl ComposeSchema for RollbackPlan
Sourceimpl Debug for RollbackPlan
impl Debug for RollbackPlan
Sourceimpl<'de> Deserialize<'de> for RollbackPlan
impl<'de> Deserialize<'de> for RollbackPlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RollbackPlan
Sourceimpl JsonSchema for RollbackPlan
impl JsonSchema for RollbackPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RollbackPlan
impl PartialEq for RollbackPlan
Sourceimpl Serialize for RollbackPlan
impl Serialize for RollbackPlan
impl StructuralPartialEq for RollbackPlan