pub struct RollbackReceipt {Show 14 fields
pub protocol: String,
pub receipt_id: String,
pub plan_id: String,
pub actor: String,
pub outcome: RollbackOutcome,
pub restored_release_id: String,
pub restored_config_revision_id: String,
pub environment_revision_before: u64,
pub environment_revision_after: u64,
pub exposure_percent: u8,
pub remaining_risks: Vec<DeliveryIssue>,
pub approval_boundary_required: bool,
pub evidence_references: Vec<String>,
pub effects: DeliveryEffects,
}Fields
protocol: Stringreceipt_id: Stringplan_id: Stringactor: Stringoutcome: RollbackOutcomerestored_release_id: Stringrestored_config_revision_id: Stringenvironment_revision_before: u64environment_revision_after: u64exposure_percent: u8remaining_risks: Vec<DeliveryIssue>approval_boundary_required: boolevidence_references: Vec<String>effects: DeliveryEffectsTrait Implementations
Sourceimpl Clone for RollbackReceipt
impl Clone for RollbackReceipt
Sourcefn clone(&self) -> RollbackReceipt
fn clone(&self) -> RollbackReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RollbackReceipt
impl ComposeSchema for RollbackReceipt
Sourceimpl Debug for RollbackReceipt
impl Debug for RollbackReceipt
Sourceimpl<'de> Deserialize<'de> for RollbackReceipt
impl<'de> Deserialize<'de> for RollbackReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RollbackReceipt
Sourceimpl JsonSchema for RollbackReceipt
impl JsonSchema for RollbackReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RollbackReceipt
impl PartialEq for RollbackReceipt
Sourceimpl Serialize for RollbackReceipt
impl Serialize for RollbackReceipt
impl StructuralPartialEq for RollbackReceipt