pub struct RollbackSafetyEvidence {Show 17 fields
pub protocol: String,
pub evidence_id: String,
pub canary_plan_id: String,
pub failed_deployment_plan_id: String,
pub previous_deployment_plan_id: String,
pub expected_environment_revision: u64,
pub provider_id: String,
pub provider_proof: String,
pub migrations_reversible: bool,
pub destructive_changes_absent: bool,
pub workflows_downgrade_safe: bool,
pub config_revision_compatible: bool,
pub secret_references_resolvable: bool,
pub edge_configuration_compatible: bool,
pub adapter_recovery_complete: bool,
pub policy_approved: bool,
pub evidence_references: Vec<String>,
}Fields
protocol: Stringevidence_id: Stringcanary_plan_id: Stringfailed_deployment_plan_id: Stringprevious_deployment_plan_id: Stringexpected_environment_revision: u64provider_id: Stringprovider_proof: Stringmigrations_reversible: booldestructive_changes_absent: boolworkflows_downgrade_safe: boolconfig_revision_compatible: boolsecret_references_resolvable: booledge_configuration_compatible: booladapter_recovery_complete: boolpolicy_approved: boolevidence_references: Vec<String>Trait Implementations
Sourceimpl Clone for RollbackSafetyEvidence
impl Clone for RollbackSafetyEvidence
Sourcefn clone(&self) -> RollbackSafetyEvidence
fn clone(&self) -> RollbackSafetyEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RollbackSafetyEvidence
impl ComposeSchema for RollbackSafetyEvidence
Sourceimpl Debug for RollbackSafetyEvidence
impl Debug for RollbackSafetyEvidence
Sourceimpl<'de> Deserialize<'de> for RollbackSafetyEvidence
impl<'de> Deserialize<'de> for RollbackSafetyEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RollbackSafetyEvidence
Sourceimpl JsonSchema for RollbackSafetyEvidence
impl JsonSchema for RollbackSafetyEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RollbackSafetyEvidence
impl PartialEq for RollbackSafetyEvidence
Sourceimpl Serialize for RollbackSafetyEvidence
impl Serialize for RollbackSafetyEvidence
impl StructuralPartialEq for RollbackSafetyEvidence