pub struct SecretReference {
pub reference_id: String,
pub provider: String,
pub purpose: String,
pub scope: String,
pub status: SecretReferenceStatus,
pub metadata: BTreeMap<String, String>,
}Fields
reference_id: Stringprovider: Stringpurpose: Stringscope: Stringstatus: SecretReferenceStatusmetadata: BTreeMap<String, String>Trait Implementations
Sourceimpl Clone for SecretReference
impl Clone for SecretReference
Sourcefn clone(&self) -> SecretReference
fn clone(&self) -> SecretReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for SecretReference
impl ComposeSchema for SecretReference
Sourceimpl Debug for SecretReference
impl Debug for SecretReference
Sourceimpl<'de> Deserialize<'de> for SecretReference
impl<'de> Deserialize<'de> for SecretReference
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SecretReference
Sourceimpl JsonSchema for SecretReference
impl JsonSchema for SecretReference
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SecretReference
impl PartialEq for SecretReference
Sourceimpl Serialize for SecretReference
impl Serialize for SecretReference
impl StructuralPartialEq for SecretReference