pub struct SecretReferenceObservation {
pub status: SecretReferenceStatus,
pub metadata: BTreeMap<String, String>,
}Fields
status: SecretReferenceStatusmetadata: BTreeMap<String, String>Trait Implementations
Sourceimpl Clone for SecretReferenceObservation
impl Clone for SecretReferenceObservation
Sourcefn clone(&self) -> SecretReferenceObservation
fn clone(&self) -> SecretReferenceObservation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for SecretReferenceObservation
impl ComposeSchema for SecretReferenceObservation
Sourceimpl Debug for SecretReferenceObservation
impl Debug for SecretReferenceObservation
Sourceimpl<'de> Deserialize<'de> for SecretReferenceObservation
impl<'de> Deserialize<'de> for SecretReferenceObservation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SecretReferenceObservation
Sourceimpl JsonSchema for SecretReferenceObservation
impl JsonSchema for SecretReferenceObservation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for SecretReferenceObservation