pub struct SecurityContinuity {
pub workload_identity_enforced: bool,
pub tenant_context_enforced: bool,
pub call_policy_enforced: bool,
pub service_authorization_enforced: bool,
}Fields
workload_identity_enforced: booltenant_context_enforced: boolcall_policy_enforced: boolTrait Implementations
Sourceimpl Clone for SecurityContinuity
impl Clone for SecurityContinuity
Sourcefn clone(&self) -> SecurityContinuity
fn clone(&self) -> SecurityContinuity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for SecurityContinuity
impl ComposeSchema for SecurityContinuity
Sourceimpl Debug for SecurityContinuity
impl Debug for SecurityContinuity
Sourceimpl<'de> Deserialize<'de> for SecurityContinuity
impl<'de> Deserialize<'de> for SecurityContinuity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SecurityContinuity
Sourceimpl JsonSchema for SecurityContinuity
impl JsonSchema for SecurityContinuity
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SecurityContinuity
impl PartialEq for SecurityContinuity
Sourceimpl Serialize for SecurityContinuity
impl Serialize for SecurityContinuity
impl StructuralPartialEq for SecurityContinuity