pub struct SecurityFinding {
pub finding_id: String,
pub finding_digest: String,
pub severity: SecuritySeverity,
pub surface: ThreatSurface,
pub affected_subject_digests: Vec<String>,
pub owner: String,
pub disposition: FindingDisposition,
pub remediation_reference: Option<String>,
pub risk_acceptance: Option<RiskAcceptance>,
pub contains_sensitive_material: bool,
}Fields
finding_id: Stringfinding_digest: Stringseverity: SecuritySeveritysurface: ThreatSurfaceaffected_subject_digests: Vec<String>owner: Stringdisposition: FindingDispositionremediation_reference: Option<String>risk_acceptance: Option<RiskAcceptance>contains_sensitive_material: boolTrait Implementations
Sourceimpl Clone for SecurityFinding
impl Clone for SecurityFinding
Sourcefn clone(&self) -> SecurityFinding
fn clone(&self) -> SecurityFinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for SecurityFinding
impl ComposeSchema for SecurityFinding
Sourceimpl Debug for SecurityFinding
impl Debug for SecurityFinding
Sourceimpl<'de> Deserialize<'de> for SecurityFinding
impl<'de> Deserialize<'de> for SecurityFinding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SecurityFinding
Sourceimpl JsonSchema for SecurityFinding
impl JsonSchema for SecurityFinding
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SecurityFinding
impl PartialEq for SecurityFinding
Sourceimpl Serialize for SecurityFinding
impl Serialize for SecurityFinding
impl StructuralPartialEq for SecurityFinding