pub struct SecurityReleaseSubject {
pub component_id: String,
pub version: String,
pub source_commit: String,
pub artifact_digest: String,
pub provenance_digest: String,
pub sbom_digest: String,
}Fields
component_id: Stringversion: Stringsource_commit: Stringartifact_digest: Stringprovenance_digest: Stringsbom_digest: StringTrait Implementations
Sourceimpl Clone for SecurityReleaseSubject
impl Clone for SecurityReleaseSubject
Sourcefn clone(&self) -> SecurityReleaseSubject
fn clone(&self) -> SecurityReleaseSubject
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for SecurityReleaseSubject
impl ComposeSchema for SecurityReleaseSubject
Sourceimpl Debug for SecurityReleaseSubject
impl Debug for SecurityReleaseSubject
Sourceimpl<'de> Deserialize<'de> for SecurityReleaseSubject
impl<'de> Deserialize<'de> for SecurityReleaseSubject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SecurityReleaseSubject
Sourceimpl JsonSchema for SecurityReleaseSubject
impl JsonSchema for SecurityReleaseSubject
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SecurityReleaseSubject
impl PartialEq for SecurityReleaseSubject
Sourceimpl Serialize for SecurityReleaseSubject
impl Serialize for SecurityReleaseSubject
impl StructuralPartialEq for SecurityReleaseSubject