pub struct SecurityReviewInput {
pub support_manifest_digest: String,
pub release_subjects: Vec<SecurityReleaseSubject>,
pub threat_models: Vec<ThreatModelEvidence>,
pub findings: Vec<SecurityFinding>,
pub scans: Vec<SecurityScanEvidence>,
pub reviewer: String,
pub reviewed_at_unix_ms: u64,
pub freshness_horizon_unix_ms: u64,
}Fields
support_manifest_digest: Stringrelease_subjects: Vec<SecurityReleaseSubject>threat_models: Vec<ThreatModelEvidence>findings: Vec<SecurityFinding>scans: Vec<SecurityScanEvidence>reviewer: Stringreviewed_at_unix_ms: u64freshness_horizon_unix_ms: u64Trait Implementations
Sourceimpl Clone for SecurityReviewInput
impl Clone for SecurityReviewInput
Sourcefn clone(&self) -> SecurityReviewInput
fn clone(&self) -> SecurityReviewInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for SecurityReviewInput
impl ComposeSchema for SecurityReviewInput
Sourceimpl Debug for SecurityReviewInput
impl Debug for SecurityReviewInput
Sourceimpl<'de> Deserialize<'de> for SecurityReviewInput
impl<'de> Deserialize<'de> for SecurityReviewInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SecurityReviewInput
Sourceimpl JsonSchema for SecurityReviewInput
impl JsonSchema for SecurityReviewInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SecurityReviewInput
impl PartialEq for SecurityReviewInput
Sourceimpl Serialize for SecurityReviewInput
impl Serialize for SecurityReviewInput
impl StructuralPartialEq for SecurityReviewInput