pub struct SecurityReviewIssue {
pub code: SecurityReviewIssueCode,
pub message: String,
pub remediation: String,
pub next_actions: Vec<String>,
}Fields
code: SecurityReviewIssueCodemessage: Stringremediation: Stringnext_actions: Vec<String>Trait Implementations
Sourceimpl Clone for SecurityReviewIssue
impl Clone for SecurityReviewIssue
Sourcefn clone(&self) -> SecurityReviewIssue
fn clone(&self) -> SecurityReviewIssue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for SecurityReviewIssue
impl ComposeSchema for SecurityReviewIssue
Sourceimpl Debug for SecurityReviewIssue
impl Debug for SecurityReviewIssue
Sourceimpl<'de> Deserialize<'de> for SecurityReviewIssue
impl<'de> Deserialize<'de> for SecurityReviewIssue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SecurityReviewIssue
Sourceimpl JsonSchema for SecurityReviewIssue
impl JsonSchema for SecurityReviewIssue
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SecurityReviewIssue
impl PartialEq for SecurityReviewIssue
Sourceimpl Serialize for SecurityReviewIssue
impl Serialize for SecurityReviewIssue
impl StructuralPartialEq for SecurityReviewIssue