pub struct SecurityScanEvidence {
pub scanner_id: String,
pub scanner_version: String,
pub subject_digest: String,
pub result_digest: String,
pub completed: bool,
}Fields
scanner_id: Stringscanner_version: Stringsubject_digest: Stringresult_digest: Stringcompleted: boolTrait Implementations
Sourceimpl Clone for SecurityScanEvidence
impl Clone for SecurityScanEvidence
Sourcefn clone(&self) -> SecurityScanEvidence
fn clone(&self) -> SecurityScanEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for SecurityScanEvidence
impl ComposeSchema for SecurityScanEvidence
Sourceimpl Debug for SecurityScanEvidence
impl Debug for SecurityScanEvidence
Sourceimpl<'de> Deserialize<'de> for SecurityScanEvidence
impl<'de> Deserialize<'de> for SecurityScanEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SecurityScanEvidence
Sourceimpl JsonSchema for SecurityScanEvidence
impl JsonSchema for SecurityScanEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SecurityScanEvidence
impl PartialEq for SecurityScanEvidence
Sourceimpl Serialize for SecurityScanEvidence
impl Serialize for SecurityScanEvidence
impl StructuralPartialEq for SecurityScanEvidence