pub struct ServiceBackup {
pub protocol: String,
pub backup_id: String,
pub backup_digest: String,
pub input: ServiceBackupInput,
}Fields
protocol: Stringbackup_id: Stringbackup_digest: Stringinput: ServiceBackupInputTrait Implementations
Sourceimpl Clone for ServiceBackup
impl Clone for ServiceBackup
Sourcefn clone(&self) -> ServiceBackup
fn clone(&self) -> ServiceBackup
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ServiceBackup
impl ComposeSchema for ServiceBackup
Sourceimpl Debug for ServiceBackup
impl Debug for ServiceBackup
Sourceimpl<'de> Deserialize<'de> for ServiceBackup
impl<'de> Deserialize<'de> for ServiceBackup
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServiceBackup
Sourceimpl JsonSchema for ServiceBackup
impl JsonSchema for ServiceBackup
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServiceBackup
impl PartialEq for ServiceBackup
Sourceimpl Serialize for ServiceBackup
impl Serialize for ServiceBackup
impl StructuralPartialEq for ServiceBackup