pub struct ServiceBackupInput {Show 23 fields
pub service_id: String,
pub store_id: String,
pub format_version: String,
pub schema_version: String,
pub release_digest: String,
pub config_revision_digest: String,
pub contract_version_digests: BTreeMap<String, String>,
pub store_checkpoint_digest: String,
pub broker_position: Option<u64>,
pub restore_preconditions: Vec<String>,
pub point_in_time_unix_ms: u64,
pub captured_at_unix_ms: u64,
pub freshness_horizon_unix_ms: u64,
pub snapshot_digest: String,
pub post_checkpoint_work_digest: String,
pub encryption_key_reference: String,
pub encryption_algorithm: String,
pub state_digests: BTreeMap<String, String>,
pub outbox_sequence: u64,
pub inbox_sequence: u64,
pub workflow_timer_sequence: u64,
pub story_sequence: u64,
pub completed: bool,
}Fields
service_id: Stringstore_id: Stringformat_version: Stringschema_version: Stringrelease_digest: Stringconfig_revision_digest: Stringcontract_version_digests: BTreeMap<String, String>store_checkpoint_digest: Stringbroker_position: Option<u64>restore_preconditions: Vec<String>point_in_time_unix_ms: u64captured_at_unix_ms: u64freshness_horizon_unix_ms: u64snapshot_digest: Stringpost_checkpoint_work_digest: Stringencryption_key_reference: Stringencryption_algorithm: Stringstate_digests: BTreeMap<String, String>outbox_sequence: u64inbox_sequence: u64workflow_timer_sequence: u64story_sequence: u64completed: boolTrait Implementations
Sourceimpl Clone for ServiceBackupInput
impl Clone for ServiceBackupInput
Sourcefn clone(&self) -> ServiceBackupInput
fn clone(&self) -> ServiceBackupInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ServiceBackupInput
impl ComposeSchema for ServiceBackupInput
Sourceimpl Debug for ServiceBackupInput
impl Debug for ServiceBackupInput
Sourceimpl<'de> Deserialize<'de> for ServiceBackupInput
impl<'de> Deserialize<'de> for ServiceBackupInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServiceBackupInput
Sourceimpl JsonSchema for ServiceBackupInput
impl JsonSchema for ServiceBackupInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServiceBackupInput
impl PartialEq for ServiceBackupInput
Sourceimpl Serialize for ServiceBackupInput
impl Serialize for ServiceBackupInput
impl StructuralPartialEq for ServiceBackupInput