pub struct ServiceModuleDelivery {
pub service_id: String,
pub service_release_version: String,
pub service_release_digest: String,
pub export: String,
pub responsibility_profile: ServiceResponsibilityProfile,
pub contract_digests: Vec<String>,
}Fields
service_id: Stringservice_release_version: Stringservice_release_digest: Stringexport: Stringresponsibility_profile: ServiceResponsibilityProfilecontract_digests: Vec<String>Trait Implementations
Sourceimpl Clone for ServiceModuleDelivery
impl Clone for ServiceModuleDelivery
Sourcefn clone(&self) -> ServiceModuleDelivery
fn clone(&self) -> ServiceModuleDelivery
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServiceModuleDelivery
impl Debug for ServiceModuleDelivery
Sourceimpl<'de> Deserialize<'de> for ServiceModuleDelivery
impl<'de> Deserialize<'de> for ServiceModuleDelivery
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ServiceModuleDelivery, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ServiceModuleDelivery, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServiceModuleDelivery
Sourceimpl JsonSchema for ServiceModuleDelivery
impl JsonSchema for ServiceModuleDelivery
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServiceModuleDelivery
impl PartialEq for ServiceModuleDelivery
Sourceimpl Serialize for ServiceModuleDelivery
impl Serialize for ServiceModuleDelivery
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ServiceModuleDelivery