pub struct ServiceRelease {Show 17 fields
pub protocol: String,
pub release_id: String,
pub release_digest: String,
pub service_id: String,
pub service_version: String,
pub modules: Vec<ReleaseModule>,
pub workloads: Vec<WorkloadArtifact>,
pub contract_versions: Vec<ReleaseContractVersion>,
pub config_contract: DeliveryEvidenceReference,
pub reliability_contract: DeliveryEvidenceReference,
pub migrations: Vec<ReleaseMigration>,
pub workflow_compatibility: Vec<DeliveryEvidenceReference>,
pub verification_evidence: Vec<DeliveryEvidenceReference>,
pub rollout_gates: Vec<ReleaseRolloutGate>,
pub rollback: ReleaseRollbackConstraints,
pub retention: ReleaseRetention,
pub signatures: Vec<ReleaseSignature>,
}Fields
protocol: Stringrelease_id: Stringrelease_digest: Stringservice_id: Stringservice_version: Stringmodules: Vec<ReleaseModule>workloads: Vec<WorkloadArtifact>contract_versions: Vec<ReleaseContractVersion>config_contract: DeliveryEvidenceReferencereliability_contract: DeliveryEvidenceReferencemigrations: Vec<ReleaseMigration>workflow_compatibility: Vec<DeliveryEvidenceReference>verification_evidence: Vec<DeliveryEvidenceReference>rollout_gates: Vec<ReleaseRolloutGate>rollback: ReleaseRollbackConstraintsretention: ReleaseRetentionsignatures: Vec<ReleaseSignature>Trait Implementations
Sourceimpl Clone for ServiceRelease
impl Clone for ServiceRelease
Sourcefn clone(&self) -> ServiceRelease
fn clone(&self) -> ServiceRelease
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ServiceRelease
impl ComposeSchema for ServiceRelease
Sourceimpl Debug for ServiceRelease
impl Debug for ServiceRelease
Sourceimpl<'de> Deserialize<'de> for ServiceRelease
impl<'de> Deserialize<'de> for ServiceRelease
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServiceRelease
Sourceimpl JsonSchema for ServiceRelease
impl JsonSchema for ServiceRelease
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServiceRelease
impl PartialEq for ServiceRelease
Sourceimpl Serialize for ServiceRelease
impl Serialize for ServiceRelease
impl StructuralPartialEq for ServiceRelease