pub struct ServiceRestoreEvidence {Show 22 fields
pub protocol: String,
pub evidence_id: String,
pub evidence_digest: String,
pub backup_id: String,
pub backup_digest: String,
pub service_id: String,
pub source_store_id: String,
pub target_store_id: String,
pub point_in_time_unix_ms: u64,
pub format_version: String,
pub schema_version: String,
pub contract_version_digests: BTreeMap<String, String>,
pub restored_state_digests: BTreeMap<String, String>,
pub recovery_time_ms: u64,
pub intentional_loss_bound_ms: u64,
pub replay_bound_count: u64,
pub remaining_story_gaps: Vec<String>,
pub cleanup_complete: bool,
pub decision: RestoreDecision,
pub issues: Vec<RestoreIssue>,
pub next_actions: Vec<String>,
pub production_mutated: bool,
}Fields
protocol: Stringevidence_id: Stringevidence_digest: Stringbackup_id: Stringbackup_digest: Stringservice_id: Stringsource_store_id: Stringtarget_store_id: Stringpoint_in_time_unix_ms: u64format_version: Stringschema_version: Stringcontract_version_digests: BTreeMap<String, String>restored_state_digests: BTreeMap<String, String>recovery_time_ms: u64intentional_loss_bound_ms: u64replay_bound_count: u64remaining_story_gaps: Vec<String>cleanup_complete: booldecision: RestoreDecisionissues: Vec<RestoreIssue>next_actions: Vec<String>production_mutated: boolTrait Implementations
Sourceimpl Clone for ServiceRestoreEvidence
impl Clone for ServiceRestoreEvidence
Sourcefn clone(&self) -> ServiceRestoreEvidence
fn clone(&self) -> ServiceRestoreEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ServiceRestoreEvidence
impl ComposeSchema for ServiceRestoreEvidence
Sourceimpl Debug for ServiceRestoreEvidence
impl Debug for ServiceRestoreEvidence
Sourceimpl<'de> Deserialize<'de> for ServiceRestoreEvidence
impl<'de> Deserialize<'de> for ServiceRestoreEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServiceRestoreEvidence
Sourceimpl JsonSchema for ServiceRestoreEvidence
impl JsonSchema for ServiceRestoreEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServiceRestoreEvidence
impl PartialEq for ServiceRestoreEvidence
Sourceimpl Serialize for ServiceRestoreEvidence
impl Serialize for ServiceRestoreEvidence
impl StructuralPartialEq for ServiceRestoreEvidence