pub struct ServiceRestoreInput {Show 29 fields
pub backup: ServiceBackup,
pub target_store_id: String,
pub target_was_clean: bool,
pub expected_service_id: String,
pub expected_format_version: String,
pub expected_schema_version: String,
pub expected_release_digest: String,
pub expected_config_revision_digest: String,
pub expected_contract_version_digests: BTreeMap<String, String>,
pub key_reference_available: bool,
pub observed_at_unix_ms: u64,
pub restored_snapshot_digest: String,
pub restored_state_digests: BTreeMap<String, String>,
pub restored_contract_version_digests: BTreeMap<String, String>,
pub restored_release_digest: String,
pub restored_config_revision_digest: String,
pub replay_outbox_from_sequence: u64,
pub replay_inbox_from_sequence: u64,
pub restored_workflow_timer_sequence: u64,
pub restored_story_sequence: u64,
pub authoritative_workload_count: u32,
pub business_invariants_verified: bool,
pub post_checkpoint_work_reconciled: bool,
pub recovery_time_ms: u64,
pub intentional_loss_bound_ms: u64,
pub replay_bound_count: u64,
pub remaining_story_gaps: Vec<String>,
pub cleanup_complete: bool,
pub postgres: PostgresRestoreObservation,
}Fields
backup: ServiceBackuptarget_store_id: Stringtarget_was_clean: boolexpected_service_id: Stringexpected_format_version: Stringexpected_schema_version: Stringexpected_release_digest: Stringexpected_config_revision_digest: Stringexpected_contract_version_digests: BTreeMap<String, String>key_reference_available: boolobserved_at_unix_ms: u64restored_snapshot_digest: Stringrestored_state_digests: BTreeMap<String, String>restored_contract_version_digests: BTreeMap<String, String>restored_release_digest: Stringrestored_config_revision_digest: Stringreplay_outbox_from_sequence: u64replay_inbox_from_sequence: u64restored_workflow_timer_sequence: u64restored_story_sequence: u64business_invariants_verified: boolpost_checkpoint_work_reconciled: boolrecovery_time_ms: u64intentional_loss_bound_ms: u64replay_bound_count: u64remaining_story_gaps: Vec<String>cleanup_complete: boolpostgres: PostgresRestoreObservationTrait Implementations
Sourceimpl Clone for ServiceRestoreInput
impl Clone for ServiceRestoreInput
Sourcefn clone(&self) -> ServiceRestoreInput
fn clone(&self) -> ServiceRestoreInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ServiceRestoreInput
impl ComposeSchema for ServiceRestoreInput
Sourceimpl Debug for ServiceRestoreInput
impl Debug for ServiceRestoreInput
Sourceimpl<'de> Deserialize<'de> for ServiceRestoreInput
impl<'de> Deserialize<'de> for ServiceRestoreInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServiceRestoreInput
Sourceimpl JsonSchema for ServiceRestoreInput
impl JsonSchema for ServiceRestoreInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServiceRestoreInput
impl PartialEq for ServiceRestoreInput
Sourceimpl Serialize for ServiceRestoreInput
impl Serialize for ServiceRestoreInput
impl StructuralPartialEq for ServiceRestoreInput