pub struct ServiceUpgradeAdmission {
pub protocol: String,
pub plan_digest: String,
pub workload: UpgradeWorkload,
pub decision: SupportDecision,
pub claims_work: bool,
pub mutates_state: bool,
pub issues: Vec<GaIssue>,
pub next_actions: Vec<String>,
}Fields
protocol: Stringplan_digest: Stringworkload: UpgradeWorkloaddecision: SupportDecisionclaims_work: boolmutates_state: boolissues: Vec<GaIssue>next_actions: Vec<String>Trait Implementations
Sourceimpl Clone for ServiceUpgradeAdmission
impl Clone for ServiceUpgradeAdmission
Sourcefn clone(&self) -> ServiceUpgradeAdmission
fn clone(&self) -> ServiceUpgradeAdmission
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ServiceUpgradeAdmission
impl ComposeSchema for ServiceUpgradeAdmission
Sourceimpl Debug for ServiceUpgradeAdmission
impl Debug for ServiceUpgradeAdmission
Sourceimpl<'de> Deserialize<'de> for ServiceUpgradeAdmission
impl<'de> Deserialize<'de> for ServiceUpgradeAdmission
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServiceUpgradeAdmission
Sourceimpl JsonSchema for ServiceUpgradeAdmission
impl JsonSchema for ServiceUpgradeAdmission
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServiceUpgradeAdmission
impl PartialEq for ServiceUpgradeAdmission
Sourceimpl Serialize for ServiceUpgradeAdmission
impl Serialize for ServiceUpgradeAdmission
impl StructuralPartialEq for ServiceUpgradeAdmission