pub struct ServiceUpgradeInput {
pub service_id: String,
pub from_release_id: String,
pub from_release_digest: String,
pub to_release_id: String,
pub to_release_digest: String,
pub config_revision_id: String,
pub config_revision_digest: String,
pub source_state_version: String,
pub target_state_version: String,
pub workflow_artifact_digests: Vec<String>,
}Fields
service_id: Stringfrom_release_id: Stringfrom_release_digest: Stringto_release_id: Stringto_release_digest: Stringconfig_revision_id: Stringconfig_revision_digest: Stringsource_state_version: Stringtarget_state_version: Stringworkflow_artifact_digests: Vec<String>Trait Implementations
Sourceimpl Clone for ServiceUpgradeInput
impl Clone for ServiceUpgradeInput
Sourcefn clone(&self) -> ServiceUpgradeInput
fn clone(&self) -> ServiceUpgradeInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ServiceUpgradeInput
impl ComposeSchema for ServiceUpgradeInput
Sourceimpl Debug for ServiceUpgradeInput
impl Debug for ServiceUpgradeInput
Sourceimpl<'de> Deserialize<'de> for ServiceUpgradeInput
impl<'de> Deserialize<'de> for ServiceUpgradeInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServiceUpgradeInput
Sourceimpl JsonSchema for ServiceUpgradeInput
impl JsonSchema for ServiceUpgradeInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServiceUpgradeInput
impl PartialEq for ServiceUpgradeInput
Sourceimpl Serialize for ServiceUpgradeInput
impl Serialize for ServiceUpgradeInput
impl StructuralPartialEq for ServiceUpgradeInput