pub struct ServiceUpgradePlan {
pub protocol: String,
pub plan_id: String,
pub plan_digest: String,
pub manifest_id: String,
pub manifest_digest: String,
pub input: ServiceUpgradeInput,
pub steps: Vec<ServiceUpgradeStep>,
pub mixed_version_references: Vec<String>,
pub preserved_identities: Vec<String>,
pub rollback: UpgradeRollbackConstraint,
}Fields
protocol: Stringplan_id: Stringplan_digest: Stringmanifest_id: Stringmanifest_digest: Stringinput: ServiceUpgradeInputsteps: Vec<ServiceUpgradeStep>mixed_version_references: Vec<String>preserved_identities: Vec<String>rollback: UpgradeRollbackConstraintTrait Implementations
Sourceimpl Clone for ServiceUpgradePlan
impl Clone for ServiceUpgradePlan
Sourcefn clone(&self) -> ServiceUpgradePlan
fn clone(&self) -> ServiceUpgradePlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ServiceUpgradePlan
impl ComposeSchema for ServiceUpgradePlan
Sourceimpl Debug for ServiceUpgradePlan
impl Debug for ServiceUpgradePlan
Sourceimpl<'de> Deserialize<'de> for ServiceUpgradePlan
impl<'de> Deserialize<'de> for ServiceUpgradePlan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServiceUpgradePlan
Sourceimpl JsonSchema for ServiceUpgradePlan
impl JsonSchema for ServiceUpgradePlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServiceUpgradePlan
impl PartialEq for ServiceUpgradePlan
Sourceimpl Serialize for ServiceUpgradePlan
impl Serialize for ServiceUpgradePlan
impl StructuralPartialEq for ServiceUpgradePlan