pub struct ServiceUpgradeRuntimeObservation {
pub workload: UpgradeWorkload,
pub current_release_id: String,
pub current_state_version: String,
pub migration_completed: bool,
pub workflow_artifact_digests: Vec<String>,
}Fields
workload: UpgradeWorkloadcurrent_release_id: Stringcurrent_state_version: Stringmigration_completed: boolworkflow_artifact_digests: Vec<String>Trait Implementations
Sourceimpl Clone for ServiceUpgradeRuntimeObservation
impl Clone for ServiceUpgradeRuntimeObservation
Sourcefn clone(&self) -> ServiceUpgradeRuntimeObservation
fn clone(&self) -> ServiceUpgradeRuntimeObservation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ServiceUpgradeRuntimeObservation
impl ComposeSchema for ServiceUpgradeRuntimeObservation
Sourceimpl<'de> Deserialize<'de> for ServiceUpgradeRuntimeObservation
impl<'de> Deserialize<'de> for ServiceUpgradeRuntimeObservation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServiceUpgradeRuntimeObservation
Sourceimpl JsonSchema for ServiceUpgradeRuntimeObservation
impl JsonSchema for ServiceUpgradeRuntimeObservation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ServiceUpgradeRuntimeObservation