pub struct ServiceUpgradeStep {
pub sequence: u32,
pub workload: UpgradeWorkload,
pub precondition: String,
pub expected_state_version: String,
}Fields
sequence: u32workload: UpgradeWorkloadprecondition: Stringexpected_state_version: StringTrait Implementations
Sourceimpl Clone for ServiceUpgradeStep
impl Clone for ServiceUpgradeStep
Sourcefn clone(&self) -> ServiceUpgradeStep
fn clone(&self) -> ServiceUpgradeStep
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ServiceUpgradeStep
impl ComposeSchema for ServiceUpgradeStep
Sourceimpl Debug for ServiceUpgradeStep
impl Debug for ServiceUpgradeStep
Sourceimpl<'de> Deserialize<'de> for ServiceUpgradeStep
impl<'de> Deserialize<'de> for ServiceUpgradeStep
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ServiceUpgradeStep
Sourceimpl JsonSchema for ServiceUpgradeStep
impl JsonSchema for ServiceUpgradeStep
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ServiceUpgradeStep
impl PartialEq for ServiceUpgradeStep
Sourceimpl Serialize for ServiceUpgradeStep
impl Serialize for ServiceUpgradeStep
impl StructuralPartialEq for ServiceUpgradeStep