pub struct SupportCombinationInput {
pub combination_id: String,
pub component_references: Vec<String>,
pub state_version: String,
pub status: SupportStatus,
}Fields
combination_id: Stringcomponent_references: Vec<String>state_version: Stringstatus: SupportStatusTrait Implementations
Sourceimpl Clone for SupportCombinationInput
impl Clone for SupportCombinationInput
Sourcefn clone(&self) -> SupportCombinationInput
fn clone(&self) -> SupportCombinationInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for SupportCombinationInput
impl ComposeSchema for SupportCombinationInput
Sourceimpl Debug for SupportCombinationInput
impl Debug for SupportCombinationInput
Sourceimpl<'de> Deserialize<'de> for SupportCombinationInput
impl<'de> Deserialize<'de> for SupportCombinationInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SupportCombinationInput
Sourceimpl JsonSchema for SupportCombinationInput
impl JsonSchema for SupportCombinationInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SupportCombinationInput
impl PartialEq for SupportCombinationInput
Sourceimpl Serialize for SupportCombinationInput
impl Serialize for SupportCombinationInput
impl StructuralPartialEq for SupportCombinationInput