pub struct SupportEnvelope {
pub protocol: String,
pub envelope_id: String,
pub envelope_digest: String,
pub support_manifest_digest: String,
pub adapter_versions: BTreeMap<String, String>,
pub points: Vec<SupportScalePoint>,
pub recommended_service_limit: u32,
pub decision: SupportEnvelopeDecision,
pub issues: Vec<SupportEnvelopeIssue>,
pub next_actions: Vec<String>,
}Fields
protocol: Stringenvelope_id: Stringenvelope_digest: Stringsupport_manifest_digest: Stringadapter_versions: BTreeMap<String, String>points: Vec<SupportScalePoint>recommended_service_limit: u32decision: SupportEnvelopeDecisionissues: Vec<SupportEnvelopeIssue>next_actions: Vec<String>Trait Implementations
Sourceimpl Clone for SupportEnvelope
impl Clone for SupportEnvelope
Sourcefn clone(&self) -> SupportEnvelope
fn clone(&self) -> SupportEnvelope
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for SupportEnvelope
impl ComposeSchema for SupportEnvelope
Sourceimpl Debug for SupportEnvelope
impl Debug for SupportEnvelope
Sourceimpl<'de> Deserialize<'de> for SupportEnvelope
impl<'de> Deserialize<'de> for SupportEnvelope
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SupportEnvelope
Sourceimpl JsonSchema for SupportEnvelope
impl JsonSchema for SupportEnvelope
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SupportEnvelope
impl PartialEq for SupportEnvelope
Sourceimpl Serialize for SupportEnvelope
impl Serialize for SupportEnvelope
impl StructuralPartialEq for SupportEnvelope