pub struct SupportEnvelopeInput {
pub support_manifest_digest: String,
pub adapter_versions: BTreeMap<String, String>,
pub points: Vec<SupportScalePoint>,
pub recommended_service_limit: u32,
pub variance_tolerance_basis_points: u32,
}Fields
support_manifest_digest: Stringadapter_versions: BTreeMap<String, String>points: Vec<SupportScalePoint>recommended_service_limit: u32variance_tolerance_basis_points: u32Trait Implementations
Sourceimpl Clone for SupportEnvelopeInput
impl Clone for SupportEnvelopeInput
Sourcefn clone(&self) -> SupportEnvelopeInput
fn clone(&self) -> SupportEnvelopeInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for SupportEnvelopeInput
impl ComposeSchema for SupportEnvelopeInput
Sourceimpl Debug for SupportEnvelopeInput
impl Debug for SupportEnvelopeInput
Sourceimpl<'de> Deserialize<'de> for SupportEnvelopeInput
impl<'de> Deserialize<'de> for SupportEnvelopeInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SupportEnvelopeInput
Sourceimpl JsonSchema for SupportEnvelopeInput
impl JsonSchema for SupportEnvelopeInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SupportEnvelopeInput
impl PartialEq for SupportEnvelopeInput
Sourceimpl Serialize for SupportEnvelopeInput
impl Serialize for SupportEnvelopeInput
impl StructuralPartialEq for SupportEnvelopeInput