pub struct SupportEnvelopeIssue {
pub code: SupportEnvelopeIssueCode,
pub message: String,
pub remediation: String,
pub next_actions: Vec<String>,
}Fields
code: SupportEnvelopeIssueCodemessage: Stringremediation: Stringnext_actions: Vec<String>Trait Implementations
Sourceimpl Clone for SupportEnvelopeIssue
impl Clone for SupportEnvelopeIssue
Sourcefn clone(&self) -> SupportEnvelopeIssue
fn clone(&self) -> SupportEnvelopeIssue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for SupportEnvelopeIssue
impl ComposeSchema for SupportEnvelopeIssue
Sourceimpl Debug for SupportEnvelopeIssue
impl Debug for SupportEnvelopeIssue
Sourceimpl<'de> Deserialize<'de> for SupportEnvelopeIssue
impl<'de> Deserialize<'de> for SupportEnvelopeIssue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SupportEnvelopeIssue
Sourceimpl JsonSchema for SupportEnvelopeIssue
impl JsonSchema for SupportEnvelopeIssue
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SupportEnvelopeIssue
impl PartialEq for SupportEnvelopeIssue
Sourceimpl Serialize for SupportEnvelopeIssue
impl Serialize for SupportEnvelopeIssue
impl StructuralPartialEq for SupportEnvelopeIssue