pub struct SupportScalePoint {Show 23 fields
pub service_count: u32,
pub workload_count: u32,
pub store_count: u32,
pub contract_count: u32,
pub workflow_count: u32,
pub tenant_count: u32,
pub topology_digest: String,
pub environment_digest: String,
pub compatible_baseline_digest: String,
pub environment_verification: bool,
pub environment_drift_detected: bool,
pub measurement_digests: BTreeMap<String, String>,
pub budgets_passed: bool,
pub repeated_run_count: u32,
pub variance_basis_points: u32,
pub system_plane_data_plane_requests: u64,
pub runtime_console_data_plane_requests: u64,
pub telemetry_data_plane_requests: u64,
pub policy_data_plane_requests: u64,
pub registry_data_plane_requests: u64,
pub saturation_signal: String,
pub bottlenecks: Vec<String>,
pub cleanup_complete: bool,
}Fields
service_count: u32workload_count: u32store_count: u32contract_count: u32workflow_count: u32tenant_count: u32topology_digest: Stringenvironment_digest: Stringcompatible_baseline_digest: Stringenvironment_verification: boolenvironment_drift_detected: boolmeasurement_digests: BTreeMap<String, String>budgets_passed: boolrepeated_run_count: u32variance_basis_points: u32system_plane_data_plane_requests: u64runtime_console_data_plane_requests: u64telemetry_data_plane_requests: u64policy_data_plane_requests: u64registry_data_plane_requests: u64saturation_signal: Stringbottlenecks: Vec<String>cleanup_complete: boolTrait Implementations
Sourceimpl Clone for SupportScalePoint
impl Clone for SupportScalePoint
Sourcefn clone(&self) -> SupportScalePoint
fn clone(&self) -> SupportScalePoint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for SupportScalePoint
impl ComposeSchema for SupportScalePoint
Sourceimpl Debug for SupportScalePoint
impl Debug for SupportScalePoint
Sourceimpl<'de> Deserialize<'de> for SupportScalePoint
impl<'de> Deserialize<'de> for SupportScalePoint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SupportScalePoint
Sourceimpl JsonSchema for SupportScalePoint
impl JsonSchema for SupportScalePoint
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SupportScalePoint
impl PartialEq for SupportScalePoint
Sourceimpl Serialize for SupportScalePoint
impl Serialize for SupportScalePoint
impl StructuralPartialEq for SupportScalePoint