pub struct ThreatModelEvidence {
pub surface: ThreatSurface,
pub model_version: String,
pub model_digest: String,
pub reviewed: bool,
}Fields
surface: ThreatSurfacemodel_version: Stringmodel_digest: Stringreviewed: boolTrait Implementations
Sourceimpl Clone for ThreatModelEvidence
impl Clone for ThreatModelEvidence
Sourcefn clone(&self) -> ThreatModelEvidence
fn clone(&self) -> ThreatModelEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ThreatModelEvidence
impl ComposeSchema for ThreatModelEvidence
Sourceimpl Debug for ThreatModelEvidence
impl Debug for ThreatModelEvidence
Sourceimpl<'de> Deserialize<'de> for ThreatModelEvidence
impl<'de> Deserialize<'de> for ThreatModelEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ThreatModelEvidence
Sourceimpl JsonSchema for ThreatModelEvidence
impl JsonSchema for ThreatModelEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ThreatModelEvidence
impl PartialEq for ThreatModelEvidence
Sourceimpl Serialize for ThreatModelEvidence
impl Serialize for ThreatModelEvidence
impl StructuralPartialEq for ThreatModelEvidence