pub struct UpgradeEdgeInput {
pub edge_id: String,
pub source_format: String,
pub target_format: String,
pub mixed_version_references: Vec<String>,
pub rollback_safe: bool,
}Fields
edge_id: Stringsource_format: Stringtarget_format: Stringmixed_version_references: Vec<String>rollback_safe: boolTrait Implementations
Sourceimpl Clone for UpgradeEdgeInput
impl Clone for UpgradeEdgeInput
Sourcefn clone(&self) -> UpgradeEdgeInput
fn clone(&self) -> UpgradeEdgeInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for UpgradeEdgeInput
impl ComposeSchema for UpgradeEdgeInput
Sourceimpl Debug for UpgradeEdgeInput
impl Debug for UpgradeEdgeInput
Sourceimpl<'de> Deserialize<'de> for UpgradeEdgeInput
impl<'de> Deserialize<'de> for UpgradeEdgeInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for UpgradeEdgeInput
Sourceimpl JsonSchema for UpgradeEdgeInput
impl JsonSchema for UpgradeEdgeInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for UpgradeEdgeInput
impl PartialEq for UpgradeEdgeInput
Sourceimpl Serialize for UpgradeEdgeInput
impl Serialize for UpgradeEdgeInput
impl StructuralPartialEq for UpgradeEdgeInput