pub struct UpgradeRollbackConstraint {
pub automatic_allowed: bool,
pub reason: String,
pub approval_boundary: Option<String>,
}Fields
automatic_allowed: boolreason: Stringapproval_boundary: Option<String>Trait Implementations
Sourceimpl Clone for UpgradeRollbackConstraint
impl Clone for UpgradeRollbackConstraint
Sourcefn clone(&self) -> UpgradeRollbackConstraint
fn clone(&self) -> UpgradeRollbackConstraint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for UpgradeRollbackConstraint
impl ComposeSchema for UpgradeRollbackConstraint
Sourceimpl Debug for UpgradeRollbackConstraint
impl Debug for UpgradeRollbackConstraint
Sourceimpl<'de> Deserialize<'de> for UpgradeRollbackConstraint
impl<'de> Deserialize<'de> for UpgradeRollbackConstraint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for UpgradeRollbackConstraint
Sourceimpl JsonSchema for UpgradeRollbackConstraint
impl JsonSchema for UpgradeRollbackConstraint
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for UpgradeRollbackConstraint