pub struct WorkflowCompatibilityInput {
pub new_starts_compatible: Option<bool>,
pub in_flight_compatible: Option<bool>,
pub downgrade_safe: Option<bool>,
}Fields
new_starts_compatible: Option<bool>in_flight_compatible: Option<bool>downgrade_safe: Option<bool>Trait Implementations
Sourceimpl Clone for WorkflowCompatibilityInput
impl Clone for WorkflowCompatibilityInput
Sourcefn clone(&self) -> WorkflowCompatibilityInput
fn clone(&self) -> WorkflowCompatibilityInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for WorkflowCompatibilityInput
impl ComposeSchema for WorkflowCompatibilityInput
Sourceimpl Debug for WorkflowCompatibilityInput
impl Debug for WorkflowCompatibilityInput
Sourceimpl<'de> Deserialize<'de> for WorkflowCompatibilityInput
impl<'de> Deserialize<'de> for WorkflowCompatibilityInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WorkflowCompatibilityInput
Sourceimpl JsonSchema for WorkflowCompatibilityInput
impl JsonSchema for WorkflowCompatibilityInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for WorkflowCompatibilityInput