pub struct WorkloadArtifact {
pub workload_id: String,
pub role: ReleaseWorkloadRole,
pub artifact_reference: String,
pub artifact_digest: String,
pub media_type: String,
pub display_tag: Option<String>,
pub sbom: DeliveryEvidenceReference,
pub provenance: ReleaseProvenance,
pub signature_subject: String,
}Fields
workload_id: Stringrole: ReleaseWorkloadRoleartifact_reference: Stringartifact_digest: Stringmedia_type: Stringdisplay_tag: Option<String>sbom: DeliveryEvidenceReferenceprovenance: ReleaseProvenancesignature_subject: StringTrait Implementations
Sourceimpl Clone for WorkloadArtifact
impl Clone for WorkloadArtifact
Sourcefn clone(&self) -> WorkloadArtifact
fn clone(&self) -> WorkloadArtifact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for WorkloadArtifact
impl ComposeSchema for WorkloadArtifact
Sourceimpl Debug for WorkloadArtifact
impl Debug for WorkloadArtifact
Sourceimpl<'de> Deserialize<'de> for WorkloadArtifact
impl<'de> Deserialize<'de> for WorkloadArtifact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WorkloadArtifact
Sourceimpl JsonSchema for WorkloadArtifact
impl JsonSchema for WorkloadArtifact
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for WorkloadArtifact
impl PartialEq for WorkloadArtifact
Sourceimpl Serialize for WorkloadArtifact
impl Serialize for WorkloadArtifact
impl StructuralPartialEq for WorkloadArtifact