pub struct ActionContributionResolutionRequest {
pub context: ManagedServiceContext,
pub slot: String,
pub slot_version: u32,
pub slot_context: BTreeMap<String, Value>,
}Fields
context: ManagedServiceContextslot: Stringslot_version: u32slot_context: BTreeMap<String, Value>Trait Implementations
Sourceimpl Clone for ActionContributionResolutionRequest
impl Clone for ActionContributionResolutionRequest
Sourcefn clone(&self) -> ActionContributionResolutionRequest
fn clone(&self) -> ActionContributionResolutionRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ActionContributionResolutionRequest
impl ComposeSchema for ActionContributionResolutionRequest
Sourceimpl<'de> Deserialize<'de> for ActionContributionResolutionRequest
impl<'de> Deserialize<'de> for ActionContributionResolutionRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ActionContributionResolutionRequest
Sourceimpl JsonSchema for ActionContributionResolutionRequest
impl JsonSchema for ActionContributionResolutionRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ActionContributionResolutionRequest