pub struct ModuleConfigAuditEvidence {
pub sequence: u64,
pub operation_id: String,
pub module_id: String,
pub key: String,
pub sensitive: bool,
pub old_value_digest: Option<String>,
pub new_value_digest: String,
pub recorded_at_unix_ms: u64,
}Fields
sequence: u64operation_id: Stringmodule_id: Stringkey: Stringsensitive: boolold_value_digest: Option<String>new_value_digest: Stringrecorded_at_unix_ms: u64Trait Implementations
Sourceimpl Clone for ModuleConfigAuditEvidence
impl Clone for ModuleConfigAuditEvidence
Sourcefn clone(&self) -> ModuleConfigAuditEvidence
fn clone(&self) -> ModuleConfigAuditEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ModuleConfigAuditEvidence
impl ComposeSchema for ModuleConfigAuditEvidence
Sourceimpl Debug for ModuleConfigAuditEvidence
impl Debug for ModuleConfigAuditEvidence
Sourceimpl<'de> Deserialize<'de> for ModuleConfigAuditEvidence
impl<'de> Deserialize<'de> for ModuleConfigAuditEvidence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleConfigAuditEvidence
Sourceimpl JsonSchema for ModuleConfigAuditEvidence
impl JsonSchema for ModuleConfigAuditEvidence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ModuleConfigAuditEvidence