pub struct ModuleConfigReadRequest {
pub context: ManagedServiceContext,
pub module_id: String,
pub keys: Vec<String>,
}Fields
context: ManagedServiceContextmodule_id: Stringkeys: Vec<String>Trait Implementations
Sourceimpl Clone for ModuleConfigReadRequest
impl Clone for ModuleConfigReadRequest
Sourcefn clone(&self) -> ModuleConfigReadRequest
fn clone(&self) -> ModuleConfigReadRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ModuleConfigReadRequest
impl ComposeSchema for ModuleConfigReadRequest
Sourceimpl Debug for ModuleConfigReadRequest
impl Debug for ModuleConfigReadRequest
Sourceimpl<'de> Deserialize<'de> for ModuleConfigReadRequest
impl<'de> Deserialize<'de> for ModuleConfigReadRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleConfigReadRequest
Sourceimpl JsonSchema for ModuleConfigReadRequest
impl JsonSchema for ModuleConfigReadRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleConfigReadRequest
impl PartialEq for ModuleConfigReadRequest
Sourceimpl Serialize for ModuleConfigReadRequest
impl Serialize for ModuleConfigReadRequest
impl StructuralPartialEq for ModuleConfigReadRequest