pub struct ModuleConfigReadResponse {
pub protocol: String,
pub context: ManagedServiceContext,
pub module_id: String,
pub values: Vec<ModuleConfigValue>,
}Fields
protocol: Stringcontext: ManagedServiceContextmodule_id: Stringvalues: Vec<ModuleConfigValue>Trait Implementations
Sourceimpl Clone for ModuleConfigReadResponse
impl Clone for ModuleConfigReadResponse
Sourcefn clone(&self) -> ModuleConfigReadResponse
fn clone(&self) -> ModuleConfigReadResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ModuleConfigReadResponse
impl ComposeSchema for ModuleConfigReadResponse
Sourceimpl Debug for ModuleConfigReadResponse
impl Debug for ModuleConfigReadResponse
Sourceimpl<'de> Deserialize<'de> for ModuleConfigReadResponse
impl<'de> Deserialize<'de> for ModuleConfigReadResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleConfigReadResponse
Sourceimpl JsonSchema for ModuleConfigReadResponse
impl JsonSchema for ModuleConfigReadResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleConfigReadResponse
impl PartialEq for ModuleConfigReadResponse
Sourceimpl Serialize for ModuleConfigReadResponse
impl Serialize for ModuleConfigReadResponse
impl StructuralPartialEq for ModuleConfigReadResponse