pub struct ModuleConfigWriteRequest {
pub context: ManagedServiceContext,
pub module_id: String,
pub values: Vec<ModuleConfigWriteValue>,
}Fields
context: ManagedServiceContextmodule_id: Stringvalues: Vec<ModuleConfigWriteValue>Trait Implementations
Sourceimpl Clone for ModuleConfigWriteRequest
impl Clone for ModuleConfigWriteRequest
Sourcefn clone(&self) -> ModuleConfigWriteRequest
fn clone(&self) -> ModuleConfigWriteRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ModuleConfigWriteRequest
impl ComposeSchema for ModuleConfigWriteRequest
Sourceimpl Debug for ModuleConfigWriteRequest
impl Debug for ModuleConfigWriteRequest
Sourceimpl<'de> Deserialize<'de> for ModuleConfigWriteRequest
impl<'de> Deserialize<'de> for ModuleConfigWriteRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ModuleConfigWriteRequest
impl JsonSchema for ModuleConfigWriteRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleConfigWriteRequest
impl PartialEq for ModuleConfigWriteRequest
Sourceimpl Serialize for ModuleConfigWriteRequest
impl Serialize for ModuleConfigWriteRequest
impl StructuralPartialEq for ModuleConfigWriteRequest