pub struct ModuleConfigWriteResponse {
pub protocol: String,
pub operation_id: String,
pub context: ManagedServiceContext,
pub module_id: String,
pub target_revision_before: String,
pub target_revision_after: String,
pub authorization_digest: String,
pub evidence: Vec<ModuleConfigAuditEvidence>,
}Fields
protocol: Stringoperation_id: Stringcontext: ManagedServiceContextmodule_id: Stringtarget_revision_before: Stringtarget_revision_after: Stringevidence: Vec<ModuleConfigAuditEvidence>Trait Implementations
Sourceimpl Clone for ModuleConfigWriteResponse
impl Clone for ModuleConfigWriteResponse
Sourcefn clone(&self) -> ModuleConfigWriteResponse
fn clone(&self) -> ModuleConfigWriteResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ModuleConfigWriteResponse
impl ComposeSchema for ModuleConfigWriteResponse
Sourceimpl Debug for ModuleConfigWriteResponse
impl Debug for ModuleConfigWriteResponse
Sourceimpl<'de> Deserialize<'de> for ModuleConfigWriteResponse
impl<'de> Deserialize<'de> for ModuleConfigWriteResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ModuleConfigWriteResponse
Sourceimpl JsonSchema for ModuleConfigWriteResponse
impl JsonSchema for ModuleConfigWriteResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ModuleConfigWriteResponse