pub struct ModuleConfigWriteValue {
pub key: String,
pub value: Value,
}Fields
key: Stringvalue: ValueTrait Implementations
Sourceimpl Clone for ModuleConfigWriteValue
impl Clone for ModuleConfigWriteValue
Sourcefn clone(&self) -> ModuleConfigWriteValue
fn clone(&self) -> ModuleConfigWriteValue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ModuleConfigWriteValue
impl ComposeSchema for ModuleConfigWriteValue
Sourceimpl Debug for ModuleConfigWriteValue
impl Debug for ModuleConfigWriteValue
Sourceimpl<'de> Deserialize<'de> for ModuleConfigWriteValue
impl<'de> Deserialize<'de> for ModuleConfigWriteValue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ModuleConfigWriteValue
impl JsonSchema for ModuleConfigWriteValue
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModuleConfigWriteValue
impl PartialEq for ModuleConfigWriteValue
Sourceimpl Serialize for ModuleConfigWriteValue
impl Serialize for ModuleConfigWriteValue
impl StructuralPartialEq for ModuleConfigWriteValue