pub struct RuntimeObservabilitySnapshot {
pub protocol: String,
pub service_id: String,
pub service_revision: String,
pub snapshot_revision: String,
pub schema_digest: String,
pub next_cursor: String,
pub observed_at: DateTime<Utc>,
pub status: RuntimeObservabilityStatus,
pub queues: Vec<RuntimeQueueSummary>,
}Fields
protocol: Stringservice_id: Stringservice_revision: Stringsnapshot_revision: Stringschema_digest: Stringnext_cursor: Stringobserved_at: DateTime<Utc>status: RuntimeObservabilityStatusqueues: Vec<RuntimeQueueSummary>Trait Implementations
Sourceimpl Clone for RuntimeObservabilitySnapshot
impl Clone for RuntimeObservabilitySnapshot
Sourcefn clone(&self) -> RuntimeObservabilitySnapshot
fn clone(&self) -> RuntimeObservabilitySnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RuntimeObservabilitySnapshot
impl ComposeSchema for RuntimeObservabilitySnapshot
Sourceimpl Debug for RuntimeObservabilitySnapshot
impl Debug for RuntimeObservabilitySnapshot
Sourceimpl<'de> Deserialize<'de> for RuntimeObservabilitySnapshot
impl<'de> Deserialize<'de> for RuntimeObservabilitySnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RuntimeObservabilitySnapshot
Sourceimpl JsonSchema for RuntimeObservabilitySnapshot
impl JsonSchema for RuntimeObservabilitySnapshot
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for RuntimeObservabilitySnapshot