pub struct RuntimeObservationChange {
pub sequence: u64,
pub queue: RuntimeQueueKind,
pub resource_id: String,
pub change_kind: RuntimeObservationChangeKind,
pub recorded_at: DateTime<Utc>,
}Fields
sequence: u64queue: RuntimeQueueKindresource_id: Stringchange_kind: RuntimeObservationChangeKindrecorded_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for RuntimeObservationChange
impl Clone for RuntimeObservationChange
Sourcefn clone(&self) -> RuntimeObservationChange
fn clone(&self) -> RuntimeObservationChange
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RuntimeObservationChange
impl ComposeSchema for RuntimeObservationChange
Sourceimpl Debug for RuntimeObservationChange
impl Debug for RuntimeObservationChange
Sourceimpl<'de> Deserialize<'de> for RuntimeObservationChange
impl<'de> Deserialize<'de> for RuntimeObservationChange
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RuntimeObservationChange
Sourceimpl JsonSchema for RuntimeObservationChange
impl JsonSchema for RuntimeObservationChange
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RuntimeObservationChange
impl PartialEq for RuntimeObservationChange
Sourceimpl Serialize for RuntimeObservationChange
impl Serialize for RuntimeObservationChange
impl StructuralPartialEq for RuntimeObservationChange