pub struct RuntimeObservationFeed {
pub protocol: String,
pub service_id: String,
pub service_revision: String,
pub schema_digest: String,
pub collected_at: DateTime<Utc>,
pub continuity: RuntimeObservationContinuity,
pub evidence_gap: Option<RuntimeObservationEvidenceGap>,
pub changes: Vec<RuntimeObservationChange>,
pub next_cursor: String,
pub has_more: bool,
}Fields
protocol: Stringservice_id: Stringservice_revision: Stringschema_digest: Stringcollected_at: DateTime<Utc>continuity: RuntimeObservationContinuityevidence_gap: Option<RuntimeObservationEvidenceGap>changes: Vec<RuntimeObservationChange>next_cursor: Stringhas_more: boolTrait Implementations
Sourceimpl Clone for RuntimeObservationFeed
impl Clone for RuntimeObservationFeed
Sourcefn clone(&self) -> RuntimeObservationFeed
fn clone(&self) -> RuntimeObservationFeed
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RuntimeObservationFeed
impl ComposeSchema for RuntimeObservationFeed
Sourceimpl Debug for RuntimeObservationFeed
impl Debug for RuntimeObservationFeed
Sourceimpl<'de> Deserialize<'de> for RuntimeObservationFeed
impl<'de> Deserialize<'de> for RuntimeObservationFeed
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RuntimeObservationFeed
Sourceimpl JsonSchema for RuntimeObservationFeed
impl JsonSchema for RuntimeObservationFeed
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RuntimeObservationFeed
impl PartialEq for RuntimeObservationFeed
Sourceimpl Serialize for RuntimeObservationFeed
impl Serialize for RuntimeObservationFeed
impl StructuralPartialEq for RuntimeObservationFeed