pub struct RuntimeQueueSummary {
pub queue: RuntimeQueueKind,
pub pending: u64,
pub active: u64,
pub completed: u64,
pub failed: u64,
pub dead: u64,
pub oldest_pending_age_seconds: Option<u64>,
pub oldest_failed_age_seconds: Option<u64>,
}Fields
queue: RuntimeQueueKindpending: u64active: u64completed: u64failed: u64dead: u64oldest_pending_age_seconds: Option<u64>oldest_failed_age_seconds: Option<u64>Trait Implementations
Sourceimpl Clone for RuntimeQueueSummary
impl Clone for RuntimeQueueSummary
Sourcefn clone(&self) -> RuntimeQueueSummary
fn clone(&self) -> RuntimeQueueSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RuntimeQueueSummary
impl ComposeSchema for RuntimeQueueSummary
Sourceimpl Debug for RuntimeQueueSummary
impl Debug for RuntimeQueueSummary
Sourceimpl<'de> Deserialize<'de> for RuntimeQueueSummary
impl<'de> Deserialize<'de> for RuntimeQueueSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RuntimeQueueSummary
Sourceimpl JsonSchema for RuntimeQueueSummary
impl JsonSchema for RuntimeQueueSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RuntimeQueueSummary
impl PartialEq for RuntimeQueueSummary
Sourceimpl Serialize for RuntimeQueueSummary
impl Serialize for RuntimeQueueSummary
impl StructuralPartialEq for RuntimeQueueSummary