pub struct ManagementActor {
pub kind: ManagementActorKind,
pub subject: String,
pub delegated_authority_digest: String,
}Fields
kind: ManagementActorKindsubject: StringTrait Implementations
Sourceimpl Clone for ManagementActor
impl Clone for ManagementActor
Sourcefn clone(&self) -> ManagementActor
fn clone(&self) -> ManagementActor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ManagementActor
impl ComposeSchema for ManagementActor
Sourceimpl Debug for ManagementActor
impl Debug for ManagementActor
Sourceimpl<'de> Deserialize<'de> for ManagementActor
impl<'de> Deserialize<'de> for ManagementActor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ManagementActor
Sourceimpl JsonSchema for ManagementActor
impl JsonSchema for ManagementActor
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ManagementActor
impl PartialEq for ManagementActor
Sourceimpl Serialize for ManagementActor
impl Serialize for ManagementActor
impl StructuralPartialEq for ManagementActor