pub struct ManagementIntent {Show 13 fields
pub protocol: String,
pub intent_id: String,
pub service_id: String,
pub service_revision: String,
pub target: RuntimeOperationTarget,
pub desired_outcome: RuntimeOperationDesiredOutcome,
pub expected_target_revision: String,
pub actor: ManagementActor,
pub approvals: Vec<ManagementApproval>,
pub deadline_unix_ms: u64,
pub idempotency_key: String,
pub capability_contract_id: String,
pub capability_schema_digest: String,
}Fields
protocol: Stringintent_id: Stringservice_id: Stringservice_revision: Stringtarget: RuntimeOperationTargetdesired_outcome: RuntimeOperationDesiredOutcomeexpected_target_revision: Stringactor: ManagementActorapprovals: Vec<ManagementApproval>deadline_unix_ms: u64idempotency_key: Stringcapability_contract_id: Stringcapability_schema_digest: StringTrait Implementations
Sourceimpl Clone for ManagementIntent
impl Clone for ManagementIntent
Sourcefn clone(&self) -> ManagementIntent
fn clone(&self) -> ManagementIntent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ManagementIntent
impl ComposeSchema for ManagementIntent
Sourceimpl Debug for ManagementIntent
impl Debug for ManagementIntent
Sourceimpl<'de> Deserialize<'de> for ManagementIntent
impl<'de> Deserialize<'de> for ManagementIntent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ManagementIntent
Sourceimpl JsonSchema for ManagementIntent
impl JsonSchema for ManagementIntent
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ManagementIntent
impl PartialEq for ManagementIntent
Sourceimpl Serialize for ManagementIntent
impl Serialize for ManagementIntent
impl StructuralPartialEq for ManagementIntent