pub struct RuntimeOperationAcknowledgement {
pub protocol: String,
pub operation_id: String,
pub idempotency_key: String,
pub intent_digest: String,
pub plan_digest: String,
pub state: RuntimeOperationState,
pub accepted_at_unix_ms: u64,
pub authorization_epoch: u64,
pub enrollment_receipt_digest: String,
}Fields
protocol: Stringoperation_id: Stringidempotency_key: Stringintent_digest: Stringplan_digest: Stringstate: RuntimeOperationStateaccepted_at_unix_ms: u64enrollment_receipt_digest: StringTrait Implementations
Sourceimpl Clone for RuntimeOperationAcknowledgement
impl Clone for RuntimeOperationAcknowledgement
Sourcefn clone(&self) -> RuntimeOperationAcknowledgement
fn clone(&self) -> RuntimeOperationAcknowledgement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RuntimeOperationAcknowledgement
impl ComposeSchema for RuntimeOperationAcknowledgement
Sourceimpl<'de> Deserialize<'de> for RuntimeOperationAcknowledgement
impl<'de> Deserialize<'de> for RuntimeOperationAcknowledgement
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RuntimeOperationAcknowledgement
Sourceimpl JsonSchema for RuntimeOperationAcknowledgement
impl JsonSchema for RuntimeOperationAcknowledgement
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for RuntimeOperationAcknowledgement