pub struct RuntimeOperationPlanReceipt {Show 13 fields
pub protocol: String,
pub intent_digest: String,
pub plan_digest: String,
pub service_id: String,
pub service_revision: String,
pub target: RuntimeOperationTarget,
pub expected_target_revision: String,
pub expected_effects: Vec<String>,
pub risks: Vec<RuntimeOperationRisk>,
pub availability_impact: RuntimeOperationAvailabilityImpact,
pub compensation_support: RuntimeOperationCompensationSupport,
pub approval_required: bool,
pub expires_at_unix_ms: u64,
}Fields
protocol: Stringintent_digest: Stringplan_digest: Stringservice_id: Stringservice_revision: Stringtarget: RuntimeOperationTargetexpected_target_revision: Stringexpected_effects: Vec<String>risks: Vec<RuntimeOperationRisk>availability_impact: RuntimeOperationAvailabilityImpactcompensation_support: RuntimeOperationCompensationSupportapproval_required: boolexpires_at_unix_ms: u64Trait Implementations
Sourceimpl Clone for RuntimeOperationPlanReceipt
impl Clone for RuntimeOperationPlanReceipt
Sourcefn clone(&self) -> RuntimeOperationPlanReceipt
fn clone(&self) -> RuntimeOperationPlanReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RuntimeOperationPlanReceipt
impl ComposeSchema for RuntimeOperationPlanReceipt
Sourceimpl Debug for RuntimeOperationPlanReceipt
impl Debug for RuntimeOperationPlanReceipt
Sourceimpl<'de> Deserialize<'de> for RuntimeOperationPlanReceipt
impl<'de> Deserialize<'de> for RuntimeOperationPlanReceipt
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RuntimeOperationPlanReceipt
Sourceimpl JsonSchema for RuntimeOperationPlanReceipt
impl JsonSchema for RuntimeOperationPlanReceipt
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for RuntimeOperationPlanReceipt