pub struct RuntimeOperationRecovery {
pub protocol: String,
pub acknowledgement: RuntimeOperationAcknowledgement,
pub latest_evidence: RuntimeOperationEvidence,
}Fields
protocol: Stringacknowledgement: RuntimeOperationAcknowledgementlatest_evidence: RuntimeOperationEvidenceTrait Implementations
Sourceimpl Clone for RuntimeOperationRecovery
impl Clone for RuntimeOperationRecovery
Sourcefn clone(&self) -> RuntimeOperationRecovery
fn clone(&self) -> RuntimeOperationRecovery
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RuntimeOperationRecovery
impl ComposeSchema for RuntimeOperationRecovery
Sourceimpl Debug for RuntimeOperationRecovery
impl Debug for RuntimeOperationRecovery
Sourceimpl<'de> Deserialize<'de> for RuntimeOperationRecovery
impl<'de> Deserialize<'de> for RuntimeOperationRecovery
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RuntimeOperationRecovery
Sourceimpl JsonSchema for RuntimeOperationRecovery
impl JsonSchema for RuntimeOperationRecovery
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RuntimeOperationRecovery
impl PartialEq for RuntimeOperationRecovery
Sourceimpl Serialize for RuntimeOperationRecovery
impl Serialize for RuntimeOperationRecovery
impl StructuralPartialEq for RuntimeOperationRecovery