pub struct RuntimeOperationTarget {
pub kind: RuntimeOperationTargetKind,
pub target_id: String,
}Fields
kind: RuntimeOperationTargetKindtarget_id: StringTrait Implementations
Sourceimpl Clone for RuntimeOperationTarget
impl Clone for RuntimeOperationTarget
Sourcefn clone(&self) -> RuntimeOperationTarget
fn clone(&self) -> RuntimeOperationTarget
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RuntimeOperationTarget
impl ComposeSchema for RuntimeOperationTarget
Sourceimpl Debug for RuntimeOperationTarget
impl Debug for RuntimeOperationTarget
Sourceimpl<'de> Deserialize<'de> for RuntimeOperationTarget
impl<'de> Deserialize<'de> for RuntimeOperationTarget
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RuntimeOperationTarget
Sourceimpl JsonSchema for RuntimeOperationTarget
impl JsonSchema for RuntimeOperationTarget
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RuntimeOperationTarget
impl PartialEq for RuntimeOperationTarget
Sourceimpl Serialize for RuntimeOperationTarget
impl Serialize for RuntimeOperationTarget
impl StructuralPartialEq for RuntimeOperationTarget