pub struct CapabilityAdvertisement {
pub contract_id: String,
pub major_version: u32,
pub feature_ids: BTreeSet<String>,
pub schema_digest: String,
pub endpoint: String,
}Fields
contract_id: Stringmajor_version: u32feature_ids: BTreeSet<String>schema_digest: Stringendpoint: StringTrait Implementations
Sourceimpl Clone for CapabilityAdvertisement
impl Clone for CapabilityAdvertisement
Sourcefn clone(&self) -> CapabilityAdvertisement
fn clone(&self) -> CapabilityAdvertisement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CapabilityAdvertisement
impl ComposeSchema for CapabilityAdvertisement
Sourceimpl Debug for CapabilityAdvertisement
impl Debug for CapabilityAdvertisement
Sourceimpl<'de> Deserialize<'de> for CapabilityAdvertisement
impl<'de> Deserialize<'de> for CapabilityAdvertisement
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CapabilityAdvertisement
Sourceimpl JsonSchema for CapabilityAdvertisement
impl JsonSchema for CapabilityAdvertisement
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CapabilityAdvertisement
impl PartialEq for CapabilityAdvertisement
Sourceimpl Serialize for CapabilityAdvertisement
impl Serialize for CapabilityAdvertisement
impl StructuralPartialEq for CapabilityAdvertisement