pub struct CoreDocument {
pub protocol: String,
pub service_id: String,
pub service_principal: String,
pub service_revision: String,
pub capabilities: Vec<CapabilityAdvertisement>,
}Fields
protocol: Stringservice_id: Stringservice_principal: Stringservice_revision: Stringcapabilities: Vec<CapabilityAdvertisement>Trait Implementations
Sourceimpl Clone for CoreDocument
impl Clone for CoreDocument
Sourcefn clone(&self) -> CoreDocument
fn clone(&self) -> CoreDocument
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CoreDocument
impl ComposeSchema for CoreDocument
Sourceimpl Debug for CoreDocument
impl Debug for CoreDocument
Sourceimpl<'de> Deserialize<'de> for CoreDocument
impl<'de> Deserialize<'de> for CoreDocument
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CoreDocument
Sourceimpl JsonSchema for CoreDocument
impl JsonSchema for CoreDocument
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CoreDocument
impl PartialEq for CoreDocument
Sourceimpl Serialize for CoreDocument
impl Serialize for CoreDocument
impl StructuralPartialEq for CoreDocument