pub struct CoreIssue {
pub code: CoreIssueCode,
pub path: String,
pub message: String,
pub next_action: String,
}Fields
code: CoreIssueCodepath: Stringmessage: Stringnext_action: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for CoreIssue
impl<'de> Deserialize<'de> for CoreIssue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CoreIssue
Sourceimpl JsonSchema for CoreIssue
impl JsonSchema for CoreIssue
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for CoreIssue
impl Ord for CoreIssue
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for CoreIssue
impl PartialOrd for CoreIssue
impl StructuralPartialEq for CoreIssue